Coverage for cuda/bindings/_internal/runtime.pyx: 59.94%
1625 statements
« prev ^ index » next coverage.py v7.15.2, created at 2026-07-19 01:12 +0000
« prev ^ index » next coverage.py v7.15.2, created at 2026-07-19 01:12 +0000
1# SPDX-FileCopyrightText: Copyright (c) 2021-2026 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
2#
3# SPDX-License-Identifier: Apache-2.0
4#
5# This code was automatically generated across versions from 12.9.0 to 13.3.0. Do not modify it directly.
7# CYTHON-BINDINGS-GENERATED-DO-NOT-MODIFY-THIS-FILE: format=1; content-sha256=c45a1e41ddef35af045f2ff91e9703cb77870bf90603b3c5c7369e76f7a539f0
8import os
10from libc.stdint cimport uintptr_t
12from cuda.pathfinder import load_nvidia_dynamic_lib
13cimport cuda.bindings._lib.dlfcn as dlfcn
14cimport cuda.bindings._internal.runtime_ptds as ptds
15cimport cython
18###############################################################################
19# Per-thread default stream dispatch
20###############################################################################
22cdef bint __cudaPythonInit = False
23cdef bint __usePTDS = False
25cdef int _cudaPythonInit() except -1 nogil:
26 global __cudaPythonInit
27 global __usePTDS
28 with gil: 1a5
29 __usePTDS = bool(int(os.getenv('CUDA_PYTHON_CUDA_PER_THREAD_DEFAULT_STREAM', default=0))) 1a5
30 __cudaPythonInit = True 1a5
31 return __usePTDS 1a5
33cdef inline int cudaPythonInit() except -1 nogil:
34 if __cudaPythonInit: 2a ' ( ) * + , - . / : ; = 5 ? @ [ ] ^ _ ` { | } ~ abbbcbdbebfbgbhbibjbkblbmbnbobpbqbrbsbtbubvbwbxbybzbAbBbCbDbEbFbGbHbIbJbKbLbMbNbObPbQb6 RbM N 1 9 O P Q D s d E l t u q F L ! 2 G v w # r e c x m k f n i b g j h o y z A C B R $ % H S SbTbUbVbWbXb3 4 I YbZbT U J K V 7 W X Y Z 0 p 0b1b2b3b4b5b6b7b8b9b!b#b$b%b'b(b)b*b+b,b-b.b/b:b;b=b?b@b[b]b^b_b`b{b|b}b~bacbcccdcecfcgchcicjckclcmcncocpcqcrcsctcucvcwcxcyczcAcBcCcDcEcFcGcHcIcJc
35 return __usePTDS 2a ' ( ) * + , - . / : ; = 5 ? @ [ ] ^ _ ` { | } ~ abbbcbdbebfbgbhbibjbkblbmbnbobpbqbrbsbtbubvbwbxbybzbAbBbCbDbEbFbGbHbIbJbKbLbMbNbObPbQb6 RbM N 1 9 O P Q D s d E l t u q F L ! 2 G v w # r e c x m k f n i b g j h o y z A C B R $ % H S SbTbUbVbWbXb3 4 I YbZbT U J K V 7 W X Y Z 0 p 0b1b2b3b4b5b6b7b8b9b!b#b$b%b'b(b)b*b+b,b-b.b/b:b;b=b?b@b[b]b^b_b`b{b|b}b~bacbcccdcecfcgchcicjckclcmcncocpcqcrcsctcucvcwcxcyczcAcBcCcDcEcFcGcHcIcJc
36 return _cudaPythonInit() 1a5
39###############################################################################
40# EGL/GL/VDPAU helpers (implementations delegating to driver EGL/VDPAU/GL APIs)
41###############################################################################
43include "../_lib/cyruntime/cyruntime.pxi"
46###############################################################################
47# getLocalRuntimeVersion — dynamically loads cudart to read its own version
48###############################################################################
50cdef cudaError_t _getLocalRuntimeVersion(int* runtimeVersion) except ?cudaErrorCallRequiresNewerDriver nogil:
51 # Load cudart dynamically to read its embedded version number.
52 with gil: 18
53 loaded_dl = load_nvidia_dynamic_lib("cudart") 18
54 handle = <void *><uintptr_t>loaded_dl._handle_uint 18
56 cdef void* __cudaRuntimeGetVersion = dlfcn.dlsym(handle, 'cudaRuntimeGetVersion') 18
58 if __cudaRuntimeGetVersion == NULL: 18
59 with gil:
60 raise RuntimeError(f'Function "cudaRuntimeGetVersion" not found in {loaded_dl.abs_path}')
62 # We explicitly do *NOT* cleanup the library handle here, acknowledging
63 # that, yes, the handle leaks. The reason is that there's a
64 # `functools.cache` on the top-level caller of this function.
65 #
66 # This means this library would be opened once and then immediately closed,
67 # all the while remaining in the cache lurking there for people to call.
68 #
69 # Since we open the library one time (technically once per unique library name),
70 # there's not a ton of leakage, which we deem acceptable for the 1000x speedup
71 # achieved by caching (ultimately) `ctypes.CDLL` calls.
72 #
73 # Long(er)-term we can explore cleaning up the library using higher-level
74 # Python mechanisms, like `__del__` or `weakref.finalizer`s.
76 cdef cudaError_t err = cudaSuccess 18
77 err = (<cudaError_t (*)(int*) except ?cudaErrorCallRequiresNewerDriver nogil> __cudaRuntimeGetVersion)(runtimeVersion) 18
78 return err 18
81###############################################################################
82# C function declarations for static cudart (avoids infinite recursion through
83# the same-named Cython wrappers imported via `from ..cyruntime cimport *`)
84###############################################################################
86cdef extern from 'cuda_runtime_api.h' nogil:
87 cudaError_t _static_cudaDeviceReset "cudaDeviceReset" () noexcept
89cdef extern from 'cuda_runtime_api.h' nogil:
90 cudaError_t _static_cudaDeviceSynchronize "cudaDeviceSynchronize" () noexcept
92cdef extern from 'cuda_runtime_api.h' nogil:
93 cudaError_t _static_cudaDeviceSetLimit "cudaDeviceSetLimit" (cudaLimit limit, size_t value) noexcept
95cdef extern from 'cuda_runtime_api.h' nogil:
96 cudaError_t _static_cudaDeviceGetLimit "cudaDeviceGetLimit" (size_t* pValue, cudaLimit limit) noexcept
98cdef extern from 'cuda_runtime_api.h' nogil:
99 cudaError_t _static_cudaDeviceGetTexture1DLinearMaxWidth "cudaDeviceGetTexture1DLinearMaxWidth" (size_t* maxWidthInElements, const cudaChannelFormatDesc* fmtDesc, int device) noexcept
101cdef extern from 'cuda_runtime_api.h' nogil:
102 cudaError_t _static_cudaDeviceGetCacheConfig "cudaDeviceGetCacheConfig" (cudaFuncCache* pCacheConfig) noexcept
104cdef extern from 'cuda_runtime_api.h' nogil:
105 cudaError_t _static_cudaDeviceGetStreamPriorityRange "cudaDeviceGetStreamPriorityRange" (int* leastPriority, int* greatestPriority) noexcept
107cdef extern from 'cuda_runtime_api.h' nogil:
108 cudaError_t _static_cudaDeviceSetCacheConfig "cudaDeviceSetCacheConfig" (cudaFuncCache cacheConfig) noexcept
110cdef extern from 'cuda_runtime_api.h' nogil:
111 cudaError_t _static_cudaDeviceGetByPCIBusId "cudaDeviceGetByPCIBusId" (int* device, const char* pciBusId) noexcept
113cdef extern from 'cuda_runtime_api.h' nogil:
114 cudaError_t _static_cudaDeviceGetPCIBusId "cudaDeviceGetPCIBusId" (char* pciBusId, int len, int device) noexcept
116cdef extern from 'cuda_runtime_api.h' nogil:
117 cudaError_t _static_cudaIpcGetEventHandle "cudaIpcGetEventHandle" (cudaIpcEventHandle_t* handle, cudaEvent_t event) noexcept
119cdef extern from 'cuda_runtime_api.h' nogil:
120 cudaError_t _static_cudaIpcOpenEventHandle "cudaIpcOpenEventHandle" (cudaEvent_t* event, cudaIpcEventHandle_t handle) noexcept
122cdef extern from 'cuda_runtime_api.h' nogil:
123 cudaError_t _static_cudaIpcGetMemHandle "cudaIpcGetMemHandle" (cudaIpcMemHandle_t* handle, void* devPtr) noexcept
125cdef extern from 'cuda_runtime_api.h' nogil:
126 cudaError_t _static_cudaIpcOpenMemHandle "cudaIpcOpenMemHandle" (void** devPtr, cudaIpcMemHandle_t handle, unsigned int flags) noexcept
128cdef extern from 'cuda_runtime_api.h' nogil:
129 cudaError_t _static_cudaIpcCloseMemHandle "cudaIpcCloseMemHandle" (void* devPtr) noexcept
131cdef extern from 'cuda_runtime_api.h' nogil:
132 cudaError_t _static_cudaDeviceFlushGPUDirectRDMAWrites "cudaDeviceFlushGPUDirectRDMAWrites" (cudaFlushGPUDirectRDMAWritesTarget target, cudaFlushGPUDirectRDMAWritesScope scope) noexcept
134cdef extern from 'cuda_runtime_api.h' nogil:
135 cudaError_t _static_cudaDeviceRegisterAsyncNotification "cudaDeviceRegisterAsyncNotification" (int device, cudaAsyncCallback callbackFunc, void* userData, cudaAsyncCallbackHandle_t* callback) noexcept
137cdef extern from 'cuda_runtime_api.h' nogil:
138 cudaError_t _static_cudaDeviceUnregisterAsyncNotification "cudaDeviceUnregisterAsyncNotification" (int device, cudaAsyncCallbackHandle_t callback) noexcept
140cdef extern from 'cuda_runtime_api.h' nogil:
141 cudaError_t _static_cudaDeviceGetSharedMemConfig "cudaDeviceGetSharedMemConfig" (cudaSharedMemConfig* pConfig) noexcept
143cdef extern from 'cuda_runtime_api.h' nogil:
144 cudaError_t _static_cudaDeviceSetSharedMemConfig "cudaDeviceSetSharedMemConfig" (cudaSharedMemConfig config) noexcept
146cdef extern from 'cuda_runtime_api.h' nogil:
147 cudaError_t _static_cudaGetLastError "cudaGetLastError" () noexcept
149cdef extern from 'cuda_runtime_api.h' nogil:
150 cudaError_t _static_cudaPeekAtLastError "cudaPeekAtLastError" () noexcept
152cdef extern from 'cuda_runtime_api.h' nogil:
153 const char* _static_cudaGetErrorName "cudaGetErrorName" (cudaError_t error) noexcept
155cdef extern from 'cuda_runtime_api.h' nogil:
156 const char* _static_cudaGetErrorString "cudaGetErrorString" (cudaError_t error) noexcept
158cdef extern from 'cuda_runtime_api.h' nogil:
159 cudaError_t _static_cudaGetDeviceCount "cudaGetDeviceCount" (int* count) noexcept
161cdef extern from 'cuda_runtime_api.h' nogil:
162 cudaError_t _static_cudaDeviceGetAttribute "cudaDeviceGetAttribute" (int* value, cudaDeviceAttr attr, int device) noexcept
164cdef extern from 'cuda_runtime_api.h' nogil:
165 cudaError_t _static_cudaDeviceGetDefaultMemPool "cudaDeviceGetDefaultMemPool" (cudaMemPool_t* memPool, int device) noexcept
167cdef extern from 'cuda_runtime_api.h' nogil:
168 cudaError_t _static_cudaDeviceSetMemPool "cudaDeviceSetMemPool" (int device, cudaMemPool_t memPool) noexcept
170cdef extern from 'cuda_runtime_api.h' nogil:
171 cudaError_t _static_cudaDeviceGetMemPool "cudaDeviceGetMemPool" (cudaMemPool_t* memPool, int device) noexcept
173cdef extern from 'cuda_runtime_api.h' nogil:
174 cudaError_t _static_cudaDeviceGetNvSciSyncAttributes "cudaDeviceGetNvSciSyncAttributes" (void* nvSciSyncAttrList, int device, int flags) noexcept
176cdef extern from 'cuda_runtime_api.h' nogil:
177 cudaError_t _static_cudaDeviceGetP2PAttribute "cudaDeviceGetP2PAttribute" (int* value, cudaDeviceP2PAttr attr, int srcDevice, int dstDevice) noexcept
179cdef extern from 'cuda_runtime_api.h' nogil:
180 cudaError_t _static_cudaChooseDevice "cudaChooseDevice" (int* device, const cudaDeviceProp* prop) noexcept
182cdef extern from 'cuda_runtime_api.h' nogil:
183 cudaError_t _static_cudaInitDevice "cudaInitDevice" (int device, unsigned int deviceFlags, unsigned int flags) noexcept
185cdef extern from 'cuda_runtime_api.h' nogil:
186 cudaError_t _static_cudaSetDevice "cudaSetDevice" (int device) noexcept
188cdef extern from 'cuda_runtime_api.h' nogil:
189 cudaError_t _static_cudaGetDevice "cudaGetDevice" (int* device) noexcept
191cdef extern from 'cuda_runtime_api.h' nogil:
192 cudaError_t _static_cudaSetDeviceFlags "cudaSetDeviceFlags" (unsigned int flags) noexcept
194cdef extern from 'cuda_runtime_api.h' nogil:
195 cudaError_t _static_cudaGetDeviceFlags "cudaGetDeviceFlags" (unsigned int* flags) noexcept
197cdef extern from 'cuda_runtime_api.h' nogil:
198 cudaError_t _static_cudaStreamCreate "cudaStreamCreate" (cudaStream_t* pStream) noexcept
200cdef extern from 'cuda_runtime_api.h' nogil:
201 cudaError_t _static_cudaStreamCreateWithFlags "cudaStreamCreateWithFlags" (cudaStream_t* pStream, unsigned int flags) noexcept
203cdef extern from 'cuda_runtime_api.h' nogil:
204 cudaError_t _static_cudaStreamCreateWithPriority "cudaStreamCreateWithPriority" (cudaStream_t* pStream, unsigned int flags, int priority) noexcept
206cdef extern from 'cuda_runtime_api.h' nogil:
207 cudaError_t _static_cudaStreamGetPriority "cudaStreamGetPriority" (cudaStream_t hStream, int* priority) noexcept
209cdef extern from 'cuda_runtime_api.h' nogil:
210 cudaError_t _static_cudaStreamGetFlags "cudaStreamGetFlags" (cudaStream_t hStream, unsigned int* flags) noexcept
212cdef extern from 'cuda_runtime_api.h' nogil:
213 cudaError_t _static_cudaStreamGetId "cudaStreamGetId" (cudaStream_t hStream, unsigned long long* streamId) noexcept
215cdef extern from 'cuda_runtime_api.h' nogil:
216 cudaError_t _static_cudaStreamGetDevice "cudaStreamGetDevice" (cudaStream_t hStream, int* device) noexcept
218cdef extern from 'cuda_runtime_api.h' nogil:
219 cudaError_t _static_cudaCtxResetPersistingL2Cache "cudaCtxResetPersistingL2Cache" () noexcept
221cdef extern from 'cuda_runtime_api.h' nogil:
222 cudaError_t _static_cudaStreamCopyAttributes "cudaStreamCopyAttributes" (cudaStream_t dst, cudaStream_t src) noexcept
224cdef extern from 'cuda_runtime_api.h' nogil:
225 cudaError_t _static_cudaStreamGetAttribute "cudaStreamGetAttribute" (cudaStream_t hStream, cudaLaunchAttributeID attr, cudaLaunchAttributeValue* value_out) noexcept
227cdef extern from 'cuda_runtime_api.h' nogil:
228 cudaError_t _static_cudaStreamSetAttribute "cudaStreamSetAttribute" (cudaStream_t hStream, cudaLaunchAttributeID attr, const cudaLaunchAttributeValue* value) noexcept
230cdef extern from 'cuda_runtime_api.h' nogil:
231 cudaError_t _static_cudaStreamDestroy "cudaStreamDestroy" (cudaStream_t stream) noexcept
233cdef extern from 'cuda_runtime_api.h' nogil:
234 cudaError_t _static_cudaStreamWaitEvent "cudaStreamWaitEvent" (cudaStream_t stream, cudaEvent_t event, unsigned int flags) noexcept
236cdef extern from 'cuda_runtime_api.h' nogil:
237 cudaError_t _static_cudaStreamAddCallback "cudaStreamAddCallback" (cudaStream_t stream, cudaStreamCallback_t callback, void* userData, unsigned int flags) noexcept
239cdef extern from 'cuda_runtime_api.h' nogil:
240 cudaError_t _static_cudaStreamSynchronize "cudaStreamSynchronize" (cudaStream_t stream) noexcept
242cdef extern from 'cuda_runtime_api.h' nogil:
243 cudaError_t _static_cudaStreamQuery "cudaStreamQuery" (cudaStream_t stream) noexcept
245cdef extern from 'cuda_runtime_api.h' nogil:
246 cudaError_t _static_cudaStreamAttachMemAsync "cudaStreamAttachMemAsync" (cudaStream_t stream, void* devPtr, size_t length, unsigned int flags) noexcept
248cdef extern from 'cuda_runtime_api.h' nogil:
249 cudaError_t _static_cudaStreamBeginCapture "cudaStreamBeginCapture" (cudaStream_t stream, cudaStreamCaptureMode mode) noexcept
251cdef extern from 'cuda_runtime_api.h' nogil:
252 cudaError_t _static_cudaStreamBeginCaptureToGraph "cudaStreamBeginCaptureToGraph" (cudaStream_t stream, cudaGraph_t graph, const cudaGraphNode_t* dependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, cudaStreamCaptureMode mode) noexcept
254cdef extern from 'cuda_runtime_api.h' nogil:
255 cudaError_t _static_cudaThreadExchangeStreamCaptureMode "cudaThreadExchangeStreamCaptureMode" (cudaStreamCaptureMode* mode) noexcept
257cdef extern from 'cuda_runtime_api.h' nogil:
258 cudaError_t _static_cudaStreamEndCapture "cudaStreamEndCapture" (cudaStream_t stream, cudaGraph_t* pGraph) noexcept
260cdef extern from 'cuda_runtime_api.h' nogil:
261 cudaError_t _static_cudaStreamIsCapturing "cudaStreamIsCapturing" (cudaStream_t stream, cudaStreamCaptureStatus* pCaptureStatus) noexcept
263cdef extern from 'cuda_runtime_api.h' nogil:
264 cudaError_t _static_cudaStreamUpdateCaptureDependencies "cudaStreamUpdateCaptureDependencies" (cudaStream_t stream, cudaGraphNode_t* dependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, unsigned int flags) noexcept
266cdef extern from 'cuda_runtime_api.h' nogil:
267 cudaError_t _static_cudaEventCreate "cudaEventCreate" (cudaEvent_t* event) noexcept
269cdef extern from 'cuda_runtime_api.h' nogil:
270 cudaError_t _static_cudaEventCreateWithFlags "cudaEventCreateWithFlags" (cudaEvent_t* event, unsigned int flags) noexcept
272cdef extern from 'cuda_runtime_api.h' nogil:
273 cudaError_t _static_cudaEventRecord "cudaEventRecord" (cudaEvent_t event, cudaStream_t stream) noexcept
275cdef extern from 'cuda_runtime_api.h' nogil:
276 cudaError_t _static_cudaEventRecordWithFlags "cudaEventRecordWithFlags" (cudaEvent_t event, cudaStream_t stream, unsigned int flags) noexcept
278cdef extern from 'cuda_runtime_api.h' nogil:
279 cudaError_t _static_cudaEventQuery "cudaEventQuery" (cudaEvent_t event) noexcept
281cdef extern from 'cuda_runtime_api.h' nogil:
282 cudaError_t _static_cudaEventSynchronize "cudaEventSynchronize" (cudaEvent_t event) noexcept
284cdef extern from 'cuda_runtime_api.h' nogil:
285 cudaError_t _static_cudaEventDestroy "cudaEventDestroy" (cudaEvent_t event) noexcept
287cdef extern from 'cuda_runtime_api.h' nogil:
288 cudaError_t _static_cudaEventElapsedTime "cudaEventElapsedTime" (float* ms, cudaEvent_t start, cudaEvent_t end) noexcept
290cdef extern from 'cuda_runtime_api.h' nogil:
291 cudaError_t _static_cudaImportExternalMemory "cudaImportExternalMemory" (cudaExternalMemory_t* extMem_out, const cudaExternalMemoryHandleDesc* memHandleDesc) noexcept
293cdef extern from 'cuda_runtime_api.h' nogil:
294 cudaError_t _static_cudaExternalMemoryGetMappedBuffer "cudaExternalMemoryGetMappedBuffer" (void** devPtr, cudaExternalMemory_t extMem, const cudaExternalMemoryBufferDesc* bufferDesc) noexcept
296cdef extern from 'cuda_runtime_api.h' nogil:
297 cudaError_t _static_cudaExternalMemoryGetMappedMipmappedArray "cudaExternalMemoryGetMappedMipmappedArray" (cudaMipmappedArray_t* mipmap, cudaExternalMemory_t extMem, const cudaExternalMemoryMipmappedArrayDesc* mipmapDesc) noexcept
299cdef extern from 'cuda_runtime_api.h' nogil:
300 cudaError_t _static_cudaDestroyExternalMemory "cudaDestroyExternalMemory" (cudaExternalMemory_t extMem) noexcept
302cdef extern from 'cuda_runtime_api.h' nogil:
303 cudaError_t _static_cudaImportExternalSemaphore "cudaImportExternalSemaphore" (cudaExternalSemaphore_t* extSem_out, const cudaExternalSemaphoreHandleDesc* semHandleDesc) noexcept
305cdef extern from 'cuda_runtime_api.h' nogil:
306 cudaError_t _static_cudaDestroyExternalSemaphore "cudaDestroyExternalSemaphore" (cudaExternalSemaphore_t extSem) noexcept
308cdef extern from 'cuda_runtime_api.h' nogil:
309 cudaError_t _static_cudaFuncSetCacheConfig "cudaFuncSetCacheConfig" (const void* func, cudaFuncCache cacheConfig) noexcept
311cdef extern from 'cuda_runtime_api.h' nogil:
312 cudaError_t _static_cudaFuncGetAttributes "cudaFuncGetAttributes" (cudaFuncAttributes* attr, const void* func) noexcept
314cdef extern from 'cuda_runtime_api.h' nogil:
315 cudaError_t _static_cudaFuncSetAttribute "cudaFuncSetAttribute" (const void* func, cudaFuncAttribute attr, int value) noexcept
317cdef extern from 'cuda_runtime_api.h' nogil:
318 cudaError_t _static_cudaFuncGetName "cudaFuncGetName" (const char** name, const void* func) noexcept
320cdef extern from 'cuda_runtime_api.h' nogil:
321 cudaError_t _static_cudaFuncGetParamInfo "cudaFuncGetParamInfo" (const void* func, size_t paramIndex, size_t* paramOffset, size_t* paramSize) noexcept
323cdef extern from 'cuda_runtime_api.h' nogil:
324 cudaError_t _static_cudaLaunchHostFunc "cudaLaunchHostFunc" (cudaStream_t stream, cudaHostFn_t fn, void* userData) noexcept
326cdef extern from 'cuda_runtime_api.h' nogil:
327 cudaError_t _static_cudaFuncSetSharedMemConfig "cudaFuncSetSharedMemConfig" (const void* func, cudaSharedMemConfig config) noexcept
329cdef extern from 'cuda_runtime_api.h' nogil:
330 cudaError_t _static_cudaOccupancyMaxActiveBlocksPerMultiprocessor "cudaOccupancyMaxActiveBlocksPerMultiprocessor" (int* numBlocks, const void* func, int blockSize, size_t dynamicSMemSize) noexcept
332cdef extern from 'cuda_runtime_api.h' nogil:
333 cudaError_t _static_cudaOccupancyAvailableDynamicSMemPerBlock "cudaOccupancyAvailableDynamicSMemPerBlock" (size_t* dynamicSmemSize, const void* func, int numBlocks, int blockSize) noexcept
335cdef extern from 'cuda_runtime_api.h' nogil:
336 cudaError_t _static_cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags "cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags" (int* numBlocks, const void* func, int blockSize, size_t dynamicSMemSize, unsigned int flags) noexcept
338cdef extern from 'cuda_runtime_api.h' nogil:
339 cudaError_t _static_cudaMallocManaged "cudaMallocManaged" (void** devPtr, size_t size, unsigned int flags) noexcept
341cdef extern from 'cuda_runtime_api.h' nogil:
342 cudaError_t _static_cudaMalloc "cudaMalloc" (void** devPtr, size_t size) noexcept
344cdef extern from 'cuda_runtime_api.h' nogil:
345 cudaError_t _static_cudaMallocHost "cudaMallocHost" (void** ptr, size_t size) noexcept
347cdef extern from 'cuda_runtime_api.h' nogil:
348 cudaError_t _static_cudaMallocPitch "cudaMallocPitch" (void** devPtr, size_t* pitch, size_t width, size_t height) noexcept
350cdef extern from 'cuda_runtime_api.h' nogil:
351 cudaError_t _static_cudaMallocArray "cudaMallocArray" (cudaArray_t* array, const cudaChannelFormatDesc* desc, size_t width, size_t height, unsigned int flags) noexcept
353cdef extern from 'cuda_runtime_api.h' nogil:
354 cudaError_t _static_cudaFree "cudaFree" (void* devPtr) noexcept
356cdef extern from 'cuda_runtime_api.h' nogil:
357 cudaError_t _static_cudaFreeHost "cudaFreeHost" (void* ptr) noexcept
359cdef extern from 'cuda_runtime_api.h' nogil:
360 cudaError_t _static_cudaFreeArray "cudaFreeArray" (cudaArray_t array) noexcept
362cdef extern from 'cuda_runtime_api.h' nogil:
363 cudaError_t _static_cudaFreeMipmappedArray "cudaFreeMipmappedArray" (cudaMipmappedArray_t mipmappedArray) noexcept
365cdef extern from 'cuda_runtime_api.h' nogil:
366 cudaError_t _static_cudaHostAlloc "cudaHostAlloc" (void** pHost, size_t size, unsigned int flags) noexcept
368cdef extern from 'cuda_runtime_api.h' nogil:
369 cudaError_t _static_cudaHostRegister "cudaHostRegister" (void* ptr, size_t size, unsigned int flags) noexcept
371cdef extern from 'cuda_runtime_api.h' nogil:
372 cudaError_t _static_cudaHostUnregister "cudaHostUnregister" (void* ptr) noexcept
374cdef extern from 'cuda_runtime_api.h' nogil:
375 cudaError_t _static_cudaHostGetDevicePointer "cudaHostGetDevicePointer" (void** pDevice, void* pHost, unsigned int flags) noexcept
377cdef extern from 'cuda_runtime_api.h' nogil:
378 cudaError_t _static_cudaHostGetFlags "cudaHostGetFlags" (unsigned int* pFlags, void* pHost) noexcept
380cdef extern from 'cuda_runtime_api.h' nogil:
381 cudaError_t _static_cudaMalloc3D "cudaMalloc3D" (cudaPitchedPtr* pitchedDevPtr, cudaExtent extent) noexcept
383cdef extern from 'cuda_runtime_api.h' nogil:
384 cudaError_t _static_cudaMalloc3DArray "cudaMalloc3DArray" (cudaArray_t* array, const cudaChannelFormatDesc* desc, cudaExtent extent, unsigned int flags) noexcept
386cdef extern from 'cuda_runtime_api.h' nogil:
387 cudaError_t _static_cudaMallocMipmappedArray "cudaMallocMipmappedArray" (cudaMipmappedArray_t* mipmappedArray, const cudaChannelFormatDesc* desc, cudaExtent extent, unsigned int numLevels, unsigned int flags) noexcept
389cdef extern from 'cuda_runtime_api.h' nogil:
390 cudaError_t _static_cudaGetMipmappedArrayLevel "cudaGetMipmappedArrayLevel" (cudaArray_t* levelArray, cudaMipmappedArray_const_t mipmappedArray, unsigned int level) noexcept
392cdef extern from 'cuda_runtime_api.h' nogil:
393 cudaError_t _static_cudaMemcpy3D "cudaMemcpy3D" (const cudaMemcpy3DParms* p) noexcept
395cdef extern from 'cuda_runtime_api.h' nogil:
396 cudaError_t _static_cudaMemcpy3DPeer "cudaMemcpy3DPeer" (const cudaMemcpy3DPeerParms* p) noexcept
398cdef extern from 'cuda_runtime_api.h' nogil:
399 cudaError_t _static_cudaMemcpy3DAsync "cudaMemcpy3DAsync" (const cudaMemcpy3DParms* p, cudaStream_t stream) noexcept
401cdef extern from 'cuda_runtime_api.h' nogil:
402 cudaError_t _static_cudaMemcpy3DPeerAsync "cudaMemcpy3DPeerAsync" (const cudaMemcpy3DPeerParms* p, cudaStream_t stream) noexcept
404cdef extern from 'cuda_runtime_api.h' nogil:
405 cudaError_t _static_cudaMemGetInfo "cudaMemGetInfo" (size_t* free, size_t* total) noexcept
407cdef extern from 'cuda_runtime_api.h' nogil:
408 cudaError_t _static_cudaArrayGetInfo "cudaArrayGetInfo" (cudaChannelFormatDesc* desc, cudaExtent* extent, unsigned int* flags, cudaArray_t array) noexcept
410cdef extern from 'cuda_runtime_api.h' nogil:
411 cudaError_t _static_cudaArrayGetPlane "cudaArrayGetPlane" (cudaArray_t* pPlaneArray, cudaArray_t hArray, unsigned int planeIdx) noexcept
413cdef extern from 'cuda_runtime_api.h' nogil:
414 cudaError_t _static_cudaArrayGetMemoryRequirements "cudaArrayGetMemoryRequirements" (cudaArrayMemoryRequirements* memoryRequirements, cudaArray_t array, int device) noexcept
416cdef extern from 'cuda_runtime_api.h' nogil:
417 cudaError_t _static_cudaMipmappedArrayGetMemoryRequirements "cudaMipmappedArrayGetMemoryRequirements" (cudaArrayMemoryRequirements* memoryRequirements, cudaMipmappedArray_t mipmap, int device) noexcept
419cdef extern from 'cuda_runtime_api.h' nogil:
420 cudaError_t _static_cudaArrayGetSparseProperties "cudaArrayGetSparseProperties" (cudaArraySparseProperties* sparseProperties, cudaArray_t array) noexcept
422cdef extern from 'cuda_runtime_api.h' nogil:
423 cudaError_t _static_cudaMipmappedArrayGetSparseProperties "cudaMipmappedArrayGetSparseProperties" (cudaArraySparseProperties* sparseProperties, cudaMipmappedArray_t mipmap) noexcept
425cdef extern from 'cuda_runtime_api.h' nogil:
426 cudaError_t _static_cudaMemcpy "cudaMemcpy" (void* dst, const void* src, size_t count, cudaMemcpyKind kind) noexcept
428cdef extern from 'cuda_runtime_api.h' nogil:
429 cudaError_t _static_cudaMemcpyPeer "cudaMemcpyPeer" (void* dst, int dstDevice, const void* src, int srcDevice, size_t count) noexcept
431cdef extern from 'cuda_runtime_api.h' nogil:
432 cudaError_t _static_cudaMemcpy2D "cudaMemcpy2D" (void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind) noexcept
434cdef extern from 'cuda_runtime_api.h' nogil:
435 cudaError_t _static_cudaMemcpy2DToArray "cudaMemcpy2DToArray" (cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind) noexcept
437cdef extern from 'cuda_runtime_api.h' nogil:
438 cudaError_t _static_cudaMemcpy2DFromArray "cudaMemcpy2DFromArray" (void* dst, size_t dpitch, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t width, size_t height, cudaMemcpyKind kind) noexcept
440cdef extern from 'cuda_runtime_api.h' nogil:
441 cudaError_t _static_cudaMemcpy2DArrayToArray "cudaMemcpy2DArrayToArray" (cudaArray_t dst, size_t wOffsetDst, size_t hOffsetDst, cudaArray_const_t src, size_t wOffsetSrc, size_t hOffsetSrc, size_t width, size_t height, cudaMemcpyKind kind) noexcept
443cdef extern from 'cuda_runtime_api.h' nogil:
444 cudaError_t _static_cudaMemcpyAsync "cudaMemcpyAsync" (void* dst, const void* src, size_t count, cudaMemcpyKind kind, cudaStream_t stream) noexcept
446cdef extern from 'cuda_runtime_api.h' nogil:
447 cudaError_t _static_cudaMemcpyPeerAsync "cudaMemcpyPeerAsync" (void* dst, int dstDevice, const void* src, int srcDevice, size_t count, cudaStream_t stream) noexcept
449cdef extern from 'cuda_runtime_api.h' nogil:
450 cudaError_t _static_cudaMemcpyBatchAsync "cudaMemcpyBatchAsync" (void** dsts, const void** srcs, const size_t* sizes, size_t count, cudaMemcpyAttributes* attrs, size_t* attrsIdxs, size_t numAttrs, cudaStream_t stream) noexcept
452cdef extern from 'cuda_runtime_api.h' nogil:
453 cudaError_t _static_cudaMemcpy3DBatchAsync "cudaMemcpy3DBatchAsync" (size_t numOps, cudaMemcpy3DBatchOp* opList, unsigned long long flags, cudaStream_t stream) noexcept
455cdef extern from 'cuda_runtime_api.h' nogil:
456 cudaError_t _static_cudaMemcpy2DAsync "cudaMemcpy2DAsync" (void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) noexcept
458cdef extern from 'cuda_runtime_api.h' nogil:
459 cudaError_t _static_cudaMemcpy2DToArrayAsync "cudaMemcpy2DToArrayAsync" (cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) noexcept
461cdef extern from 'cuda_runtime_api.h' nogil:
462 cudaError_t _static_cudaMemcpy2DFromArrayAsync "cudaMemcpy2DFromArrayAsync" (void* dst, size_t dpitch, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) noexcept
464cdef extern from 'cuda_runtime_api.h' nogil:
465 cudaError_t _static_cudaMemset "cudaMemset" (void* devPtr, int value, size_t count) noexcept
467cdef extern from 'cuda_runtime_api.h' nogil:
468 cudaError_t _static_cudaMemset2D "cudaMemset2D" (void* devPtr, size_t pitch, int value, size_t width, size_t height) noexcept
470cdef extern from 'cuda_runtime_api.h' nogil:
471 cudaError_t _static_cudaMemset3D "cudaMemset3D" (cudaPitchedPtr pitchedDevPtr, int value, cudaExtent extent) noexcept
473cdef extern from 'cuda_runtime_api.h' nogil:
474 cudaError_t _static_cudaMemsetAsync "cudaMemsetAsync" (void* devPtr, int value, size_t count, cudaStream_t stream) noexcept
476cdef extern from 'cuda_runtime_api.h' nogil:
477 cudaError_t _static_cudaMemset2DAsync "cudaMemset2DAsync" (void* devPtr, size_t pitch, int value, size_t width, size_t height, cudaStream_t stream) noexcept
479cdef extern from 'cuda_runtime_api.h' nogil:
480 cudaError_t _static_cudaMemset3DAsync "cudaMemset3DAsync" (cudaPitchedPtr pitchedDevPtr, int value, cudaExtent extent, cudaStream_t stream) noexcept
482cdef extern from 'cuda_runtime_api.h' nogil:
483 cudaError_t _static_cudaMemPrefetchAsync "cudaMemPrefetchAsync" (const void* devPtr, size_t count, cudaMemLocation location, unsigned int flags, cudaStream_t stream) noexcept
485cdef extern from 'cuda_runtime_api.h' nogil:
486 cudaError_t _static_cudaMemAdvise "cudaMemAdvise" (const void* devPtr, size_t count, cudaMemoryAdvise advice, cudaMemLocation location) noexcept
488cdef extern from 'cuda_runtime_api.h' nogil:
489 cudaError_t _static_cudaMemRangeGetAttribute "cudaMemRangeGetAttribute" (void* data, size_t dataSize, cudaMemRangeAttribute attribute, const void* devPtr, size_t count) noexcept
491cdef extern from 'cuda_runtime_api.h' nogil:
492 cudaError_t _static_cudaMemRangeGetAttributes "cudaMemRangeGetAttributes" (void** data, size_t* dataSizes, cudaMemRangeAttribute* attributes, size_t numAttributes, const void* devPtr, size_t count) noexcept
494cdef extern from 'cuda_runtime_api.h' nogil:
495 cudaError_t _static_cudaMemcpyToArray "cudaMemcpyToArray" (cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t count, cudaMemcpyKind kind) noexcept
497cdef extern from 'cuda_runtime_api.h' nogil:
498 cudaError_t _static_cudaMemcpyFromArray "cudaMemcpyFromArray" (void* dst, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t count, cudaMemcpyKind kind) noexcept
500cdef extern from 'cuda_runtime_api.h' nogil:
501 cudaError_t _static_cudaMemcpyArrayToArray "cudaMemcpyArrayToArray" (cudaArray_t dst, size_t wOffsetDst, size_t hOffsetDst, cudaArray_const_t src, size_t wOffsetSrc, size_t hOffsetSrc, size_t count, cudaMemcpyKind kind) noexcept
503cdef extern from 'cuda_runtime_api.h' nogil:
504 cudaError_t _static_cudaMemcpyToArrayAsync "cudaMemcpyToArrayAsync" (cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t count, cudaMemcpyKind kind, cudaStream_t stream) noexcept
506cdef extern from 'cuda_runtime_api.h' nogil:
507 cudaError_t _static_cudaMemcpyFromArrayAsync "cudaMemcpyFromArrayAsync" (void* dst, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t count, cudaMemcpyKind kind, cudaStream_t stream) noexcept
509cdef extern from 'cuda_runtime_api.h' nogil:
510 cudaError_t _static_cudaMallocAsync "cudaMallocAsync" (void** devPtr, size_t size, cudaStream_t hStream) noexcept
512cdef extern from 'cuda_runtime_api.h' nogil:
513 cudaError_t _static_cudaFreeAsync "cudaFreeAsync" (void* devPtr, cudaStream_t hStream) noexcept
515cdef extern from 'cuda_runtime_api.h' nogil:
516 cudaError_t _static_cudaMemPoolTrimTo "cudaMemPoolTrimTo" (cudaMemPool_t memPool, size_t minBytesToKeep) noexcept
518cdef extern from 'cuda_runtime_api.h' nogil:
519 cudaError_t _static_cudaMemPoolSetAttribute "cudaMemPoolSetAttribute" (cudaMemPool_t memPool, cudaMemPoolAttr attr, void* value) noexcept
521cdef extern from 'cuda_runtime_api.h' nogil:
522 cudaError_t _static_cudaMemPoolGetAttribute "cudaMemPoolGetAttribute" (cudaMemPool_t memPool, cudaMemPoolAttr attr, void* value) noexcept
524cdef extern from 'cuda_runtime_api.h' nogil:
525 cudaError_t _static_cudaMemPoolSetAccess "cudaMemPoolSetAccess" (cudaMemPool_t memPool, const cudaMemAccessDesc* descList, size_t count) noexcept
527cdef extern from 'cuda_runtime_api.h' nogil:
528 cudaError_t _static_cudaMemPoolGetAccess "cudaMemPoolGetAccess" (cudaMemAccessFlags* flags, cudaMemPool_t memPool, cudaMemLocation* location) noexcept
530cdef extern from 'cuda_runtime_api.h' nogil:
531 cudaError_t _static_cudaMemPoolCreate "cudaMemPoolCreate" (cudaMemPool_t* memPool, const cudaMemPoolProps* poolProps) noexcept
533cdef extern from 'cuda_runtime_api.h' nogil:
534 cudaError_t _static_cudaMemPoolDestroy "cudaMemPoolDestroy" (cudaMemPool_t memPool) noexcept
536cdef extern from 'cuda_runtime_api.h' nogil:
537 cudaError_t _static_cudaMallocFromPoolAsync "cudaMallocFromPoolAsync" (void** ptr, size_t size, cudaMemPool_t memPool, cudaStream_t stream) noexcept
539cdef extern from 'cuda_runtime_api.h' nogil:
540 cudaError_t _static_cudaMemPoolExportToShareableHandle "cudaMemPoolExportToShareableHandle" (void* shareableHandle, cudaMemPool_t memPool, cudaMemAllocationHandleType handleType, unsigned int flags) noexcept
542cdef extern from 'cuda_runtime_api.h' nogil:
543 cudaError_t _static_cudaMemPoolImportFromShareableHandle "cudaMemPoolImportFromShareableHandle" (cudaMemPool_t* memPool, void* shareableHandle, cudaMemAllocationHandleType handleType, unsigned int flags) noexcept
545cdef extern from 'cuda_runtime_api.h' nogil:
546 cudaError_t _static_cudaMemPoolExportPointer "cudaMemPoolExportPointer" (cudaMemPoolPtrExportData* exportData, void* ptr) noexcept
548cdef extern from 'cuda_runtime_api.h' nogil:
549 cudaError_t _static_cudaMemPoolImportPointer "cudaMemPoolImportPointer" (void** ptr, cudaMemPool_t memPool, cudaMemPoolPtrExportData* exportData) noexcept
551cdef extern from 'cuda_runtime_api.h' nogil:
552 cudaError_t _static_cudaPointerGetAttributes "cudaPointerGetAttributes" (cudaPointerAttributes* attributes, const void* ptr) noexcept
554cdef extern from 'cuda_runtime_api.h' nogil:
555 cudaError_t _static_cudaDeviceCanAccessPeer "cudaDeviceCanAccessPeer" (int* canAccessPeer, int device, int peerDevice) noexcept
557cdef extern from 'cuda_runtime_api.h' nogil:
558 cudaError_t _static_cudaDeviceEnablePeerAccess "cudaDeviceEnablePeerAccess" (int peerDevice, unsigned int flags) noexcept
560cdef extern from 'cuda_runtime_api.h' nogil:
561 cudaError_t _static_cudaDeviceDisablePeerAccess "cudaDeviceDisablePeerAccess" (int peerDevice) noexcept
563cdef extern from 'cuda_runtime_api.h' nogil:
564 cudaError_t _static_cudaGraphicsUnregisterResource "cudaGraphicsUnregisterResource" (cudaGraphicsResource_t resource) noexcept
566cdef extern from 'cuda_runtime_api.h' nogil:
567 cudaError_t _static_cudaGraphicsResourceSetMapFlags "cudaGraphicsResourceSetMapFlags" (cudaGraphicsResource_t resource, unsigned int flags) noexcept
569cdef extern from 'cuda_runtime_api.h' nogil:
570 cudaError_t _static_cudaGraphicsMapResources "cudaGraphicsMapResources" (int count, cudaGraphicsResource_t* resources, cudaStream_t stream) noexcept
572cdef extern from 'cuda_runtime_api.h' nogil:
573 cudaError_t _static_cudaGraphicsUnmapResources "cudaGraphicsUnmapResources" (int count, cudaGraphicsResource_t* resources, cudaStream_t stream) noexcept
575cdef extern from 'cuda_runtime_api.h' nogil:
576 cudaError_t _static_cudaGraphicsResourceGetMappedPointer "cudaGraphicsResourceGetMappedPointer" (void** devPtr, size_t* size, cudaGraphicsResource_t resource) noexcept
578cdef extern from 'cuda_runtime_api.h' nogil:
579 cudaError_t _static_cudaGraphicsSubResourceGetMappedArray "cudaGraphicsSubResourceGetMappedArray" (cudaArray_t* array, cudaGraphicsResource_t resource, unsigned int arrayIndex, unsigned int mipLevel) noexcept
581cdef extern from 'cuda_runtime_api.h' nogil:
582 cudaError_t _static_cudaGraphicsResourceGetMappedMipmappedArray "cudaGraphicsResourceGetMappedMipmappedArray" (cudaMipmappedArray_t* mipmappedArray, cudaGraphicsResource_t resource) noexcept
584cdef extern from 'cuda_runtime_api.h' nogil:
585 cudaError_t _static_cudaGetChannelDesc "cudaGetChannelDesc" (cudaChannelFormatDesc* desc, cudaArray_const_t array) noexcept
587cdef extern from 'cuda_runtime_api.h' nogil:
588 cudaChannelFormatDesc _static_cudaCreateChannelDesc "cudaCreateChannelDesc" (int x, int y, int z, int w, cudaChannelFormatKind f) noexcept
590cdef extern from 'cuda_runtime_api.h' nogil:
591 cudaError_t _static_cudaCreateTextureObject "cudaCreateTextureObject" (cudaTextureObject_t* pTexObject, const cudaResourceDesc* pResDesc, const cudaTextureDesc* pTexDesc, const cudaResourceViewDesc* pResViewDesc) noexcept
593cdef extern from 'cuda_runtime_api.h' nogil:
594 cudaError_t _static_cudaDestroyTextureObject "cudaDestroyTextureObject" (cudaTextureObject_t texObject) noexcept
596cdef extern from 'cuda_runtime_api.h' nogil:
597 cudaError_t _static_cudaGetTextureObjectResourceDesc "cudaGetTextureObjectResourceDesc" (cudaResourceDesc* pResDesc, cudaTextureObject_t texObject) noexcept
599cdef extern from 'cuda_runtime_api.h' nogil:
600 cudaError_t _static_cudaGetTextureObjectTextureDesc "cudaGetTextureObjectTextureDesc" (cudaTextureDesc* pTexDesc, cudaTextureObject_t texObject) noexcept
602cdef extern from 'cuda_runtime_api.h' nogil:
603 cudaError_t _static_cudaGetTextureObjectResourceViewDesc "cudaGetTextureObjectResourceViewDesc" (cudaResourceViewDesc* pResViewDesc, cudaTextureObject_t texObject) noexcept
605cdef extern from 'cuda_runtime_api.h' nogil:
606 cudaError_t _static_cudaCreateSurfaceObject "cudaCreateSurfaceObject" (cudaSurfaceObject_t* pSurfObject, const cudaResourceDesc* pResDesc) noexcept
608cdef extern from 'cuda_runtime_api.h' nogil:
609 cudaError_t _static_cudaDestroySurfaceObject "cudaDestroySurfaceObject" (cudaSurfaceObject_t surfObject) noexcept
611cdef extern from 'cuda_runtime_api.h' nogil:
612 cudaError_t _static_cudaGetSurfaceObjectResourceDesc "cudaGetSurfaceObjectResourceDesc" (cudaResourceDesc* pResDesc, cudaSurfaceObject_t surfObject) noexcept
614cdef extern from 'cuda_runtime_api.h' nogil:
615 cudaError_t _static_cudaDriverGetVersion "cudaDriverGetVersion" (int* driverVersion) noexcept
617cdef extern from 'cuda_runtime_api.h' nogil:
618 cudaError_t _static_cudaRuntimeGetVersion "cudaRuntimeGetVersion" (int* runtimeVersion) noexcept
620cdef extern from 'cuda_runtime_api.h' nogil:
621 cudaError_t _static_cudaGraphCreate "cudaGraphCreate" (cudaGraph_t* pGraph, unsigned int flags) noexcept
623cdef extern from 'cuda_runtime_api.h' nogil:
624 cudaError_t _static_cudaGraphAddKernelNode "cudaGraphAddKernelNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaKernelNodeParams* pNodeParams) noexcept
626cdef extern from 'cuda_runtime_api.h' nogil:
627 cudaError_t _static_cudaGraphKernelNodeGetParams "cudaGraphKernelNodeGetParams" (cudaGraphNode_t node, cudaKernelNodeParams* pNodeParams) noexcept
629cdef extern from 'cuda_runtime_api.h' nogil:
630 cudaError_t _static_cudaGraphKernelNodeSetParams "cudaGraphKernelNodeSetParams" (cudaGraphNode_t node, const cudaKernelNodeParams* pNodeParams) noexcept
632cdef extern from 'cuda_runtime_api.h' nogil:
633 cudaError_t _static_cudaGraphKernelNodeCopyAttributes "cudaGraphKernelNodeCopyAttributes" (cudaGraphNode_t hDst, cudaGraphNode_t hSrc) noexcept
635cdef extern from 'cuda_runtime_api.h' nogil:
636 cudaError_t _static_cudaGraphKernelNodeGetAttribute "cudaGraphKernelNodeGetAttribute" (cudaGraphNode_t hNode, cudaLaunchAttributeID attr, cudaLaunchAttributeValue* value_out) noexcept
638cdef extern from 'cuda_runtime_api.h' nogil:
639 cudaError_t _static_cudaGraphKernelNodeSetAttribute "cudaGraphKernelNodeSetAttribute" (cudaGraphNode_t hNode, cudaLaunchAttributeID attr, const cudaLaunchAttributeValue* value) noexcept
641cdef extern from 'cuda_runtime_api.h' nogil:
642 cudaError_t _static_cudaGraphAddMemcpyNode "cudaGraphAddMemcpyNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaMemcpy3DParms* pCopyParams) noexcept
644cdef extern from 'cuda_runtime_api.h' nogil:
645 cudaError_t _static_cudaGraphAddMemcpyNode1D "cudaGraphAddMemcpyNode1D" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, void* dst, const void* src, size_t count, cudaMemcpyKind kind) noexcept
647cdef extern from 'cuda_runtime_api.h' nogil:
648 cudaError_t _static_cudaGraphMemcpyNodeGetParams "cudaGraphMemcpyNodeGetParams" (cudaGraphNode_t node, cudaMemcpy3DParms* pNodeParams) noexcept
650cdef extern from 'cuda_runtime_api.h' nogil:
651 cudaError_t _static_cudaGraphMemcpyNodeSetParams "cudaGraphMemcpyNodeSetParams" (cudaGraphNode_t node, const cudaMemcpy3DParms* pNodeParams) noexcept
653cdef extern from 'cuda_runtime_api.h' nogil:
654 cudaError_t _static_cudaGraphMemcpyNodeSetParams1D "cudaGraphMemcpyNodeSetParams1D" (cudaGraphNode_t node, void* dst, const void* src, size_t count, cudaMemcpyKind kind) noexcept
656cdef extern from 'cuda_runtime_api.h' nogil:
657 cudaError_t _static_cudaGraphAddMemsetNode "cudaGraphAddMemsetNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaMemsetParams* pMemsetParams) noexcept
659cdef extern from 'cuda_runtime_api.h' nogil:
660 cudaError_t _static_cudaGraphMemsetNodeGetParams "cudaGraphMemsetNodeGetParams" (cudaGraphNode_t node, cudaMemsetParams* pNodeParams) noexcept
662cdef extern from 'cuda_runtime_api.h' nogil:
663 cudaError_t _static_cudaGraphMemsetNodeSetParams "cudaGraphMemsetNodeSetParams" (cudaGraphNode_t node, const cudaMemsetParams* pNodeParams) noexcept
665cdef extern from 'cuda_runtime_api.h' nogil:
666 cudaError_t _static_cudaGraphAddHostNode "cudaGraphAddHostNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaHostNodeParams* pNodeParams) noexcept
668cdef extern from 'cuda_runtime_api.h' nogil:
669 cudaError_t _static_cudaGraphHostNodeGetParams "cudaGraphHostNodeGetParams" (cudaGraphNode_t node, cudaHostNodeParams* pNodeParams) noexcept
671cdef extern from 'cuda_runtime_api.h' nogil:
672 cudaError_t _static_cudaGraphHostNodeSetParams "cudaGraphHostNodeSetParams" (cudaGraphNode_t node, const cudaHostNodeParams* pNodeParams) noexcept
674cdef extern from 'cuda_runtime_api.h' nogil:
675 cudaError_t _static_cudaGraphAddChildGraphNode "cudaGraphAddChildGraphNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaGraph_t childGraph) noexcept
677cdef extern from 'cuda_runtime_api.h' nogil:
678 cudaError_t _static_cudaGraphChildGraphNodeGetGraph "cudaGraphChildGraphNodeGetGraph" (cudaGraphNode_t node, cudaGraph_t* pGraph) noexcept
680cdef extern from 'cuda_runtime_api.h' nogil:
681 cudaError_t _static_cudaGraphAddEmptyNode "cudaGraphAddEmptyNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies) noexcept
683cdef extern from 'cuda_runtime_api.h' nogil:
684 cudaError_t _static_cudaGraphAddEventRecordNode "cudaGraphAddEventRecordNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaEvent_t event) noexcept
686cdef extern from 'cuda_runtime_api.h' nogil:
687 cudaError_t _static_cudaGraphEventRecordNodeGetEvent "cudaGraphEventRecordNodeGetEvent" (cudaGraphNode_t node, cudaEvent_t* event_out) noexcept
689cdef extern from 'cuda_runtime_api.h' nogil:
690 cudaError_t _static_cudaGraphEventRecordNodeSetEvent "cudaGraphEventRecordNodeSetEvent" (cudaGraphNode_t node, cudaEvent_t event) noexcept
692cdef extern from 'cuda_runtime_api.h' nogil:
693 cudaError_t _static_cudaGraphAddEventWaitNode "cudaGraphAddEventWaitNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaEvent_t event) noexcept
695cdef extern from 'cuda_runtime_api.h' nogil:
696 cudaError_t _static_cudaGraphEventWaitNodeGetEvent "cudaGraphEventWaitNodeGetEvent" (cudaGraphNode_t node, cudaEvent_t* event_out) noexcept
698cdef extern from 'cuda_runtime_api.h' nogil:
699 cudaError_t _static_cudaGraphEventWaitNodeSetEvent "cudaGraphEventWaitNodeSetEvent" (cudaGraphNode_t node, cudaEvent_t event) noexcept
701cdef extern from 'cuda_runtime_api.h' nogil:
702 cudaError_t _static_cudaGraphAddExternalSemaphoresSignalNode "cudaGraphAddExternalSemaphoresSignalNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaExternalSemaphoreSignalNodeParams* nodeParams) noexcept
704cdef extern from 'cuda_runtime_api.h' nogil:
705 cudaError_t _static_cudaGraphExternalSemaphoresSignalNodeGetParams "cudaGraphExternalSemaphoresSignalNodeGetParams" (cudaGraphNode_t hNode, cudaExternalSemaphoreSignalNodeParams* params_out) noexcept
707cdef extern from 'cuda_runtime_api.h' nogil:
708 cudaError_t _static_cudaGraphExternalSemaphoresSignalNodeSetParams "cudaGraphExternalSemaphoresSignalNodeSetParams" (cudaGraphNode_t hNode, const cudaExternalSemaphoreSignalNodeParams* nodeParams) noexcept
710cdef extern from 'cuda_runtime_api.h' nogil:
711 cudaError_t _static_cudaGraphAddExternalSemaphoresWaitNode "cudaGraphAddExternalSemaphoresWaitNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaExternalSemaphoreWaitNodeParams* nodeParams) noexcept
713cdef extern from 'cuda_runtime_api.h' nogil:
714 cudaError_t _static_cudaGraphExternalSemaphoresWaitNodeGetParams "cudaGraphExternalSemaphoresWaitNodeGetParams" (cudaGraphNode_t hNode, cudaExternalSemaphoreWaitNodeParams* params_out) noexcept
716cdef extern from 'cuda_runtime_api.h' nogil:
717 cudaError_t _static_cudaGraphExternalSemaphoresWaitNodeSetParams "cudaGraphExternalSemaphoresWaitNodeSetParams" (cudaGraphNode_t hNode, const cudaExternalSemaphoreWaitNodeParams* nodeParams) noexcept
719cdef extern from 'cuda_runtime_api.h' nogil:
720 cudaError_t _static_cudaGraphAddMemAllocNode "cudaGraphAddMemAllocNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaMemAllocNodeParams* nodeParams) noexcept
722cdef extern from 'cuda_runtime_api.h' nogil:
723 cudaError_t _static_cudaGraphMemAllocNodeGetParams "cudaGraphMemAllocNodeGetParams" (cudaGraphNode_t node, cudaMemAllocNodeParams* params_out) noexcept
725cdef extern from 'cuda_runtime_api.h' nogil:
726 cudaError_t _static_cudaGraphAddMemFreeNode "cudaGraphAddMemFreeNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, void* dptr) noexcept
728cdef extern from 'cuda_runtime_api.h' nogil:
729 cudaError_t _static_cudaGraphMemFreeNodeGetParams "cudaGraphMemFreeNodeGetParams" (cudaGraphNode_t node, void* dptr_out) noexcept
731cdef extern from 'cuda_runtime_api.h' nogil:
732 cudaError_t _static_cudaDeviceGraphMemTrim "cudaDeviceGraphMemTrim" (int device) noexcept
734cdef extern from 'cuda_runtime_api.h' nogil:
735 cudaError_t _static_cudaDeviceGetGraphMemAttribute "cudaDeviceGetGraphMemAttribute" (int device, cudaGraphMemAttributeType attr, void* value) noexcept
737cdef extern from 'cuda_runtime_api.h' nogil:
738 cudaError_t _static_cudaDeviceSetGraphMemAttribute "cudaDeviceSetGraphMemAttribute" (int device, cudaGraphMemAttributeType attr, void* value) noexcept
740cdef extern from 'cuda_runtime_api.h' nogil:
741 cudaError_t _static_cudaGraphClone "cudaGraphClone" (cudaGraph_t* pGraphClone, cudaGraph_t originalGraph) noexcept
743cdef extern from 'cuda_runtime_api.h' nogil:
744 cudaError_t _static_cudaGraphNodeFindInClone "cudaGraphNodeFindInClone" (cudaGraphNode_t* pNode, cudaGraphNode_t originalNode, cudaGraph_t clonedGraph) noexcept
746cdef extern from 'cuda_runtime_api.h' nogil:
747 cudaError_t _static_cudaGraphNodeGetType "cudaGraphNodeGetType" (cudaGraphNode_t node, cudaGraphNodeType* pType) noexcept
749cdef extern from 'cuda_runtime_api.h' nogil:
750 cudaError_t _static_cudaGraphGetNodes "cudaGraphGetNodes" (cudaGraph_t graph, cudaGraphNode_t* nodes, size_t* numNodes) noexcept
752cdef extern from 'cuda_runtime_api.h' nogil:
753 cudaError_t _static_cudaGraphGetRootNodes "cudaGraphGetRootNodes" (cudaGraph_t graph, cudaGraphNode_t* pRootNodes, size_t* pNumRootNodes) noexcept
755cdef extern from 'cuda_runtime_api.h' nogil:
756 cudaError_t _static_cudaGraphGetEdges "cudaGraphGetEdges" (cudaGraph_t graph, cudaGraphNode_t* from_, cudaGraphNode_t* to, cudaGraphEdgeData* edgeData, size_t* numEdges) noexcept
758cdef extern from 'cuda_runtime_api.h' nogil:
759 cudaError_t _static_cudaGraphNodeGetDependencies "cudaGraphNodeGetDependencies" (cudaGraphNode_t node, cudaGraphNode_t* pDependencies, cudaGraphEdgeData* edgeData, size_t* pNumDependencies) noexcept
761cdef extern from 'cuda_runtime_api.h' nogil:
762 cudaError_t _static_cudaGraphNodeGetDependentNodes "cudaGraphNodeGetDependentNodes" (cudaGraphNode_t node, cudaGraphNode_t* pDependentNodes, cudaGraphEdgeData* edgeData, size_t* pNumDependentNodes) noexcept
764cdef extern from 'cuda_runtime_api.h' nogil:
765 cudaError_t _static_cudaGraphAddDependencies "cudaGraphAddDependencies" (cudaGraph_t graph, const cudaGraphNode_t* from_, const cudaGraphNode_t* to, const cudaGraphEdgeData* edgeData, size_t numDependencies) noexcept
767cdef extern from 'cuda_runtime_api.h' nogil:
768 cudaError_t _static_cudaGraphRemoveDependencies "cudaGraphRemoveDependencies" (cudaGraph_t graph, const cudaGraphNode_t* from_, const cudaGraphNode_t* to, const cudaGraphEdgeData* edgeData, size_t numDependencies) noexcept
770cdef extern from 'cuda_runtime_api.h' nogil:
771 cudaError_t _static_cudaGraphDestroyNode "cudaGraphDestroyNode" (cudaGraphNode_t node) noexcept
773cdef extern from 'cuda_runtime_api.h' nogil:
774 cudaError_t _static_cudaGraphInstantiate "cudaGraphInstantiate" (cudaGraphExec_t* pGraphExec, cudaGraph_t graph, unsigned long long flags) noexcept
776cdef extern from 'cuda_runtime_api.h' nogil:
777 cudaError_t _static_cudaGraphInstantiateWithFlags "cudaGraphInstantiateWithFlags" (cudaGraphExec_t* pGraphExec, cudaGraph_t graph, unsigned long long flags) noexcept
779cdef extern from 'cuda_runtime_api.h' nogil:
780 cudaError_t _static_cudaGraphInstantiateWithParams "cudaGraphInstantiateWithParams" (cudaGraphExec_t* pGraphExec, cudaGraph_t graph, cudaGraphInstantiateParams* instantiateParams) noexcept
782cdef extern from 'cuda_runtime_api.h' nogil:
783 cudaError_t _static_cudaGraphExecGetFlags "cudaGraphExecGetFlags" (cudaGraphExec_t graphExec, unsigned long long* flags) noexcept
785cdef extern from 'cuda_runtime_api.h' nogil:
786 cudaError_t _static_cudaGraphExecKernelNodeSetParams "cudaGraphExecKernelNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaKernelNodeParams* pNodeParams) noexcept
788cdef extern from 'cuda_runtime_api.h' nogil:
789 cudaError_t _static_cudaGraphExecMemcpyNodeSetParams "cudaGraphExecMemcpyNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaMemcpy3DParms* pNodeParams) noexcept
791cdef extern from 'cuda_runtime_api.h' nogil:
792 cudaError_t _static_cudaGraphExecMemcpyNodeSetParams1D "cudaGraphExecMemcpyNodeSetParams1D" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, void* dst, const void* src, size_t count, cudaMemcpyKind kind) noexcept
794cdef extern from 'cuda_runtime_api.h' nogil:
795 cudaError_t _static_cudaGraphExecMemsetNodeSetParams "cudaGraphExecMemsetNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaMemsetParams* pNodeParams) noexcept
797cdef extern from 'cuda_runtime_api.h' nogil:
798 cudaError_t _static_cudaGraphExecHostNodeSetParams "cudaGraphExecHostNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaHostNodeParams* pNodeParams) noexcept
800cdef extern from 'cuda_runtime_api.h' nogil:
801 cudaError_t _static_cudaGraphExecChildGraphNodeSetParams "cudaGraphExecChildGraphNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t node, cudaGraph_t childGraph) noexcept
803cdef extern from 'cuda_runtime_api.h' nogil:
804 cudaError_t _static_cudaGraphExecEventRecordNodeSetEvent "cudaGraphExecEventRecordNodeSetEvent" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, cudaEvent_t event) noexcept
806cdef extern from 'cuda_runtime_api.h' nogil:
807 cudaError_t _static_cudaGraphExecEventWaitNodeSetEvent "cudaGraphExecEventWaitNodeSetEvent" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, cudaEvent_t event) noexcept
809cdef extern from 'cuda_runtime_api.h' nogil:
810 cudaError_t _static_cudaGraphExecExternalSemaphoresSignalNodeSetParams "cudaGraphExecExternalSemaphoresSignalNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, const cudaExternalSemaphoreSignalNodeParams* nodeParams) noexcept
812cdef extern from 'cuda_runtime_api.h' nogil:
813 cudaError_t _static_cudaGraphExecExternalSemaphoresWaitNodeSetParams "cudaGraphExecExternalSemaphoresWaitNodeSetParams" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, const cudaExternalSemaphoreWaitNodeParams* nodeParams) noexcept
815cdef extern from 'cuda_runtime_api.h' nogil:
816 cudaError_t _static_cudaGraphNodeSetEnabled "cudaGraphNodeSetEnabled" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, unsigned int isEnabled) noexcept
818cdef extern from 'cuda_runtime_api.h' nogil:
819 cudaError_t _static_cudaGraphNodeGetEnabled "cudaGraphNodeGetEnabled" (cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, unsigned int* isEnabled) noexcept
821cdef extern from 'cuda_runtime_api.h' nogil:
822 cudaError_t _static_cudaGraphExecUpdate "cudaGraphExecUpdate" (cudaGraphExec_t hGraphExec, cudaGraph_t hGraph, cudaGraphExecUpdateResultInfo* resultInfo) noexcept
824cdef extern from 'cuda_runtime_api.h' nogil:
825 cudaError_t _static_cudaGraphUpload "cudaGraphUpload" (cudaGraphExec_t graphExec, cudaStream_t stream) noexcept
827cdef extern from 'cuda_runtime_api.h' nogil:
828 cudaError_t _static_cudaGraphLaunch "cudaGraphLaunch" (cudaGraphExec_t graphExec, cudaStream_t stream) noexcept
830cdef extern from 'cuda_runtime_api.h' nogil:
831 cudaError_t _static_cudaGraphExecDestroy "cudaGraphExecDestroy" (cudaGraphExec_t graphExec) noexcept
833cdef extern from 'cuda_runtime_api.h' nogil:
834 cudaError_t _static_cudaGraphDestroy "cudaGraphDestroy" (cudaGraph_t graph) noexcept
836cdef extern from 'cuda_runtime_api.h' nogil:
837 cudaError_t _static_cudaGraphDebugDotPrint "cudaGraphDebugDotPrint" (cudaGraph_t graph, const char* path, unsigned int flags) noexcept
839cdef extern from 'cuda_runtime_api.h' nogil:
840 cudaError_t _static_cudaUserObjectCreate "cudaUserObjectCreate" (cudaUserObject_t* object_out, void* ptr, cudaHostFn_t destroy, unsigned int initialRefcount, unsigned int flags) noexcept
842cdef extern from 'cuda_runtime_api.h' nogil:
843 cudaError_t _static_cudaUserObjectRetain "cudaUserObjectRetain" (cudaUserObject_t object, unsigned int count) noexcept
845cdef extern from 'cuda_runtime_api.h' nogil:
846 cudaError_t _static_cudaUserObjectRelease "cudaUserObjectRelease" (cudaUserObject_t object, unsigned int count) noexcept
848cdef extern from 'cuda_runtime_api.h' nogil:
849 cudaError_t _static_cudaGraphRetainUserObject "cudaGraphRetainUserObject" (cudaGraph_t graph, cudaUserObject_t object, unsigned int count, unsigned int flags) noexcept
851cdef extern from 'cuda_runtime_api.h' nogil:
852 cudaError_t _static_cudaGraphReleaseUserObject "cudaGraphReleaseUserObject" (cudaGraph_t graph, cudaUserObject_t object, unsigned int count) noexcept
854cdef extern from 'cuda_runtime_api.h' nogil:
855 cudaError_t _static_cudaGraphAddNode "cudaGraphAddNode" (cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, cudaGraphNodeParams* nodeParams) noexcept
857cdef extern from 'cuda_runtime_api.h' nogil:
858 cudaError_t _static_cudaGraphNodeSetParams "cudaGraphNodeSetParams" (cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) noexcept
860cdef extern from 'cuda_runtime_api.h' nogil:
861 cudaError_t _static_cudaGraphExecNodeSetParams "cudaGraphExecNodeSetParams" (cudaGraphExec_t graphExec, cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) noexcept
863cdef extern from 'cuda_runtime_api.h' nogil:
864 cudaError_t _static_cudaGraphConditionalHandleCreate "cudaGraphConditionalHandleCreate" (cudaGraphConditionalHandle* pHandle_out, cudaGraph_t graph, unsigned int defaultLaunchValue, unsigned int flags) noexcept
866cdef extern from 'cuda_runtime_api.h' nogil:
867 cudaError_t _static_cudaGetDriverEntryPoint "cudaGetDriverEntryPoint" (const char* symbol, void** funcPtr, unsigned long long flags, cudaDriverEntryPointQueryResult* driverStatus) noexcept
869cdef extern from 'cuda_runtime_api.h' nogil:
870 cudaError_t _static_cudaGetDriverEntryPointByVersion "cudaGetDriverEntryPointByVersion" (const char* symbol, void** funcPtr, unsigned int cudaVersion, unsigned long long flags, cudaDriverEntryPointQueryResult* driverStatus) noexcept
872cdef extern from 'cuda_runtime_api.h' nogil:
873 cudaError_t _static_cudaLibraryLoadData "cudaLibraryLoadData" (cudaLibrary_t* library, const void* code, cudaJitOption* jitOptions, void** jitOptionsValues, unsigned int numJitOptions, cudaLibraryOption* libraryOptions, void** libraryOptionValues, unsigned int numLibraryOptions) noexcept
875cdef extern from 'cuda_runtime_api.h' nogil:
876 cudaError_t _static_cudaLibraryLoadFromFile "cudaLibraryLoadFromFile" (cudaLibrary_t* library, const char* fileName, cudaJitOption* jitOptions, void** jitOptionsValues, unsigned int numJitOptions, cudaLibraryOption* libraryOptions, void** libraryOptionValues, unsigned int numLibraryOptions) noexcept
878cdef extern from 'cuda_runtime_api.h' nogil:
879 cudaError_t _static_cudaLibraryUnload "cudaLibraryUnload" (cudaLibrary_t library) noexcept
881cdef extern from 'cuda_runtime_api.h' nogil:
882 cudaError_t _static_cudaLibraryGetKernel "cudaLibraryGetKernel" (cudaKernel_t* pKernel, cudaLibrary_t library, const char* name) noexcept
884cdef extern from 'cuda_runtime_api.h' nogil:
885 cudaError_t _static_cudaLibraryGetGlobal "cudaLibraryGetGlobal" (void** dptr, size_t* bytes, cudaLibrary_t library, const char* name) noexcept
887cdef extern from 'cuda_runtime_api.h' nogil:
888 cudaError_t _static_cudaLibraryGetManaged "cudaLibraryGetManaged" (void** dptr, size_t* bytes, cudaLibrary_t library, const char* name) noexcept
890cdef extern from 'cuda_runtime_api.h' nogil:
891 cudaError_t _static_cudaLibraryGetUnifiedFunction "cudaLibraryGetUnifiedFunction" (void** fptr, cudaLibrary_t library, const char* symbol) noexcept
893cdef extern from 'cuda_runtime_api.h' nogil:
894 cudaError_t _static_cudaLibraryGetKernelCount "cudaLibraryGetKernelCount" (unsigned int* count, cudaLibrary_t lib) noexcept
896cdef extern from 'cuda_runtime_api.h' nogil:
897 cudaError_t _static_cudaLibraryEnumerateKernels "cudaLibraryEnumerateKernels" (cudaKernel_t* kernels, unsigned int numKernels, cudaLibrary_t lib) noexcept
899cdef extern from 'cuda_runtime_api.h' nogil:
900 cudaError_t _static_cudaKernelSetAttributeForDevice "cudaKernelSetAttributeForDevice" (cudaKernel_t kernel, cudaFuncAttribute attr, int value, int device) noexcept
902cdef extern from 'cuda_runtime_api.h' nogil:
903 cudaError_t _static_cudaGetExportTable "cudaGetExportTable" (const void** ppExportTable, const cudaUUID_t* pExportTableId) noexcept
905cdef extern from 'cuda_runtime_api.h' nogil:
906 cudaError_t _static_cudaGetKernel "cudaGetKernel" (cudaKernel_t* kernelPtr, const void* entryFuncAddr) noexcept
908cdef extern from 'cuda_profiler_api.h' nogil:
909 cudaError_t _static_cudaProfilerStart "cudaProfilerStart" () noexcept
911cdef extern from 'cuda_profiler_api.h' nogil:
912 cudaError_t _static_cudaProfilerStop "cudaProfilerStop" () noexcept
914cdef extern from 'cuda_runtime_api.h' nogil:
915 cudaError_t _static_cudaGetDeviceProperties "cudaGetDeviceProperties" (cudaDeviceProp* prop, int device) noexcept
917cdef extern from 'cuda_runtime_api.h' nogil:
918 cudaError_t _static_cudaDeviceGetHostAtomicCapabilities "cudaDeviceGetHostAtomicCapabilities" (unsigned int* capabilities, const cudaAtomicOperation* operations, unsigned int count, int device) noexcept
920cdef extern from 'cuda_runtime_api.h' nogil:
921 cudaError_t _static_cudaDeviceGetP2PAtomicCapabilities "cudaDeviceGetP2PAtomicCapabilities" (unsigned int* capabilities, const cudaAtomicOperation* operations, unsigned int count, int srcDevice, int dstDevice) noexcept
923cdef extern from 'cuda_runtime_api.h' nogil:
924 cudaError_t _static_cudaStreamGetCaptureInfo "cudaStreamGetCaptureInfo" (cudaStream_t stream, cudaStreamCaptureStatus* captureStatus_out, unsigned long long* id_out, cudaGraph_t* graph_out, const cudaGraphNode_t** dependencies_out, const cudaGraphEdgeData** edgeData_out, size_t* numDependencies_out) noexcept
926cdef extern from 'cuda_runtime_api.h' nogil:
927 cudaError_t _static_cudaSignalExternalSemaphoresAsync "cudaSignalExternalSemaphoresAsync" (const cudaExternalSemaphore_t* extSemArray, const cudaExternalSemaphoreSignalParams* paramsArray, unsigned int numExtSems, cudaStream_t stream) noexcept
929cdef extern from 'cuda_runtime_api.h' nogil:
930 cudaError_t _static_cudaWaitExternalSemaphoresAsync "cudaWaitExternalSemaphoresAsync" (const cudaExternalSemaphore_t* extSemArray, const cudaExternalSemaphoreWaitParams* paramsArray, unsigned int numExtSems, cudaStream_t stream) noexcept
932cdef extern from 'cuda_runtime_api.h' nogil:
933 cudaError_t _static_cudaMemPrefetchBatchAsync "cudaMemPrefetchBatchAsync" (void** dptrs, size_t* sizes, size_t count, cudaMemLocation* prefetchLocs, size_t* prefetchLocIdxs, size_t numPrefetchLocs, unsigned long long flags, cudaStream_t stream) noexcept
935cdef extern from 'cuda_runtime_api.h' nogil:
936 cudaError_t _static_cudaMemDiscardBatchAsync "cudaMemDiscardBatchAsync" (void** dptrs, size_t* sizes, size_t count, unsigned long long flags, cudaStream_t stream) noexcept
938cdef extern from 'cuda_runtime_api.h' nogil:
939 cudaError_t _static_cudaMemDiscardAndPrefetchBatchAsync "cudaMemDiscardAndPrefetchBatchAsync" (void** dptrs, size_t* sizes, size_t count, cudaMemLocation* prefetchLocs, size_t* prefetchLocIdxs, size_t numPrefetchLocs, unsigned long long flags, cudaStream_t stream) noexcept
941cdef extern from 'cuda_runtime_api.h' nogil:
942 cudaError_t _static_cudaMemGetDefaultMemPool "cudaMemGetDefaultMemPool" (cudaMemPool_t* memPool, cudaMemLocation* location, cudaMemAllocationType type) noexcept
944cdef extern from 'cuda_runtime_api.h' nogil:
945 cudaError_t _static_cudaMemGetMemPool "cudaMemGetMemPool" (cudaMemPool_t* memPool, cudaMemLocation* location, cudaMemAllocationType type) noexcept
947cdef extern from 'cuda_runtime_api.h' nogil:
948 cudaError_t _static_cudaMemSetMemPool "cudaMemSetMemPool" (cudaMemLocation* location, cudaMemAllocationType type, cudaMemPool_t memPool) noexcept
950cdef extern from 'cuda_runtime_api.h' nogil:
951 cudaError_t _static_cudaLogsRegisterCallback "cudaLogsRegisterCallback" (cudaLogsCallback_t callbackFunc, void* userData, cudaLogsCallbackHandle* callback_out) noexcept
953cdef extern from 'cuda_runtime_api.h' nogil:
954 cudaError_t _static_cudaLogsUnregisterCallback "cudaLogsUnregisterCallback" (cudaLogsCallbackHandle callback) noexcept
956cdef extern from 'cuda_runtime_api.h' nogil:
957 cudaError_t _static_cudaLogsCurrent "cudaLogsCurrent" (cudaLogIterator* iterator_out, unsigned int flags) noexcept
959cdef extern from 'cuda_runtime_api.h' nogil:
960 cudaError_t _static_cudaLogsDumpToFile "cudaLogsDumpToFile" (cudaLogIterator* iterator, const char* pathToFile, unsigned int flags) noexcept
962cdef extern from 'cuda_runtime_api.h' nogil:
963 cudaError_t _static_cudaLogsDumpToMemory "cudaLogsDumpToMemory" (cudaLogIterator* iterator, char* buffer, size_t* size, unsigned int flags) noexcept
965cdef extern from 'cuda_runtime_api.h' nogil:
966 cudaError_t _static_cudaGraphNodeGetContainingGraph "cudaGraphNodeGetContainingGraph" (cudaGraphNode_t hNode, cudaGraph_t* phGraph) noexcept
968cdef extern from 'cuda_runtime_api.h' nogil:
969 cudaError_t _static_cudaGraphNodeGetLocalId "cudaGraphNodeGetLocalId" (cudaGraphNode_t hNode, unsigned int* nodeId) noexcept
971cdef extern from 'cuda_runtime_api.h' nogil:
972 cudaError_t _static_cudaGraphNodeGetToolsId "cudaGraphNodeGetToolsId" (cudaGraphNode_t hNode, unsigned long long* toolsNodeId) noexcept
974cdef extern from 'cuda_runtime_api.h' nogil:
975 cudaError_t _static_cudaGraphGetId "cudaGraphGetId" (cudaGraph_t hGraph, unsigned int* graphID) noexcept
977cdef extern from 'cuda_runtime_api.h' nogil:
978 cudaError_t _static_cudaGraphExecGetId "cudaGraphExecGetId" (cudaGraphExec_t hGraphExec, unsigned int* graphID) noexcept
980cdef extern from 'cuda_runtime_api.h' nogil:
981 cudaError_t _static_cudaGraphConditionalHandleCreate_v2 "cudaGraphConditionalHandleCreate_v2" (cudaGraphConditionalHandle* pHandle_out, cudaGraph_t graph, cudaExecutionContext_t ctx, unsigned int defaultLaunchValue, unsigned int flags) noexcept
983cdef extern from 'cuda_runtime_api.h' nogil:
984 cudaError_t _static_cudaDeviceGetDevResource "cudaDeviceGetDevResource" (int device, cudaDevResource* resource, cudaDevResourceType type) noexcept
986cdef extern from 'cuda_runtime_api.h' nogil:
987 cudaError_t _static_cudaDevSmResourceSplitByCount "cudaDevSmResourceSplitByCount" (cudaDevResource* result, unsigned int* nbGroups, const cudaDevResource* input, cudaDevResource* remaining, unsigned int flags, unsigned int minCount) noexcept
989cdef extern from 'cuda_runtime_api.h' nogil:
990 cudaError_t _static_cudaDevSmResourceSplit "cudaDevSmResourceSplit" (cudaDevResource* result, unsigned int nbGroups, const cudaDevResource* input, cudaDevResource* remainder, unsigned int flags, cudaDevSmResourceGroupParams* groupParams) noexcept
992cdef extern from 'cuda_runtime_api.h' nogil:
993 cudaError_t _static_cudaDevResourceGenerateDesc "cudaDevResourceGenerateDesc" (cudaDevResourceDesc_t* phDesc, cudaDevResource* resources, unsigned int nbResources) noexcept
995cdef extern from 'cuda_runtime_api.h' nogil:
996 cudaError_t _static_cudaGreenCtxCreate "cudaGreenCtxCreate" (cudaExecutionContext_t* phCtx, cudaDevResourceDesc_t desc, int device, unsigned int flags) noexcept
998cdef extern from 'cuda_runtime_api.h' nogil:
999 cudaError_t _static_cudaExecutionCtxDestroy "cudaExecutionCtxDestroy" (cudaExecutionContext_t ctx) noexcept
1001cdef extern from 'cuda_runtime_api.h' nogil:
1002 cudaError_t _static_cudaExecutionCtxGetDevResource "cudaExecutionCtxGetDevResource" (cudaExecutionContext_t ctx, cudaDevResource* resource, cudaDevResourceType type) noexcept
1004cdef extern from 'cuda_runtime_api.h' nogil:
1005 cudaError_t _static_cudaExecutionCtxGetDevice "cudaExecutionCtxGetDevice" (int* device, cudaExecutionContext_t ctx) noexcept
1007cdef extern from 'cuda_runtime_api.h' nogil:
1008 cudaError_t _static_cudaExecutionCtxGetId "cudaExecutionCtxGetId" (cudaExecutionContext_t ctx, unsigned long long* ctxId) noexcept
1010cdef extern from 'cuda_runtime_api.h' nogil:
1011 cudaError_t _static_cudaExecutionCtxStreamCreate "cudaExecutionCtxStreamCreate" (cudaStream_t* phStream, cudaExecutionContext_t ctx, unsigned int flags, int priority) noexcept
1013cdef extern from 'cuda_runtime_api.h' nogil:
1014 cudaError_t _static_cudaExecutionCtxSynchronize "cudaExecutionCtxSynchronize" (cudaExecutionContext_t ctx) noexcept
1016cdef extern from 'cuda_runtime_api.h' nogil:
1017 cudaError_t _static_cudaStreamGetDevResource "cudaStreamGetDevResource" (cudaStream_t hStream, cudaDevResource* resource, cudaDevResourceType type) noexcept
1019cdef extern from 'cuda_runtime_api.h' nogil:
1020 cudaError_t _static_cudaExecutionCtxRecordEvent "cudaExecutionCtxRecordEvent" (cudaExecutionContext_t ctx, cudaEvent_t event) noexcept
1022cdef extern from 'cuda_runtime_api.h' nogil:
1023 cudaError_t _static_cudaExecutionCtxWaitEvent "cudaExecutionCtxWaitEvent" (cudaExecutionContext_t ctx, cudaEvent_t event) noexcept
1025cdef extern from 'cuda_runtime_api.h' nogil:
1026 cudaError_t _static_cudaDeviceGetExecutionCtx "cudaDeviceGetExecutionCtx" (cudaExecutionContext_t* ctx, int device) noexcept
1028cdef extern from 'cuda_runtime_api.h' nogil:
1029 cudaError_t _static_cudaFuncGetParamCount "cudaFuncGetParamCount" (const void* func, size_t* paramCount) noexcept
1031cdef extern from 'cuda_runtime_api.h' nogil:
1032 cudaError_t _static_cudaLaunchHostFunc_v2 "cudaLaunchHostFunc_v2" (cudaStream_t stream, cudaHostFn_t fn, void* userData, unsigned int syncMode) noexcept
1034cdef extern from 'cuda_runtime_api.h' nogil:
1035 cudaError_t _static_cudaMemcpyWithAttributesAsync "cudaMemcpyWithAttributesAsync" (void* dst, const void* src, size_t size, cudaMemcpyAttributes* attr, cudaStream_t stream) noexcept
1037cdef extern from 'cuda_runtime_api.h' nogil:
1038 cudaError_t _static_cudaMemcpy3DWithAttributesAsync "cudaMemcpy3DWithAttributesAsync" (cudaMemcpy3DBatchOp* op, unsigned long long flags, cudaStream_t stream) noexcept
1040cdef extern from 'cuda_runtime_api.h' nogil:
1041 cudaError_t _static_cudaGraphNodeGetParams "cudaGraphNodeGetParams" (cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) noexcept
1043cdef extern from 'cuda_runtime_api.h' nogil:
1044 cudaError_t _static_cudaStreamBeginRecaptureToGraph "cudaStreamBeginRecaptureToGraph" (cudaStream_t stream, cudaStreamCaptureMode mode, cudaGraph_t graph, cudaGraphRecaptureCallbackData* callbackData) noexcept
1047###############################################################################
1048# Wrapper functions
1049###############################################################################
1051cdef cudaError_t _cudaDeviceReset() except ?cudaErrorCallRequiresNewerDriver nogil:
1052 cdef bint usePTDS = cudaPythonInit()
1053 if usePTDS:
1054 return ptds._cudaDeviceReset()
1055 return _static_cudaDeviceReset()
1058cdef cudaError_t _cudaDeviceSynchronize() except ?cudaErrorCallRequiresNewerDriver nogil:
1059 cdef bint usePTDS = cudaPythonInit() 2' ( ) * + , - . / : ; = 5 ? @ [ ] ^ _ ` { | } ~ abbbcbdbebfbgbhbibjbkblbmbnbobpbqbrbsbtbubvbwbxbybzbAbBbCbDbEbFbGbHbIbJbKbLbMbNbObPbC TbUbYbZb0b1b2b3b4b5b6b7b8b9b!b#b$b%b'b(b)b*b+b,b-b.b/b:b;b=b?b@b[b]b^b_b`b{b|b}b~bacbcccdcecfcgchcicjckclcmcncocpcqcrcsctcucvcwcxcyczcAcBcCcDcEcFcGcHcIcJc
1060 if usePTDS: 2a ' ( ) * + , - . / : ; = 5 ? @ [ ] ^ _ ` { | } ~ abbbcbdbebfbgbhbibjbkblbmbnbobpbqbrbsbtbubvbwbxbybzbAbBbCbDbEbFbGbHbIbJbKbLbMbNbObPbC TbUbYbZb0b1b2b3b4b5b6b7b8b9b!b#b$b%b'b(b)b*b+b,b-b.b/b:b;b=b?b@b[b]b^b_b`b{b|b}b~bacbcccdcecfcgchcicjckclcmcncocpcqcrcsctcucvcwcxcyczcAcBcCcDcEcFcGcHcIcJc
1061 return ptds._cudaDeviceSynchronize()
1062 return _static_cudaDeviceSynchronize() 2' ( ) * + , - . / : ; = 5 ? @ [ ] ^ _ ` { | } ~ abbbcbdbebfbgbhbibjbkblbmbnbobpbqbrbsbtbubvbwbxbybzbAbBbCbDbEbFbGbHbIbJbKbLbMbNbObPbC TbUbYbZb0b1b2b3b4b5b6b7b8b9b!b#b$b%b'b(b)b*b+b,b-b.b/b:b;b=b?b@b[b]b^b_b`b{b|b}b~bacbcccdcecfcgchcicjckclcmcncocpcqcrcsctcucvcwcxcyczcAcBcCcDcEcFcGcHcIcJc
1065cdef cudaError_t _cudaDeviceSetLimit(cudaLimit limit, size_t value) except ?cudaErrorCallRequiresNewerDriver nogil:
1066 cdef bint usePTDS = cudaPythonInit()
1067 if usePTDS:
1068 return ptds._cudaDeviceSetLimit(limit, value)
1069 return _static_cudaDeviceSetLimit(limit, value)
1072cdef cudaError_t _cudaDeviceGetLimit(size_t* pValue, cudaLimit limit) except ?cudaErrorCallRequiresNewerDriver nogil:
1073 cdef bint usePTDS = cudaPythonInit()
1074 if usePTDS:
1075 return ptds._cudaDeviceGetLimit(pValue, limit)
1076 return _static_cudaDeviceGetLimit(pValue, limit)
1079cdef cudaError_t _cudaDeviceGetTexture1DLinearMaxWidth(size_t* maxWidthInElements, const cudaChannelFormatDesc* fmtDesc, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1080 cdef bint usePTDS = cudaPythonInit()
1081 if usePTDS:
1082 return ptds._cudaDeviceGetTexture1DLinearMaxWidth(maxWidthInElements, fmtDesc, device)
1083 return _static_cudaDeviceGetTexture1DLinearMaxWidth(maxWidthInElements, fmtDesc, device)
1086cdef cudaError_t _cudaDeviceGetCacheConfig(cudaFuncCache* pCacheConfig) except ?cudaErrorCallRequiresNewerDriver nogil:
1087 cdef bint usePTDS = cudaPythonInit()
1088 if usePTDS:
1089 return ptds._cudaDeviceGetCacheConfig(pCacheConfig)
1090 return _static_cudaDeviceGetCacheConfig(pCacheConfig)
1093cdef cudaError_t _cudaDeviceGetStreamPriorityRange(int* leastPriority, int* greatestPriority) except ?cudaErrorCallRequiresNewerDriver nogil:
1094 cdef bint usePTDS = cudaPythonInit()
1095 if usePTDS:
1096 return ptds._cudaDeviceGetStreamPriorityRange(leastPriority, greatestPriority)
1097 return _static_cudaDeviceGetStreamPriorityRange(leastPriority, greatestPriority)
1100cdef cudaError_t _cudaDeviceSetCacheConfig(cudaFuncCache cacheConfig) except ?cudaErrorCallRequiresNewerDriver nogil:
1101 cdef bint usePTDS = cudaPythonInit()
1102 if usePTDS:
1103 return ptds._cudaDeviceSetCacheConfig(cacheConfig)
1104 return _static_cudaDeviceSetCacheConfig(cacheConfig)
1107cdef cudaError_t _cudaDeviceGetByPCIBusId(int* device, const char* pciBusId) except ?cudaErrorCallRequiresNewerDriver nogil:
1108 cdef bint usePTDS = cudaPythonInit()
1109 if usePTDS:
1110 return ptds._cudaDeviceGetByPCIBusId(device, pciBusId)
1111 return _static_cudaDeviceGetByPCIBusId(device, pciBusId)
1114cdef cudaError_t _cudaDeviceGetPCIBusId(char* pciBusId, int len, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1115 cdef bint usePTDS = cudaPythonInit() 2QbWbXb
1116 if usePTDS: 2a QbWbXb
1117 return ptds._cudaDeviceGetPCIBusId(pciBusId, len, device)
1118 return _static_cudaDeviceGetPCIBusId(pciBusId, len, device) 2QbWbXb
1121cdef cudaError_t _cudaIpcGetEventHandle(cudaIpcEventHandle_t* handle, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
1122 cdef bint usePTDS = cudaPythonInit()
1123 if usePTDS:
1124 return ptds._cudaIpcGetEventHandle(handle, event)
1125 return _static_cudaIpcGetEventHandle(handle, event)
1128cdef cudaError_t _cudaIpcOpenEventHandle(cudaEvent_t* event, cudaIpcEventHandle_t handle) except ?cudaErrorCallRequiresNewerDriver nogil:
1129 cdef bint usePTDS = cudaPythonInit()
1130 if usePTDS:
1131 return ptds._cudaIpcOpenEventHandle(event, handle)
1132 return _static_cudaIpcOpenEventHandle(event, handle)
1135cdef cudaError_t _cudaIpcGetMemHandle(cudaIpcMemHandle_t* handle, void* devPtr) except ?cudaErrorCallRequiresNewerDriver nogil:
1136 cdef bint usePTDS = cudaPythonInit()
1137 if usePTDS:
1138 return ptds._cudaIpcGetMemHandle(handle, devPtr)
1139 return _static_cudaIpcGetMemHandle(handle, devPtr)
1142cdef cudaError_t _cudaIpcOpenMemHandle(void** devPtr, cudaIpcMemHandle_t handle, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1143 cdef bint usePTDS = cudaPythonInit()
1144 if usePTDS:
1145 return ptds._cudaIpcOpenMemHandle(devPtr, handle, flags)
1146 return _static_cudaIpcOpenMemHandle(devPtr, handle, flags)
1149cdef cudaError_t _cudaIpcCloseMemHandle(void* devPtr) except ?cudaErrorCallRequiresNewerDriver nogil:
1150 cdef bint usePTDS = cudaPythonInit()
1151 if usePTDS:
1152 return ptds._cudaIpcCloseMemHandle(devPtr)
1153 return _static_cudaIpcCloseMemHandle(devPtr)
1156cdef cudaError_t _cudaDeviceFlushGPUDirectRDMAWrites(cudaFlushGPUDirectRDMAWritesTarget target, cudaFlushGPUDirectRDMAWritesScope scope) except ?cudaErrorCallRequiresNewerDriver nogil:
1157 cdef bint usePTDS = cudaPythonInit()
1158 if usePTDS:
1159 return ptds._cudaDeviceFlushGPUDirectRDMAWrites(target, scope)
1160 return _static_cudaDeviceFlushGPUDirectRDMAWrites(target, scope)
1163cdef cudaError_t _cudaDeviceRegisterAsyncNotification(int device, cudaAsyncCallback callbackFunc, void* userData, cudaAsyncCallbackHandle_t* callback) except ?cudaErrorCallRequiresNewerDriver nogil:
1164 cdef bint usePTDS = cudaPythonInit()
1165 if usePTDS:
1166 return ptds._cudaDeviceRegisterAsyncNotification(device, callbackFunc, userData, callback)
1167 return _static_cudaDeviceRegisterAsyncNotification(device, callbackFunc, userData, callback)
1170cdef cudaError_t _cudaDeviceUnregisterAsyncNotification(int device, cudaAsyncCallbackHandle_t callback) except ?cudaErrorCallRequiresNewerDriver nogil:
1171 cdef bint usePTDS = cudaPythonInit()
1172 if usePTDS:
1173 return ptds._cudaDeviceUnregisterAsyncNotification(device, callback)
1174 return _static_cudaDeviceUnregisterAsyncNotification(device, callback)
1177cdef cudaError_t _cudaDeviceGetSharedMemConfig(cudaSharedMemConfig* pConfig) except ?cudaErrorCallRequiresNewerDriver nogil:
1178 cdef bint usePTDS = cudaPythonInit()
1179 if usePTDS:
1180 return ptds._cudaDeviceGetSharedMemConfig(pConfig)
1181 return _static_cudaDeviceGetSharedMemConfig(pConfig)
1184cdef cudaError_t _cudaDeviceSetSharedMemConfig(cudaSharedMemConfig config) except ?cudaErrorCallRequiresNewerDriver nogil:
1185 cdef bint usePTDS = cudaPythonInit()
1186 if usePTDS:
1187 return ptds._cudaDeviceSetSharedMemConfig(config)
1188 return _static_cudaDeviceSetSharedMemConfig(config)
1191cdef cudaError_t _cudaGetLastError() except ?cudaErrorCallRequiresNewerDriver nogil:
1192 cdef bint usePTDS = cudaPythonInit()
1193 if usePTDS:
1194 return ptds._cudaGetLastError() 1I
1195 return _static_cudaGetLastError() 1I
1198cdef cudaError_t _cudaPeekAtLastError() except ?cudaErrorCallRequiresNewerDriver nogil:
1199 cdef bint usePTDS = cudaPythonInit()
1200 if usePTDS:
1201 return ptds._cudaPeekAtLastError() 1I
1202 return _static_cudaPeekAtLastError() 1I
1205cdef const char* _cudaGetErrorName(cudaError_t error) except?NULL nogil:
1206 cdef bint usePTDS = cudaPythonInit() 1634I
1207 if usePTDS: 1a634I
1208 return ptds._cudaGetErrorName(error)
1209 return _static_cudaGetErrorName(error) 1634I
1212cdef const char* _cudaGetErrorString(cudaError_t error) except?NULL nogil:
1213 cdef bint usePTDS = cudaPythonInit() 26 RbI
1214 if usePTDS: 2a 6 RbI
1215 return ptds._cudaGetErrorString(error)
1216 return _static_cudaGetErrorString(error) 2a 6 RbI
1219cdef cudaError_t _cudaGetDeviceCount(int* count) except ?cudaErrorCallRequiresNewerDriver nogil:
1220 cdef bint usePTDS = cudaPythonInit()
1221 if usePTDS:
1222 return ptds._cudaGetDeviceCount(count)
1223 return _static_cudaGetDeviceCount(count)
1226cdef cudaError_t _cudaDeviceGetAttribute(int* value, cudaDeviceAttr attr, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1227 cdef bint usePTDS = cudaPythonInit() 2a Sb
1228 if usePTDS: 2a Sb
1229 return ptds._cudaDeviceGetAttribute(value, attr, device)
1230 return _static_cudaDeviceGetAttribute(value, attr, device) 2a Sb
1233cdef cudaError_t _cudaDeviceGetDefaultMemPool(cudaMemPool_t* memPool, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1234 cdef bint usePTDS = cudaPythonInit() 17
1235 if usePTDS: 1a7
1236 return ptds._cudaDeviceGetDefaultMemPool(memPool, device)
1237 return _static_cudaDeviceGetDefaultMemPool(memPool, device) 17
1240cdef cudaError_t _cudaDeviceSetMemPool(int device, cudaMemPool_t memPool) except ?cudaErrorCallRequiresNewerDriver nogil:
1241 cdef bint usePTDS = cudaPythonInit() 17
1242 if usePTDS: 1a7
1243 return ptds._cudaDeviceSetMemPool(device, memPool)
1244 return _static_cudaDeviceSetMemPool(device, memPool) 17
1247cdef cudaError_t _cudaDeviceGetMemPool(cudaMemPool_t* memPool, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1248 cdef bint usePTDS = cudaPythonInit()
1249 if usePTDS:
1250 return ptds._cudaDeviceGetMemPool(memPool, device)
1251 return _static_cudaDeviceGetMemPool(memPool, device)
1254cdef cudaError_t _cudaDeviceGetNvSciSyncAttributes(void* nvSciSyncAttrList, int device, int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1255 cdef bint usePTDS = cudaPythonInit()
1256 if usePTDS:
1257 return ptds._cudaDeviceGetNvSciSyncAttributes(nvSciSyncAttrList, device, flags)
1258 return _static_cudaDeviceGetNvSciSyncAttributes(nvSciSyncAttrList, device, flags)
1261cdef cudaError_t _cudaDeviceGetP2PAttribute(int* value, cudaDeviceP2PAttr attr, int srcDevice, int dstDevice) except ?cudaErrorCallRequiresNewerDriver nogil:
1262 cdef bint usePTDS = cudaPythonInit()
1263 if usePTDS:
1264 return ptds._cudaDeviceGetP2PAttribute(value, attr, srcDevice, dstDevice)
1265 return _static_cudaDeviceGetP2PAttribute(value, attr, srcDevice, dstDevice)
1268cdef cudaError_t _cudaChooseDevice(int* device, const cudaDeviceProp* prop) except ?cudaErrorCallRequiresNewerDriver nogil:
1269 cdef bint usePTDS = cudaPythonInit()
1270 if usePTDS:
1271 return ptds._cudaChooseDevice(device, prop) 1q
1272 return _static_cudaChooseDevice(device, prop) 1q
1275cdef cudaError_t _cudaInitDevice(int device, unsigned int deviceFlags, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1276 cdef bint usePTDS = cudaPythonInit()
1277 if usePTDS:
1278 return ptds._cudaInitDevice(device, deviceFlags, flags)
1279 return _static_cudaInitDevice(device, deviceFlags, flags)
1282cdef cudaError_t _cudaSetDevice(int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1283 cdef bint usePTDS = cudaPythonInit() 1q
1284 if usePTDS: 1aq
1285 return ptds._cudaSetDevice(device)
1286 return _static_cudaSetDevice(device) 1q
1289cdef cudaError_t _cudaGetDevice(int* device) except ?cudaErrorCallRequiresNewerDriver nogil:
1290 cdef bint usePTDS = cudaPythonInit() 2Vb
1291 if usePTDS: 2a Vb
1292 return ptds._cudaGetDevice(device)
1293 return _static_cudaGetDevice(device) 2Vb
1296cdef cudaError_t _cudaSetDeviceFlags(unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1297 cdef bint usePTDS = cudaPythonInit()
1298 if usePTDS:
1299 return ptds._cudaSetDeviceFlags(flags) 1dFecibACW
1300 return _static_cudaSetDeviceFlags(flags) 1dFecibACW
1303cdef cudaError_t _cudaGetDeviceFlags(unsigned int* flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1304 cdef bint usePTDS = cudaPythonInit()
1305 if usePTDS:
1306 return ptds._cudaGetDeviceFlags(flags) 1B
1307 return _static_cudaGetDeviceFlags(flags) 1B
1310cdef cudaError_t _cudaStreamCreate(cudaStream_t* pStream) except ?cudaErrorCallRequiresNewerDriver nogil:
1311 cdef bint usePTDS = cudaPythonInit() 1dFecibACW
1312 if usePTDS: 1adFecibACW
1313 return ptds._cudaStreamCreate(pStream)
1314 return _static_cudaStreamCreate(pStream) 1dFecibACW
1317cdef cudaError_t _cudaStreamCreateWithFlags(cudaStream_t* pStream, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1318 cdef bint usePTDS = cudaPythonInit() 1B
1319 if usePTDS: 1aB
1320 return ptds._cudaStreamCreateWithFlags(pStream, flags)
1321 return _static_cudaStreamCreateWithFlags(pStream, flags) 1B
1324cdef cudaError_t _cudaStreamCreateWithPriority(cudaStream_t* pStream, unsigned int flags, int priority) except ?cudaErrorCallRequiresNewerDriver nogil:
1325 cdef bint usePTDS = cudaPythonInit()
1326 if usePTDS:
1327 return ptds._cudaStreamCreateWithPriority(pStream, flags, priority)
1328 return _static_cudaStreamCreateWithPriority(pStream, flags, priority)
1331cdef cudaError_t _cudaStreamGetPriority(cudaStream_t hStream, int* priority) except ?cudaErrorCallRequiresNewerDriver nogil:
1332 cdef bint usePTDS = cudaPythonInit()
1333 if usePTDS:
1334 return ptds._cudaStreamGetPriority(hStream, priority)
1335 return _static_cudaStreamGetPriority(hStream, priority)
1338cdef cudaError_t _cudaStreamGetFlags(cudaStream_t hStream, unsigned int* flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1339 cdef bint usePTDS = cudaPythonInit()
1340 if usePTDS:
1341 return ptds._cudaStreamGetFlags(hStream, flags)
1342 return _static_cudaStreamGetFlags(hStream, flags)
1345cdef cudaError_t _cudaStreamGetId(cudaStream_t hStream, unsigned long long* streamId) except ?cudaErrorCallRequiresNewerDriver nogil:
1346 cdef bint usePTDS = cudaPythonInit()
1347 if usePTDS:
1348 return ptds._cudaStreamGetId(hStream, streamId)
1349 return _static_cudaStreamGetId(hStream, streamId)
1352cdef cudaError_t _cudaStreamGetDevice(cudaStream_t hStream, int* device) except ?cudaErrorCallRequiresNewerDriver nogil:
1353 cdef bint usePTDS = cudaPythonInit()
1354 if usePTDS:
1355 return ptds._cudaStreamGetDevice(hStream, device)
1356 return _static_cudaStreamGetDevice(hStream, device)
1359cdef cudaError_t _cudaCtxResetPersistingL2Cache() except ?cudaErrorCallRequiresNewerDriver nogil:
1360 cdef bint usePTDS = cudaPythonInit()
1361 if usePTDS:
1362 return ptds._cudaCtxResetPersistingL2Cache()
1363 return _static_cudaCtxResetPersistingL2Cache()
1366cdef cudaError_t _cudaStreamCopyAttributes(cudaStream_t dst, cudaStream_t src) except ?cudaErrorCallRequiresNewerDriver nogil:
1367 cdef bint usePTDS = cudaPythonInit()
1368 if usePTDS:
1369 return ptds._cudaStreamCopyAttributes(dst, src)
1370 return _static_cudaStreamCopyAttributes(dst, src)
1373cdef cudaError_t _cudaStreamGetAttribute(cudaStream_t hStream, cudaStreamAttrID attr, cudaStreamAttrValue* value_out) except ?cudaErrorCallRequiresNewerDriver nogil:
1374 cdef bint usePTDS = cudaPythonInit()
1375 if usePTDS:
1376 return ptds._cudaStreamGetAttribute(hStream, attr, value_out) 1DdFW
1377 return _static_cudaStreamGetAttribute(hStream, attr, value_out) 1DdFW
1380cdef cudaError_t _cudaStreamSetAttribute(cudaStream_t hStream, cudaStreamAttrID attr, const cudaStreamAttrValue* value) except ?cudaErrorCallRequiresNewerDriver nogil:
1381 cdef bint usePTDS = cudaPythonInit()
1382 if usePTDS:
1383 return ptds._cudaStreamSetAttribute(hStream, attr, value)
1384 return _static_cudaStreamSetAttribute(hStream, attr, value)
1387cdef cudaError_t _cudaStreamDestroy(cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1388 cdef bint usePTDS = cudaPythonInit() 1DdFW
1389 if usePTDS: 1aDdFW
1390 return ptds._cudaStreamDestroy(stream) 1C
1391 return _static_cudaStreamDestroy(stream) 1DdFCW
1394cdef cudaError_t _cudaStreamWaitEvent(cudaStream_t stream, cudaEvent_t event, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1395 cdef bint usePTDS = cudaPythonInit()
1396 if usePTDS:
1397 return ptds._cudaStreamWaitEvent(stream, event, flags) 1ecib
1398 return _static_cudaStreamWaitEvent(stream, event, flags) 1ecib
1401cdef cudaError_t _cudaStreamAddCallback(cudaStream_t stream, cudaStreamCallback_t callback, void* userData, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1402 cdef bint usePTDS = cudaPythonInit() 1C
1403 if usePTDS: 1aC
1404 return ptds._cudaStreamAddCallback(stream, callback, userData, flags)
1405 return _static_cudaStreamAddCallback(stream, callback, userData, flags) 1C
1408cdef cudaError_t _cudaStreamSynchronize(cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1409 cdef bint usePTDS = cudaPythonInit() 1ecib
1410 if usePTDS: 1aecib
1411 return ptds._cudaStreamSynchronize(stream)
1412 return _static_cudaStreamSynchronize(stream) 1ecib
1415cdef cudaError_t _cudaStreamQuery(cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1416 cdef bint usePTDS = cudaPythonInit()
1417 if usePTDS:
1418 return ptds._cudaStreamQuery(stream) 1A
1419 return _static_cudaStreamQuery(stream) 1A
1422cdef cudaError_t _cudaStreamAttachMemAsync(cudaStream_t stream, void* devPtr, size_t length, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1423 cdef bint usePTDS = cudaPythonInit()
1424 if usePTDS:
1425 return ptds._cudaStreamAttachMemAsync(stream, devPtr, length, flags)
1426 return _static_cudaStreamAttachMemAsync(stream, devPtr, length, flags)
1429cdef cudaError_t _cudaStreamBeginCapture(cudaStream_t stream, cudaStreamCaptureMode mode) except ?cudaErrorCallRequiresNewerDriver nogil:
1430 cdef bint usePTDS = cudaPythonInit() 1A
1431 if usePTDS: 1aA
1432 return ptds._cudaStreamBeginCapture(stream, mode) 1!
1433 return _static_cudaStreamBeginCapture(stream, mode) 1!A
1436cdef cudaError_t _cudaStreamBeginCaptureToGraph(cudaStream_t stream, cudaGraph_t graph, const cudaGraphNode_t* dependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, cudaStreamCaptureMode mode) except ?cudaErrorCallRequiresNewerDriver nogil:
1437 cdef bint usePTDS = cudaPythonInit()
1438 if usePTDS:
1439 return ptds._cudaStreamBeginCaptureToGraph(stream, graph, dependencies, dependencyData, numDependencies, mode) 1A
1440 return _static_cudaStreamBeginCaptureToGraph(stream, graph, dependencies, dependencyData, numDependencies, mode) 1A
1443cdef cudaError_t _cudaThreadExchangeStreamCaptureMode(cudaStreamCaptureMode* mode) except ?cudaErrorCallRequiresNewerDriver nogil:
1444 cdef bint usePTDS = cudaPythonInit() 1!
1445 if usePTDS: 1a!
1446 return ptds._cudaThreadExchangeStreamCaptureMode(mode)
1447 return _static_cudaThreadExchangeStreamCaptureMode(mode) 1!
1450cdef cudaError_t _cudaStreamEndCapture(cudaStream_t stream, cudaGraph_t* pGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
1451 cdef bint usePTDS = cudaPythonInit() 1A
1452 if usePTDS: 1aA
1453 return ptds._cudaStreamEndCapture(stream, pGraph)
1454 return _static_cudaStreamEndCapture(stream, pGraph) 1A
1457cdef cudaError_t _cudaStreamIsCapturing(cudaStream_t stream, cudaStreamCaptureStatus* pCaptureStatus) except ?cudaErrorCallRequiresNewerDriver nogil:
1458 cdef bint usePTDS = cudaPythonInit()
1459 if usePTDS:
1460 return ptds._cudaStreamIsCapturing(stream, pCaptureStatus) 1U
1461 return _static_cudaStreamIsCapturing(stream, pCaptureStatus) 1U
1464cdef cudaError_t _cudaStreamUpdateCaptureDependencies(cudaStream_t stream, cudaGraphNode_t* dependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1465 cdef bint usePTDS = cudaPythonInit()
1466 if usePTDS:
1467 return ptds._cudaStreamUpdateCaptureDependencies(stream, dependencies, dependencyData, numDependencies, flags)
1468 return _static_cudaStreamUpdateCaptureDependencies(stream, dependencies, dependencyData, numDependencies, flags)
1471cdef cudaError_t _cudaEventCreate(cudaEvent_t* event) except ?cudaErrorCallRequiresNewerDriver nogil:
1472 cdef bint usePTDS = cudaPythonInit() 1U
1473 if usePTDS: 1aU
1474 return ptds._cudaEventCreate(event)
1475 return _static_cudaEventCreate(event) 1U
1478cdef cudaError_t _cudaEventCreateWithFlags(cudaEvent_t* event, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1479 cdef bint usePTDS = cudaPythonInit()
1480 if usePTDS:
1481 return ptds._cudaEventCreateWithFlags(event, flags)
1482 return _static_cudaEventCreateWithFlags(event, flags)
1485cdef cudaError_t _cudaEventRecord(cudaEvent_t event, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1486 cdef bint usePTDS = cudaPythonInit()
1487 if usePTDS:
1488 return ptds._cudaEventRecord(event, stream)
1489 return _static_cudaEventRecord(event, stream)
1492cdef cudaError_t _cudaEventRecordWithFlags(cudaEvent_t event, cudaStream_t stream, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1493 cdef bint usePTDS = cudaPythonInit()
1494 if usePTDS:
1495 return ptds._cudaEventRecordWithFlags(event, stream, flags)
1496 return _static_cudaEventRecordWithFlags(event, stream, flags)
1499cdef cudaError_t _cudaEventQuery(cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
1500 cdef bint usePTDS = cudaPythonInit()
1501 if usePTDS:
1502 return ptds._cudaEventQuery(event) 1U
1503 return _static_cudaEventQuery(event) 1U
1506cdef cudaError_t _cudaEventSynchronize(cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
1507 cdef bint usePTDS = cudaPythonInit()
1508 if usePTDS:
1509 return ptds._cudaEventSynchronize(event)
1510 return _static_cudaEventSynchronize(event)
1513cdef cudaError_t _cudaEventDestroy(cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
1514 cdef bint usePTDS = cudaPythonInit() 1U
1515 if usePTDS: 1aU
1516 return ptds._cudaEventDestroy(event)
1517 return _static_cudaEventDestroy(event) 1U
1520cdef cudaError_t _cudaEventElapsedTime(float* ms, cudaEvent_t start, cudaEvent_t end) except ?cudaErrorCallRequiresNewerDriver nogil:
1521 cdef bint usePTDS = cudaPythonInit()
1522 if usePTDS:
1523 return ptds._cudaEventElapsedTime(ms, start, end)
1524 return _static_cudaEventElapsedTime(ms, start, end)
1527cdef cudaError_t _cudaImportExternalMemory(cudaExternalMemory_t* extMem_out, const cudaExternalMemoryHandleDesc* memHandleDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
1528 cdef bint usePTDS = cudaPythonInit()
1529 if usePTDS:
1530 return ptds._cudaImportExternalMemory(extMem_out, memHandleDesc)
1531 return _static_cudaImportExternalMemory(extMem_out, memHandleDesc)
1534cdef cudaError_t _cudaExternalMemoryGetMappedBuffer(void** devPtr, cudaExternalMemory_t extMem, const cudaExternalMemoryBufferDesc* bufferDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
1535 cdef bint usePTDS = cudaPythonInit()
1536 if usePTDS:
1537 return ptds._cudaExternalMemoryGetMappedBuffer(devPtr, extMem, bufferDesc)
1538 return _static_cudaExternalMemoryGetMappedBuffer(devPtr, extMem, bufferDesc)
1541cdef cudaError_t _cudaExternalMemoryGetMappedMipmappedArray(cudaMipmappedArray_t* mipmap, cudaExternalMemory_t extMem, const cudaExternalMemoryMipmappedArrayDesc* mipmapDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
1542 cdef bint usePTDS = cudaPythonInit()
1543 if usePTDS:
1544 return ptds._cudaExternalMemoryGetMappedMipmappedArray(mipmap, extMem, mipmapDesc)
1545 return _static_cudaExternalMemoryGetMappedMipmappedArray(mipmap, extMem, mipmapDesc)
1548cdef cudaError_t _cudaDestroyExternalMemory(cudaExternalMemory_t extMem) except ?cudaErrorCallRequiresNewerDriver nogil:
1549 cdef bint usePTDS = cudaPythonInit()
1550 if usePTDS:
1551 return ptds._cudaDestroyExternalMemory(extMem)
1552 return _static_cudaDestroyExternalMemory(extMem)
1555cdef cudaError_t _cudaImportExternalSemaphore(cudaExternalSemaphore_t* extSem_out, const cudaExternalSemaphoreHandleDesc* semHandleDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
1556 cdef bint usePTDS = cudaPythonInit()
1557 if usePTDS:
1558 return ptds._cudaImportExternalSemaphore(extSem_out, semHandleDesc)
1559 return _static_cudaImportExternalSemaphore(extSem_out, semHandleDesc)
1562cdef cudaError_t _cudaDestroyExternalSemaphore(cudaExternalSemaphore_t extSem) except ?cudaErrorCallRequiresNewerDriver nogil:
1563 cdef bint usePTDS = cudaPythonInit()
1564 if usePTDS:
1565 return ptds._cudaDestroyExternalSemaphore(extSem)
1566 return _static_cudaDestroyExternalSemaphore(extSem)
1569cdef cudaError_t _cudaFuncSetCacheConfig(const void* func, cudaFuncCache cacheConfig) except ?cudaErrorCallRequiresNewerDriver nogil:
1570 cdef bint usePTDS = cudaPythonInit()
1571 if usePTDS:
1572 return ptds._cudaFuncSetCacheConfig(func, cacheConfig)
1573 return _static_cudaFuncSetCacheConfig(func, cacheConfig)
1576cdef cudaError_t _cudaFuncGetAttributes(cudaFuncAttributes* attr, const void* func) except ?cudaErrorCallRequiresNewerDriver nogil:
1577 cdef bint usePTDS = cudaPythonInit()
1578 if usePTDS:
1579 return ptds._cudaFuncGetAttributes(attr, func)
1580 return _static_cudaFuncGetAttributes(attr, func)
1583cdef cudaError_t _cudaFuncSetAttribute(const void* func, cudaFuncAttribute attr, int value) except ?cudaErrorCallRequiresNewerDriver nogil:
1584 cdef bint usePTDS = cudaPythonInit()
1585 if usePTDS:
1586 return ptds._cudaFuncSetAttribute(func, attr, value)
1587 return _static_cudaFuncSetAttribute(func, attr, value)
1590cdef cudaError_t _cudaFuncGetName(const char** name, const void* func) except ?cudaErrorCallRequiresNewerDriver nogil:
1591 cdef bint usePTDS = cudaPythonInit()
1592 if usePTDS:
1593 return ptds._cudaFuncGetName(name, func) 1C
1594 return _static_cudaFuncGetName(name, func) 1C
1597cdef cudaError_t _cudaFuncGetParamInfo(const void* func, size_t paramIndex, size_t* paramOffset, size_t* paramSize) except ?cudaErrorCallRequiresNewerDriver nogil:
1598 cdef bint usePTDS = cudaPythonInit()
1599 if usePTDS:
1600 return ptds._cudaFuncGetParamInfo(func, paramIndex, paramOffset, paramSize)
1601 return _static_cudaFuncGetParamInfo(func, paramIndex, paramOffset, paramSize)
1604cdef cudaError_t _cudaLaunchHostFunc(cudaStream_t stream, cudaHostFn_t fn, void* userData) except ?cudaErrorCallRequiresNewerDriver nogil:
1605 cdef bint usePTDS = cudaPythonInit() 1C
1606 if usePTDS: 1aC
1607 return ptds._cudaLaunchHostFunc(stream, fn, userData)
1608 return _static_cudaLaunchHostFunc(stream, fn, userData) 1C
1611cdef cudaError_t _cudaFuncSetSharedMemConfig(const void* func, cudaSharedMemConfig config) except ?cudaErrorCallRequiresNewerDriver nogil:
1612 cdef bint usePTDS = cudaPythonInit()
1613 if usePTDS:
1614 return ptds._cudaFuncSetSharedMemConfig(func, config)
1615 return _static_cudaFuncSetSharedMemConfig(func, config)
1618cdef cudaError_t _cudaOccupancyMaxActiveBlocksPerMultiprocessor(int* numBlocks, const void* func, int blockSize, size_t dynamicSMemSize) except ?cudaErrorCallRequiresNewerDriver nogil:
1619 cdef bint usePTDS = cudaPythonInit()
1620 if usePTDS:
1621 return ptds._cudaOccupancyMaxActiveBlocksPerMultiprocessor(numBlocks, func, blockSize, dynamicSMemSize)
1622 return _static_cudaOccupancyMaxActiveBlocksPerMultiprocessor(numBlocks, func, blockSize, dynamicSMemSize)
1625cdef cudaError_t _cudaOccupancyAvailableDynamicSMemPerBlock(size_t* dynamicSmemSize, const void* func, int numBlocks, int blockSize) except ?cudaErrorCallRequiresNewerDriver nogil:
1626 cdef bint usePTDS = cudaPythonInit()
1627 if usePTDS:
1628 return ptds._cudaOccupancyAvailableDynamicSMemPerBlock(dynamicSmemSize, func, numBlocks, blockSize)
1629 return _static_cudaOccupancyAvailableDynamicSMemPerBlock(dynamicSmemSize, func, numBlocks, blockSize)
1632cdef cudaError_t _cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags(int* numBlocks, const void* func, int blockSize, size_t dynamicSMemSize, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1633 cdef bint usePTDS = cudaPythonInit()
1634 if usePTDS:
1635 return ptds._cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags(numBlocks, func, blockSize, dynamicSMemSize, flags) 1ecfbghHp
1636 return _static_cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags(numBlocks, func, blockSize, dynamicSMemSize, flags) 1ecfbghHp
1639cdef cudaError_t _cudaMallocManaged(void** devPtr, size_t size, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1640 cdef bint usePTDS = cudaPythonInit()
1641 if usePTDS:
1642 return ptds._cudaMallocManaged(devPtr, size, flags)
1643 return _static_cudaMallocManaged(devPtr, size, flags)
1646cdef cudaError_t _cudaMalloc(void** devPtr, size_t size) except ?cudaErrorCallRequiresNewerDriver nogil:
1647 cdef bint usePTDS = cudaPythonInit() 1ecfbghHp
1648 if usePTDS: 1aecfbghHp
1649 return ptds._cudaMalloc(devPtr, size)
1650 return _static_cudaMalloc(devPtr, size) 1ecfbghHp
1653cdef cudaError_t _cudaMallocHost(void** ptr, size_t size) except ?cudaErrorCallRequiresNewerDriver nogil:
1654 cdef bint usePTDS = cudaPythonInit()
1655 if usePTDS:
1656 return ptds._cudaMallocHost(ptr, size) 1vwrkfnibgjho
1657 return _static_cudaMallocHost(ptr, size) 1vwrkfnibgjho
1660cdef cudaError_t _cudaMallocPitch(void** devPtr, size_t* pitch, size_t width, size_t height) except ?cudaErrorCallRequiresNewerDriver nogil:
1661 cdef bint usePTDS = cudaPythonInit()
1662 if usePTDS:
1663 return ptds._cudaMallocPitch(devPtr, pitch, width, height) 1ecfbghyzHIp
1664 return _static_cudaMallocPitch(devPtr, pitch, width, height) 1ecfbghyzHIp
1667cdef cudaError_t _cudaMallocArray(cudaArray_t* array, const cudaChannelFormatDesc* desc, size_t width, size_t height, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1668 cdef bint usePTDS = cudaPythonInit() 1vwrkfnibgjho
1669 if usePTDS: 1avwrkfnibgjho
1670 return ptds._cudaMallocArray(array, desc, width, height, flags) 1XYZ0p
1671 return _static_cudaMallocArray(array, desc, width, height, flags) 1vwrkfnibgjhoXYZ0p
1674cdef cudaError_t _cudaFree(void* devPtr) except ?cudaErrorCallRequiresNewerDriver nogil:
1675 cdef bint usePTDS = cudaPythonInit() 1ecfbghyzH34Ip
1676 if usePTDS: 1aecfbghyzH34Ip
1677 return ptds._cudaFree(devPtr) 1vwkfnibgjho
1678 return _static_cudaFree(devPtr) 1vweckfnibgjhoyzH34Ip
1681cdef cudaError_t _cudaFreeHost(void* ptr) except ?cudaErrorCallRequiresNewerDriver nogil:
1682 cdef bint usePTDS = cudaPythonInit() 1XYZ0p
1683 if usePTDS: 1aXYZ0p
1684 return ptds._cudaFreeHost(ptr)
1685 return _static_cudaFreeHost(ptr) 1XYZ0p
1688cdef cudaError_t _cudaFreeArray(cudaArray_t array) except ?cudaErrorCallRequiresNewerDriver nogil:
1689 cdef bint usePTDS = cudaPythonInit() 1vwkfnibgjho
1690 if usePTDS: 1avwkfnibgjho
1691 return ptds._cudaFreeArray(array) 1XYZ0p
1692 return _static_cudaFreeArray(array) 1vwkfnibgjhoXYZ0p
1695cdef cudaError_t _cudaFreeMipmappedArray(cudaMipmappedArray_t mipmappedArray) except ?cudaErrorCallRequiresNewerDriver nogil:
1696 cdef bint usePTDS = cudaPythonInit() 12
1697 if usePTDS: 1a2
1698 return ptds._cudaFreeMipmappedArray(mipmappedArray) 1R
1699 return _static_cudaFreeMipmappedArray(mipmappedArray) 12R
1702cdef cudaError_t _cudaHostAlloc(void** pHost, size_t size, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1703 cdef bint usePTDS = cudaPythonInit() 1XYZ0p
1704 if usePTDS: 1aXYZ0p
1705 return ptds._cudaHostAlloc(pHost, size, flags) 1R
1706 return _static_cudaHostAlloc(pHost, size, flags) 1RXYZ0p
1709cdef cudaError_t _cudaHostRegister(void* ptr, size_t size, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1710 cdef bint usePTDS = cudaPythonInit() 1R
1711 if usePTDS: 1aR
1712 return ptds._cudaHostRegister(ptr, size, flags)
1713 return _static_cudaHostRegister(ptr, size, flags) 1R
1716cdef cudaError_t _cudaHostUnregister(void* ptr) except ?cudaErrorCallRequiresNewerDriver nogil:
1717 cdef bint usePTDS = cudaPythonInit() 1R
1718 if usePTDS: 1aR
1719 return ptds._cudaHostUnregister(ptr)
1720 return _static_cudaHostUnregister(ptr) 1R
1723cdef cudaError_t _cudaHostGetDevicePointer(void** pDevice, void* pHost, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1724 cdef bint usePTDS = cudaPythonInit()
1725 if usePTDS:
1726 return ptds._cudaHostGetDevicePointer(pDevice, pHost, flags) 1yz
1727 return _static_cudaHostGetDevicePointer(pDevice, pHost, flags) 1yz
1730cdef cudaError_t _cudaHostGetFlags(unsigned int* pFlags, void* pHost) except ?cudaErrorCallRequiresNewerDriver nogil:
1731 cdef bint usePTDS = cudaPythonInit()
1732 if usePTDS:
1733 return ptds._cudaHostGetFlags(pFlags, pHost)
1734 return _static_cudaHostGetFlags(pFlags, pHost)
1737cdef cudaError_t _cudaMalloc3D(cudaPitchedPtr* pitchedDevPtr, cudaExtent extent) except ?cudaErrorCallRequiresNewerDriver nogil:
1738 cdef bint usePTDS = cudaPythonInit() 1yz
1739 if usePTDS: 1ayz
1740 return ptds._cudaMalloc3D(pitchedDevPtr, extent)
1741 return _static_cudaMalloc3D(pitchedDevPtr, extent) 1yz
1744cdef cudaError_t _cudaMalloc3DArray(cudaArray_t* array, const cudaChannelFormatDesc* desc, cudaExtent extent, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1745 cdef bint usePTDS = cudaPythonInit()
1746 if usePTDS:
1747 return ptds._cudaMalloc3DArray(array, desc, extent, flags)
1748 return _static_cudaMalloc3DArray(array, desc, extent, flags)
1751cdef cudaError_t _cudaMallocMipmappedArray(cudaMipmappedArray_t* mipmappedArray, const cudaChannelFormatDesc* desc, cudaExtent extent, unsigned int numLevels, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
1752 cdef bint usePTDS = cudaPythonInit() 12
1753 if usePTDS: 1a2
1754 return ptds._cudaMallocMipmappedArray(mipmappedArray, desc, extent, numLevels, flags)
1755 return _static_cudaMallocMipmappedArray(mipmappedArray, desc, extent, numLevels, flags) 12
1758cdef cudaError_t _cudaGetMipmappedArrayLevel(cudaArray_t* levelArray, cudaMipmappedArray_const_t mipmappedArray, unsigned int level) except ?cudaErrorCallRequiresNewerDriver nogil:
1759 cdef bint usePTDS = cudaPythonInit()
1760 if usePTDS:
1761 return ptds._cudaGetMipmappedArrayLevel(levelArray, mipmappedArray, level) 1g
1762 return _static_cudaGetMipmappedArrayLevel(levelArray, mipmappedArray, level) 1g
1765cdef cudaError_t _cudaMemcpy3D(const cudaMemcpy3DParms* p) except ?cudaErrorCallRequiresNewerDriver nogil:
1766 cdef bint usePTDS = cudaPythonInit()
1767 if usePTDS:
1768 return ptds._cudaMemcpy3D(p) 1i
1769 return _static_cudaMemcpy3D(p) 1i
1772cdef cudaError_t _cudaMemcpy3DPeer(const cudaMemcpy3DPeerParms* p) except ?cudaErrorCallRequiresNewerDriver nogil:
1773 cdef bint usePTDS = cudaPythonInit() 1g
1774 if usePTDS: 1ag
1775 return ptds._cudaMemcpy3DPeer(p) 1b
1776 return _static_cudaMemcpy3DPeer(p) 1bg
1779cdef cudaError_t _cudaMemcpy3DAsync(const cudaMemcpy3DParms* p, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1780 cdef bint usePTDS = cudaPythonInit() 1i
1781 if usePTDS: 1ai
1782 return ptds._cudaMemcpy3DAsync(p, stream)
1783 return _static_cudaMemcpy3DAsync(p, stream) 1i
1786cdef cudaError_t _cudaMemcpy3DPeerAsync(const cudaMemcpy3DPeerParms* p, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1787 cdef bint usePTDS = cudaPythonInit() 1b
1788 if usePTDS: 1ab
1789 return ptds._cudaMemcpy3DPeerAsync(p, stream) 1v
1790 return _static_cudaMemcpy3DPeerAsync(p, stream) 1vb
1793cdef cudaError_t _cudaMemGetInfo(size_t* free, size_t* total) except ?cudaErrorCallRequiresNewerDriver nogil:
1794 cdef bint usePTDS = cudaPythonInit()
1795 if usePTDS:
1796 return ptds._cudaMemGetInfo(free, total)
1797 return _static_cudaMemGetInfo(free, total)
1800cdef cudaError_t _cudaArrayGetInfo(cudaChannelFormatDesc* desc, cudaExtent* extent, unsigned int* flags, cudaArray_t array) except ?cudaErrorCallRequiresNewerDriver nogil:
1801 cdef bint usePTDS = cudaPythonInit() 1v
1802 if usePTDS: 1av
1803 return ptds._cudaArrayGetInfo(desc, extent, flags, array)
1804 return _static_cudaArrayGetInfo(desc, extent, flags, array) 1v
1807cdef cudaError_t _cudaArrayGetPlane(cudaArray_t* pPlaneArray, cudaArray_t hArray, unsigned int planeIdx) except ?cudaErrorCallRequiresNewerDriver nogil:
1808 cdef bint usePTDS = cudaPythonInit()
1809 if usePTDS:
1810 return ptds._cudaArrayGetPlane(pPlaneArray, hArray, planeIdx)
1811 return _static_cudaArrayGetPlane(pPlaneArray, hArray, planeIdx)
1814cdef cudaError_t _cudaArrayGetMemoryRequirements(cudaArrayMemoryRequirements* memoryRequirements, cudaArray_t array, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1815 cdef bint usePTDS = cudaPythonInit()
1816 if usePTDS:
1817 return ptds._cudaArrayGetMemoryRequirements(memoryRequirements, array, device)
1818 return _static_cudaArrayGetMemoryRequirements(memoryRequirements, array, device)
1821cdef cudaError_t _cudaMipmappedArrayGetMemoryRequirements(cudaArrayMemoryRequirements* memoryRequirements, cudaMipmappedArray_t mipmap, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
1822 cdef bint usePTDS = cudaPythonInit()
1823 if usePTDS:
1824 return ptds._cudaMipmappedArrayGetMemoryRequirements(memoryRequirements, mipmap, device)
1825 return _static_cudaMipmappedArrayGetMemoryRequirements(memoryRequirements, mipmap, device)
1828cdef cudaError_t _cudaArrayGetSparseProperties(cudaArraySparseProperties* sparseProperties, cudaArray_t array) except ?cudaErrorCallRequiresNewerDriver nogil:
1829 cdef bint usePTDS = cudaPythonInit()
1830 if usePTDS:
1831 return ptds._cudaArrayGetSparseProperties(sparseProperties, array) 1fbghyzHT
1832 return _static_cudaArrayGetSparseProperties(sparseProperties, array) 1fbghyzHT
1835cdef cudaError_t _cudaMipmappedArrayGetSparseProperties(cudaArraySparseProperties* sparseProperties, cudaMipmappedArray_t mipmap) except ?cudaErrorCallRequiresNewerDriver nogil:
1836 cdef bint usePTDS = cudaPythonInit() 12
1837 if usePTDS: 1a2
1838 return ptds._cudaMipmappedArrayGetSparseProperties(sparseProperties, mipmap)
1839 return _static_cudaMipmappedArrayGetSparseProperties(sparseProperties, mipmap) 12
1842cdef cudaError_t _cudaMemcpy(void* dst, const void* src, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
1843 cdef bint usePTDS = cudaPythonInit() 1fbghyzHT
1844 if usePTDS: 1afbghyzHT
1845 return ptds._cudaMemcpy(dst, src, count, kind)
1846 return _static_cudaMemcpy(dst, src, count, kind) 1fbghyzHT
1849cdef cudaError_t _cudaMemcpyPeer(void* dst, int dstDevice, const void* src, int srcDevice, size_t count) except ?cudaErrorCallRequiresNewerDriver nogil:
1850 cdef bint usePTDS = cudaPythonInit()
1851 if usePTDS:
1852 return ptds._cudaMemcpyPeer(dst, dstDevice, src, srcDevice, count) 1kfnj
1853 return _static_cudaMemcpyPeer(dst, dstDevice, src, srcDevice, count) 1kfnj
1856cdef cudaError_t _cudaMemcpy2D(void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
1857 cdef bint usePTDS = cudaPythonInit()
1858 if usePTDS:
1859 return ptds._cudaMemcpy2D(dst, dpitch, src, spitch, width, height, kind) 1kfnibgj
1860 return _static_cudaMemcpy2D(dst, dpitch, src, spitch, width, height, kind) 1kfnibgj
1863cdef cudaError_t _cudaMemcpy2DToArray(cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
1864 cdef bint usePTDS = cudaPythonInit() 1kfnj
1865 if usePTDS: 1akfnj
1866 return ptds._cudaMemcpy2DToArray(dst, wOffset, hOffset, src, spitch, width, height, kind) 1k
1867 return _static_cudaMemcpy2DToArray(dst, wOffset, hOffset, src, spitch, width, height, kind) 1kfnj
1870cdef cudaError_t _cudaMemcpy2DFromArray(void* dst, size_t dpitch, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t width, size_t height, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
1871 cdef bint usePTDS = cudaPythonInit() 1kfnibgj
1872 if usePTDS: 1akfnibgj
1873 return ptds._cudaMemcpy2DFromArray(dst, dpitch, src, wOffset, hOffset, width, height, kind) 1p
1874 return _static_cudaMemcpy2DFromArray(dst, dpitch, src, wOffset, hOffset, width, height, kind) 1kfnibgjp
1877cdef cudaError_t _cudaMemcpy2DArrayToArray(cudaArray_t dst, size_t wOffsetDst, size_t hOffsetDst, cudaArray_const_t src, size_t wOffsetSrc, size_t hOffsetSrc, size_t width, size_t height, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
1878 cdef bint usePTDS = cudaPythonInit() 1k
1879 if usePTDS: 1ak
1880 return ptds._cudaMemcpy2DArrayToArray(dst, wOffsetDst, hOffsetDst, src, wOffsetSrc, hOffsetSrc, width, height, kind)
1881 return _static_cudaMemcpy2DArrayToArray(dst, wOffsetDst, hOffsetDst, src, wOffsetSrc, hOffsetSrc, width, height, kind) 1k
1884cdef cudaError_t _cudaMemcpyAsync(void* dst, const void* src, size_t count, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1885 cdef bint usePTDS = cudaPythonInit() 1p
1886 if usePTDS: 1ap
1887 return ptds._cudaMemcpyAsync(dst, src, count, kind, stream)
1888 return _static_cudaMemcpyAsync(dst, src, count, kind, stream) 1p
1891cdef cudaError_t _cudaMemcpyPeerAsync(void* dst, int dstDevice, const void* src, int srcDevice, size_t count, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1892 cdef bint usePTDS = cudaPythonInit()
1893 if usePTDS:
1894 return ptds._cudaMemcpyPeerAsync(dst, dstDevice, src, srcDevice, count, stream)
1895 return _static_cudaMemcpyPeerAsync(dst, dstDevice, src, srcDevice, count, stream)
1898cdef cudaError_t _cudaMemcpyBatchAsync(const void** dsts, const void** srcs, const size_t* sizes, size_t count, cudaMemcpyAttributes* attrs, size_t* attrsIdxs, size_t numAttrs, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1899 cdef bint usePTDS = cudaPythonInit()
1900 if usePTDS:
1901 return ptds._cudaMemcpyBatchAsync(dsts, srcs, sizes, count, attrs, attrsIdxs, numAttrs, stream)
1902 return _static_cudaMemcpyBatchAsync(dsts, srcs, sizes, count, attrs, attrsIdxs, numAttrs, stream)
1905cdef cudaError_t _cudaMemcpy3DBatchAsync(size_t numOps, cudaMemcpy3DBatchOp* opList, unsigned long long flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1906 cdef bint usePTDS = cudaPythonInit()
1907 if usePTDS:
1908 return ptds._cudaMemcpy3DBatchAsync(numOps, opList, flags, stream)
1909 return _static_cudaMemcpy3DBatchAsync(numOps, opList, flags, stream)
1912cdef cudaError_t _cudaMemcpy2DAsync(void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1913 cdef bint usePTDS = cudaPythonInit()
1914 if usePTDS:
1915 return ptds._cudaMemcpy2DAsync(dst, dpitch, src, spitch, width, height, kind, stream)
1916 return _static_cudaMemcpy2DAsync(dst, dpitch, src, spitch, width, height, kind, stream)
1919cdef cudaError_t _cudaMemcpy2DToArrayAsync(cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t spitch, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1920 cdef bint usePTDS = cudaPythonInit()
1921 if usePTDS:
1922 return ptds._cudaMemcpy2DToArrayAsync(dst, wOffset, hOffset, src, spitch, width, height, kind, stream) 1T
1923 return _static_cudaMemcpy2DToArrayAsync(dst, wOffset, hOffset, src, spitch, width, height, kind, stream) 1T
1926cdef cudaError_t _cudaMemcpy2DFromArrayAsync(void* dst, size_t dpitch, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t width, size_t height, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1927 cdef bint usePTDS = cudaPythonInit()
1928 if usePTDS:
1929 return ptds._cudaMemcpy2DFromArrayAsync(dst, dpitch, src, wOffset, hOffset, width, height, kind, stream)
1930 return _static_cudaMemcpy2DFromArrayAsync(dst, dpitch, src, wOffset, hOffset, width, height, kind, stream)
1933cdef cudaError_t _cudaMemset(void* devPtr, int value, size_t count) except ?cudaErrorCallRequiresNewerDriver nogil:
1934 cdef bint usePTDS = cudaPythonInit() 1T
1935 if usePTDS: 1aT
1936 return ptds._cudaMemset(devPtr, value, count) 1yz
1937 return _static_cudaMemset(devPtr, value, count) 1yzT
1940cdef cudaError_t _cudaMemset2D(void* devPtr, size_t pitch, int value, size_t width, size_t height) except ?cudaErrorCallRequiresNewerDriver nogil:
1941 cdef bint usePTDS = cudaPythonInit()
1942 if usePTDS:
1943 return ptds._cudaMemset2D(devPtr, pitch, value, width, height)
1944 return _static_cudaMemset2D(devPtr, pitch, value, width, height)
1947cdef cudaError_t _cudaMemset3D(cudaPitchedPtr pitchedDevPtr, int value, cudaExtent extent) except ?cudaErrorCallRequiresNewerDriver nogil:
1948 cdef bint usePTDS = cudaPythonInit() 1yz
1949 if usePTDS: 1ayz
1950 return ptds._cudaMemset3D(pitchedDevPtr, value, extent)
1951 return _static_cudaMemset3D(pitchedDevPtr, value, extent) 1yz
1954cdef cudaError_t _cudaMemsetAsync(void* devPtr, int value, size_t count, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1955 cdef bint usePTDS = cudaPythonInit()
1956 if usePTDS:
1957 return ptds._cudaMemsetAsync(devPtr, value, count, stream)
1958 return _static_cudaMemsetAsync(devPtr, value, count, stream)
1961cdef cudaError_t _cudaMemset2DAsync(void* devPtr, size_t pitch, int value, size_t width, size_t height, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1962 cdef bint usePTDS = cudaPythonInit()
1963 if usePTDS:
1964 return ptds._cudaMemset2DAsync(devPtr, pitch, value, width, height, stream)
1965 return _static_cudaMemset2DAsync(devPtr, pitch, value, width, height, stream)
1968cdef cudaError_t _cudaMemset3DAsync(cudaPitchedPtr pitchedDevPtr, int value, cudaExtent extent, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1969 cdef bint usePTDS = cudaPythonInit()
1970 if usePTDS:
1971 return ptds._cudaMemset3DAsync(pitchedDevPtr, value, extent, stream)
1972 return _static_cudaMemset3DAsync(pitchedDevPtr, value, extent, stream)
1975cdef cudaError_t _cudaMemPrefetchAsync(const void* devPtr, size_t count, cudaMemLocation location, unsigned int flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
1976 cdef bint usePTDS = cudaPythonInit()
1977 if usePTDS:
1978 return ptds._cudaMemPrefetchAsync(devPtr, count, location, flags, stream)
1979 return _static_cudaMemPrefetchAsync(devPtr, count, location, flags, stream)
1982cdef cudaError_t _cudaMemAdvise(const void* devPtr, size_t count, cudaMemoryAdvise advice, cudaMemLocation location) except ?cudaErrorCallRequiresNewerDriver nogil:
1983 cdef bint usePTDS = cudaPythonInit()
1984 if usePTDS:
1985 return ptds._cudaMemAdvise(devPtr, count, advice, location)
1986 return _static_cudaMemAdvise(devPtr, count, advice, location)
1989cdef cudaError_t _cudaMemRangeGetAttribute(void* data, size_t dataSize, cudaMemRangeAttribute attribute, const void* devPtr, size_t count) except ?cudaErrorCallRequiresNewerDriver nogil:
1990 cdef bint usePTDS = cudaPythonInit()
1991 if usePTDS:
1992 return ptds._cudaMemRangeGetAttribute(data, dataSize, attribute, devPtr, count) 1ho
1993 return _static_cudaMemRangeGetAttribute(data, dataSize, attribute, devPtr, count) 1ho
1996cdef cudaError_t _cudaMemRangeGetAttributes(void** data, size_t* dataSizes, cudaMemRangeAttribute* attributes, size_t numAttributes, const void* devPtr, size_t count) except ?cudaErrorCallRequiresNewerDriver nogil:
1997 cdef bint usePTDS = cudaPythonInit()
1998 if usePTDS:
1999 return ptds._cudaMemRangeGetAttributes(data, dataSizes, attributes, numAttributes, devPtr, count) 1ho
2000 return _static_cudaMemRangeGetAttributes(data, dataSizes, attributes, numAttributes, devPtr, count) 1ho
2003cdef cudaError_t _cudaMemcpyToArray(cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2004 cdef bint usePTDS = cudaPythonInit() 1ho
2005 if usePTDS: 1aho
2006 return ptds._cudaMemcpyToArray(dst, wOffset, hOffset, src, count, kind) 1j
2007 return _static_cudaMemcpyToArray(dst, wOffset, hOffset, src, count, kind) 1jho
2010cdef cudaError_t _cudaMemcpyFromArray(void* dst, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2011 cdef bint usePTDS = cudaPythonInit() 1ho
2012 if usePTDS: 1aho
2013 return ptds._cudaMemcpyFromArray(dst, src, wOffset, hOffset, count, kind)
2014 return _static_cudaMemcpyFromArray(dst, src, wOffset, hOffset, count, kind) 1ho
2017cdef cudaError_t _cudaMemcpyArrayToArray(cudaArray_t dst, size_t wOffsetDst, size_t hOffsetDst, cudaArray_const_t src, size_t wOffsetSrc, size_t hOffsetSrc, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2018 cdef bint usePTDS = cudaPythonInit() 1j
2019 if usePTDS: 1aj
2020 return ptds._cudaMemcpyArrayToArray(dst, wOffsetDst, hOffsetDst, src, wOffsetSrc, hOffsetSrc, count, kind)
2021 return _static_cudaMemcpyArrayToArray(dst, wOffsetDst, hOffsetDst, src, wOffsetSrc, hOffsetSrc, count, kind) 1j
2024cdef cudaError_t _cudaMemcpyToArrayAsync(cudaArray_t dst, size_t wOffset, size_t hOffset, const void* src, size_t count, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2025 cdef bint usePTDS = cudaPythonInit()
2026 if usePTDS:
2027 return ptds._cudaMemcpyToArrayAsync(dst, wOffset, hOffset, src, count, kind, stream)
2028 return _static_cudaMemcpyToArrayAsync(dst, wOffset, hOffset, src, count, kind, stream)
2031cdef cudaError_t _cudaMemcpyFromArrayAsync(void* dst, cudaArray_const_t src, size_t wOffset, size_t hOffset, size_t count, cudaMemcpyKind kind, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2032 cdef bint usePTDS = cudaPythonInit()
2033 if usePTDS:
2034 return ptds._cudaMemcpyFromArrayAsync(dst, src, wOffset, hOffset, count, kind, stream)
2035 return _static_cudaMemcpyFromArrayAsync(dst, src, wOffset, hOffset, count, kind, stream)
2038cdef cudaError_t _cudaMallocAsync(void** devPtr, size_t size, cudaStream_t hStream) except ?cudaErrorCallRequiresNewerDriver nogil:
2039 cdef bint usePTDS = cudaPythonInit()
2040 if usePTDS:
2041 return ptds._cudaMallocAsync(devPtr, size, hStream)
2042 return _static_cudaMallocAsync(devPtr, size, hStream)
2045cdef cudaError_t _cudaFreeAsync(void* devPtr, cudaStream_t hStream) except ?cudaErrorCallRequiresNewerDriver nogil:
2046 cdef bint usePTDS = cudaPythonInit()
2047 if usePTDS:
2048 return ptds._cudaFreeAsync(devPtr, hStream)
2049 return _static_cudaFreeAsync(devPtr, hStream)
2052cdef cudaError_t _cudaMemPoolTrimTo(cudaMemPool_t memPool, size_t minBytesToKeep) except ?cudaErrorCallRequiresNewerDriver nogil:
2053 cdef bint usePTDS = cudaPythonInit()
2054 if usePTDS:
2055 return ptds._cudaMemPoolTrimTo(memPool, minBytesToKeep)
2056 return _static_cudaMemPoolTrimTo(memPool, minBytesToKeep)
2059cdef cudaError_t _cudaMemPoolSetAttribute(cudaMemPool_t memPool, cudaMemPoolAttr attr, void* value) except ?cudaErrorCallRequiresNewerDriver nogil:
2060 cdef bint usePTDS = cudaPythonInit() 1L
2061 if usePTDS: 1aL
2062 return ptds._cudaMemPoolSetAttribute(memPool, attr, value)
2063 return _static_cudaMemPoolSetAttribute(memPool, attr, value) 1L
2066cdef cudaError_t _cudaMemPoolGetAttribute(cudaMemPool_t memPool, cudaMemPoolAttr attr, void* value) except ?cudaErrorCallRequiresNewerDriver nogil:
2067 cdef bint usePTDS = cudaPythonInit() 1L
2068 if usePTDS: 1aL
2069 return ptds._cudaMemPoolGetAttribute(memPool, attr, value)
2070 return _static_cudaMemPoolGetAttribute(memPool, attr, value) 1L
2073cdef cudaError_t _cudaMemPoolSetAccess(cudaMemPool_t memPool, const cudaMemAccessDesc* descList, size_t count) except ?cudaErrorCallRequiresNewerDriver nogil:
2074 cdef bint usePTDS = cudaPythonInit()
2075 if usePTDS:
2076 return ptds._cudaMemPoolSetAccess(memPool, descList, count)
2077 return _static_cudaMemPoolSetAccess(memPool, descList, count)
2080cdef cudaError_t _cudaMemPoolGetAccess(cudaMemAccessFlags* flags, cudaMemPool_t memPool, cudaMemLocation* location) except ?cudaErrorCallRequiresNewerDriver nogil:
2081 cdef bint usePTDS = cudaPythonInit()
2082 if usePTDS:
2083 return ptds._cudaMemPoolGetAccess(flags, memPool, location)
2084 return _static_cudaMemPoolGetAccess(flags, memPool, location)
2087cdef cudaError_t _cudaMemPoolCreate(cudaMemPool_t* memPool, const cudaMemPoolProps* poolProps) except ?cudaErrorCallRequiresNewerDriver nogil:
2088 cdef bint usePTDS = cudaPythonInit() 1L
2089 if usePTDS: 1aL
2090 return ptds._cudaMemPoolCreate(memPool, poolProps)
2091 return _static_cudaMemPoolCreate(memPool, poolProps) 1L
2094cdef cudaError_t _cudaMemPoolDestroy(cudaMemPool_t memPool) except ?cudaErrorCallRequiresNewerDriver nogil:
2095 cdef bint usePTDS = cudaPythonInit() 1L
2096 if usePTDS: 1aL
2097 return ptds._cudaMemPoolDestroy(memPool)
2098 return _static_cudaMemPoolDestroy(memPool) 1L
2101cdef cudaError_t _cudaMallocFromPoolAsync(void** ptr, size_t size, cudaMemPool_t memPool, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2102 cdef bint usePTDS = cudaPythonInit()
2103 if usePTDS:
2104 return ptds._cudaMallocFromPoolAsync(ptr, size, memPool, stream)
2105 return _static_cudaMallocFromPoolAsync(ptr, size, memPool, stream)
2108cdef cudaError_t _cudaMemPoolExportToShareableHandle(void* shareableHandle, cudaMemPool_t memPool, cudaMemAllocationHandleType handleType, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2109 cdef bint usePTDS = cudaPythonInit()
2110 if usePTDS:
2111 return ptds._cudaMemPoolExportToShareableHandle(shareableHandle, memPool, handleType, flags)
2112 return _static_cudaMemPoolExportToShareableHandle(shareableHandle, memPool, handleType, flags)
2115cdef cudaError_t _cudaMemPoolImportFromShareableHandle(cudaMemPool_t* memPool, void* shareableHandle, cudaMemAllocationHandleType handleType, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2116 cdef bint usePTDS = cudaPythonInit()
2117 if usePTDS:
2118 return ptds._cudaMemPoolImportFromShareableHandle(memPool, shareableHandle, handleType, flags)
2119 return _static_cudaMemPoolImportFromShareableHandle(memPool, shareableHandle, handleType, flags)
2122cdef cudaError_t _cudaMemPoolExportPointer(cudaMemPoolPtrExportData* exportData, void* ptr) except ?cudaErrorCallRequiresNewerDriver nogil:
2123 cdef bint usePTDS = cudaPythonInit()
2124 if usePTDS:
2125 return ptds._cudaMemPoolExportPointer(exportData, ptr)
2126 return _static_cudaMemPoolExportPointer(exportData, ptr)
2129cdef cudaError_t _cudaMemPoolImportPointer(void** ptr, cudaMemPool_t memPool, cudaMemPoolPtrExportData* exportData) except ?cudaErrorCallRequiresNewerDriver nogil:
2130 cdef bint usePTDS = cudaPythonInit()
2131 if usePTDS:
2132 return ptds._cudaMemPoolImportPointer(ptr, memPool, exportData)
2133 return _static_cudaMemPoolImportPointer(ptr, memPool, exportData)
2136cdef cudaError_t _cudaPointerGetAttributes(cudaPointerAttributes* attributes, const void* ptr) except ?cudaErrorCallRequiresNewerDriver nogil:
2137 cdef bint usePTDS = cudaPythonInit()
2138 if usePTDS:
2139 return ptds._cudaPointerGetAttributes(attributes, ptr)
2140 return _static_cudaPointerGetAttributes(attributes, ptr)
2143cdef cudaError_t _cudaDeviceCanAccessPeer(int* canAccessPeer, int device, int peerDevice) except ?cudaErrorCallRequiresNewerDriver nogil:
2144 cdef bint usePTDS = cudaPythonInit()
2145 if usePTDS:
2146 return ptds._cudaDeviceCanAccessPeer(canAccessPeer, device, peerDevice)
2147 return _static_cudaDeviceCanAccessPeer(canAccessPeer, device, peerDevice)
2150cdef cudaError_t _cudaDeviceEnablePeerAccess(int peerDevice, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2151 cdef bint usePTDS = cudaPythonInit()
2152 if usePTDS:
2153 return ptds._cudaDeviceEnablePeerAccess(peerDevice, flags)
2154 return _static_cudaDeviceEnablePeerAccess(peerDevice, flags)
2157cdef cudaError_t _cudaDeviceDisablePeerAccess(int peerDevice) except ?cudaErrorCallRequiresNewerDriver nogil:
2158 cdef bint usePTDS = cudaPythonInit()
2159 if usePTDS:
2160 return ptds._cudaDeviceDisablePeerAccess(peerDevice)
2161 return _static_cudaDeviceDisablePeerAccess(peerDevice)
2164cdef cudaError_t _cudaGraphicsUnregisterResource(cudaGraphicsResource_t resource) except ?cudaErrorCallRequiresNewerDriver nogil:
2165 cdef bint usePTDS = cudaPythonInit() 134
2166 if usePTDS: 1a34
2167 return ptds._cudaGraphicsUnregisterResource(resource)
2168 return _static_cudaGraphicsUnregisterResource(resource) 134
2171cdef cudaError_t _cudaGraphicsResourceSetMapFlags(cudaGraphicsResource_t resource, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2172 cdef bint usePTDS = cudaPythonInit()
2173 if usePTDS:
2174 return ptds._cudaGraphicsResourceSetMapFlags(resource, flags)
2175 return _static_cudaGraphicsResourceSetMapFlags(resource, flags)
2178cdef cudaError_t _cudaGraphicsMapResources(int count, cudaGraphicsResource_t* resources, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2179 cdef bint usePTDS = cudaPythonInit()
2180 if usePTDS:
2181 return ptds._cudaGraphicsMapResources(count, resources, stream)
2182 return _static_cudaGraphicsMapResources(count, resources, stream)
2185cdef cudaError_t _cudaGraphicsUnmapResources(int count, cudaGraphicsResource_t* resources, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2186 cdef bint usePTDS = cudaPythonInit()
2187 if usePTDS:
2188 return ptds._cudaGraphicsUnmapResources(count, resources, stream)
2189 return _static_cudaGraphicsUnmapResources(count, resources, stream)
2192cdef cudaError_t _cudaGraphicsResourceGetMappedPointer(void** devPtr, size_t* size, cudaGraphicsResource_t resource) except ?cudaErrorCallRequiresNewerDriver nogil:
2193 cdef bint usePTDS = cudaPythonInit()
2194 if usePTDS:
2195 return ptds._cudaGraphicsResourceGetMappedPointer(devPtr, size, resource)
2196 return _static_cudaGraphicsResourceGetMappedPointer(devPtr, size, resource)
2199cdef cudaError_t _cudaGraphicsSubResourceGetMappedArray(cudaArray_t* array, cudaGraphicsResource_t resource, unsigned int arrayIndex, unsigned int mipLevel) except ?cudaErrorCallRequiresNewerDriver nogil:
2200 cdef bint usePTDS = cudaPythonInit()
2201 if usePTDS:
2202 return ptds._cudaGraphicsSubResourceGetMappedArray(array, resource, arrayIndex, mipLevel) 1w
2203 return _static_cudaGraphicsSubResourceGetMappedArray(array, resource, arrayIndex, mipLevel) 1w
2206cdef cudaError_t _cudaGraphicsResourceGetMappedMipmappedArray(cudaMipmappedArray_t* mipmappedArray, cudaGraphicsResource_t resource) except ?cudaErrorCallRequiresNewerDriver nogil:
2207 cdef bint usePTDS = cudaPythonInit()
2208 if usePTDS:
2209 return ptds._cudaGraphicsResourceGetMappedMipmappedArray(mipmappedArray, resource) 1vwrkfnibgjho%
2210 return _static_cudaGraphicsResourceGetMappedMipmappedArray(mipmappedArray, resource) 1vwrkfnibgjho%
2213cdef cudaError_t _cudaGetChannelDesc(cudaChannelFormatDesc* desc, cudaArray_const_t array) except ?cudaErrorCallRequiresNewerDriver nogil:
2214 cdef bint usePTDS = cudaPythonInit() 1w
2215 if usePTDS: 1aw
2216 return ptds._cudaGetChannelDesc(desc, array) 1r
2217 return _static_cudaGetChannelDesc(desc, array) 1wr
2220cdef cudaChannelFormatDesc _cudaCreateChannelDesc(int x, int y, int z, int w, cudaChannelFormatKind f) except* nogil:
2221 cdef bint usePTDS = cudaPythonInit() 1vwrkfnibgjho%
2222 if usePTDS: 1avwrkfnibgjho%
2223 return ptds._cudaCreateChannelDesc(x, y, z, w, f) 1r
2224 return _static_cudaCreateChannelDesc(x, y, z, w, f) 1vwrkfnibgjho%
2227cdef cudaError_t _cudaCreateTextureObject(cudaTextureObject_t* pTexObject, const cudaResourceDesc* pResDesc, const cudaTextureDesc* pTexDesc, const cudaResourceViewDesc* pResViewDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
2228 cdef bint usePTDS = cudaPythonInit() 1r
2229 if usePTDS: 1ar
2230 return ptds._cudaCreateTextureObject(pTexObject, pResDesc, pTexDesc, pResViewDesc)
2231 return _static_cudaCreateTextureObject(pTexObject, pResDesc, pTexDesc, pResViewDesc) 1r
2234cdef cudaError_t _cudaDestroyTextureObject(cudaTextureObject_t texObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2235 cdef bint usePTDS = cudaPythonInit() 1r
2236 if usePTDS: 1ar
2237 return ptds._cudaDestroyTextureObject(texObject) 1r
2238 return _static_cudaDestroyTextureObject(texObject) 1r
2241cdef cudaError_t _cudaGetTextureObjectResourceDesc(cudaResourceDesc* pResDesc, cudaTextureObject_t texObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2242 cdef bint usePTDS = cudaPythonInit()
2243 if usePTDS:
2244 return ptds._cudaGetTextureObjectResourceDesc(pResDesc, texObject)
2245 return _static_cudaGetTextureObjectResourceDesc(pResDesc, texObject)
2248cdef cudaError_t _cudaGetTextureObjectTextureDesc(cudaTextureDesc* pTexDesc, cudaTextureObject_t texObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2249 cdef bint usePTDS = cudaPythonInit() 1r
2250 if usePTDS: 1ar
2251 return ptds._cudaGetTextureObjectTextureDesc(pTexDesc, texObject)
2252 return _static_cudaGetTextureObjectTextureDesc(pTexDesc, texObject) 1r
2255cdef cudaError_t _cudaGetTextureObjectResourceViewDesc(cudaResourceViewDesc* pResViewDesc, cudaTextureObject_t texObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2256 cdef bint usePTDS = cudaPythonInit()
2257 if usePTDS:
2258 return ptds._cudaGetTextureObjectResourceViewDesc(pResViewDesc, texObject)
2259 return _static_cudaGetTextureObjectResourceViewDesc(pResViewDesc, texObject)
2262cdef cudaError_t _cudaCreateSurfaceObject(cudaSurfaceObject_t* pSurfObject, const cudaResourceDesc* pResDesc) except ?cudaErrorCallRequiresNewerDriver nogil:
2263 cdef bint usePTDS = cudaPythonInit()
2264 if usePTDS:
2265 return ptds._cudaCreateSurfaceObject(pSurfObject, pResDesc)
2266 return _static_cudaCreateSurfaceObject(pSurfObject, pResDesc)
2269cdef cudaError_t _cudaDestroySurfaceObject(cudaSurfaceObject_t surfObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2270 cdef bint usePTDS = cudaPythonInit()
2271 if usePTDS:
2272 return ptds._cudaDestroySurfaceObject(surfObject)
2273 return _static_cudaDestroySurfaceObject(surfObject)
2276cdef cudaError_t _cudaGetSurfaceObjectResourceDesc(cudaResourceDesc* pResDesc, cudaSurfaceObject_t surfObject) except ?cudaErrorCallRequiresNewerDriver nogil:
2277 cdef bint usePTDS = cudaPythonInit()
2278 if usePTDS:
2279 return ptds._cudaGetSurfaceObjectResourceDesc(pResDesc, surfObject)
2280 return _static_cudaGetSurfaceObjectResourceDesc(pResDesc, surfObject)
2283cdef cudaError_t _cudaDriverGetVersion(int* driverVersion) except ?cudaErrorCallRequiresNewerDriver nogil:
2284 cdef bint usePTDS = cudaPythonInit()
2285 if usePTDS:
2286 return ptds._cudaDriverGetVersion(driverVersion) 1sdEltuGecxmBV
2287 return _static_cudaDriverGetVersion(driverVersion) 1asdEltuGecxmBV
2290cdef cudaError_t _cudaRuntimeGetVersion(int* runtimeVersion) except ?cudaErrorCallRequiresNewerDriver nogil:
2291 cdef bint usePTDS = cudaPythonInit()
2292 if usePTDS:
2293 return ptds._cudaRuntimeGetVersion(runtimeVersion)
2294 return _static_cudaRuntimeGetVersion(runtimeVersion)
2297cdef cudaError_t _cudaGraphCreate(cudaGraph_t* pGraph, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2298 cdef bint usePTDS = cudaPythonInit() 1sdEltuGecxmBV
2299 if usePTDS: 1asdEltuGecxmBV
2300 return ptds._cudaGraphCreate(pGraph, flags)
2301 return _static_cudaGraphCreate(pGraph, flags) 1sdEltuGecxmBV
2304cdef cudaError_t _cudaGraphAddKernelNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaKernelNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2305 cdef bint usePTDS = cudaPythonInit()
2306 if usePTDS:
2307 return ptds._cudaGraphAddKernelNode(pGraphNode, graph, pDependencies, numDependencies, pNodeParams)
2308 return _static_cudaGraphAddKernelNode(pGraphNode, graph, pDependencies, numDependencies, pNodeParams)
2311cdef cudaError_t _cudaGraphKernelNodeGetParams(cudaGraphNode_t node, cudaKernelNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2312 cdef bint usePTDS = cudaPythonInit()
2313 if usePTDS:
2314 return ptds._cudaGraphKernelNodeGetParams(node, pNodeParams)
2315 return _static_cudaGraphKernelNodeGetParams(node, pNodeParams)
2318cdef cudaError_t _cudaGraphKernelNodeSetParams(cudaGraphNode_t node, const cudaKernelNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2319 cdef bint usePTDS = cudaPythonInit()
2320 if usePTDS:
2321 return ptds._cudaGraphKernelNodeSetParams(node, pNodeParams)
2322 return _static_cudaGraphKernelNodeSetParams(node, pNodeParams)
2325cdef cudaError_t _cudaGraphKernelNodeCopyAttributes(cudaGraphNode_t hDst, cudaGraphNode_t hSrc) except ?cudaErrorCallRequiresNewerDriver nogil:
2326 cdef bint usePTDS = cudaPythonInit()
2327 if usePTDS:
2328 return ptds._cudaGraphKernelNodeCopyAttributes(hDst, hSrc)
2329 return _static_cudaGraphKernelNodeCopyAttributes(hDst, hSrc)
2332cdef cudaError_t _cudaGraphKernelNodeGetAttribute(cudaGraphNode_t hNode, cudaKernelNodeAttrID attr, cudaKernelNodeAttrValue* value_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2333 cdef bint usePTDS = cudaPythonInit()
2334 if usePTDS:
2335 return ptds._cudaGraphKernelNodeGetAttribute(hNode, attr, value_out)
2336 return _static_cudaGraphKernelNodeGetAttribute(hNode, attr, value_out)
2339cdef cudaError_t _cudaGraphKernelNodeSetAttribute(cudaGraphNode_t hNode, cudaKernelNodeAttrID attr, const cudaKernelNodeAttrValue* value) except ?cudaErrorCallRequiresNewerDriver nogil:
2340 cdef bint usePTDS = cudaPythonInit()
2341 if usePTDS:
2342 return ptds._cudaGraphKernelNodeSetAttribute(hNode, attr, value) 1ec
2343 return _static_cudaGraphKernelNodeSetAttribute(hNode, attr, value) 1ec
2346cdef cudaError_t _cudaGraphAddMemcpyNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaMemcpy3DParms* pCopyParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2347 cdef bint usePTDS = cudaPythonInit()
2348 if usePTDS:
2349 return ptds._cudaGraphAddMemcpyNode(pGraphNode, graph, pDependencies, numDependencies, pCopyParams)
2350 return _static_cudaGraphAddMemcpyNode(pGraphNode, graph, pDependencies, numDependencies, pCopyParams)
2353cdef cudaError_t _cudaGraphAddMemcpyNode1D(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, void* dst, const void* src, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2354 cdef bint usePTDS = cudaPythonInit() 1ec
2355 if usePTDS: 1aec
2356 return ptds._cudaGraphAddMemcpyNode1D(pGraphNode, graph, pDependencies, numDependencies, dst, src, count, kind)
2357 return _static_cudaGraphAddMemcpyNode1D(pGraphNode, graph, pDependencies, numDependencies, dst, src, count, kind) 1ec
2360cdef cudaError_t _cudaGraphMemcpyNodeGetParams(cudaGraphNode_t node, cudaMemcpy3DParms* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2361 cdef bint usePTDS = cudaPythonInit()
2362 if usePTDS:
2363 return ptds._cudaGraphMemcpyNodeGetParams(node, pNodeParams)
2364 return _static_cudaGraphMemcpyNodeGetParams(node, pNodeParams)
2367cdef cudaError_t _cudaGraphMemcpyNodeSetParams(cudaGraphNode_t node, const cudaMemcpy3DParms* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2368 cdef bint usePTDS = cudaPythonInit()
2369 if usePTDS:
2370 return ptds._cudaGraphMemcpyNodeSetParams(node, pNodeParams) 1c
2371 return _static_cudaGraphMemcpyNodeSetParams(node, pNodeParams) 1c
2374cdef cudaError_t _cudaGraphMemcpyNodeSetParams1D(cudaGraphNode_t node, void* dst, const void* src, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2375 cdef bint usePTDS = cudaPythonInit()
2376 if usePTDS:
2377 return ptds._cudaGraphMemcpyNodeSetParams1D(node, dst, src, count, kind)
2378 return _static_cudaGraphMemcpyNodeSetParams1D(node, dst, src, count, kind)
2381cdef cudaError_t _cudaGraphAddMemsetNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaMemsetParams* pMemsetParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2382 cdef bint usePTDS = cudaPythonInit() 1c
2383 if usePTDS: 1ac
2384 return ptds._cudaGraphAddMemsetNode(pGraphNode, graph, pDependencies, numDependencies, pMemsetParams)
2385 return _static_cudaGraphAddMemsetNode(pGraphNode, graph, pDependencies, numDependencies, pMemsetParams) 1c
2388cdef cudaError_t _cudaGraphMemsetNodeGetParams(cudaGraphNode_t node, cudaMemsetParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2389 cdef bint usePTDS = cudaPythonInit()
2390 if usePTDS:
2391 return ptds._cudaGraphMemsetNodeGetParams(node, pNodeParams)
2392 return _static_cudaGraphMemsetNodeGetParams(node, pNodeParams)
2395cdef cudaError_t _cudaGraphMemsetNodeSetParams(cudaGraphNode_t node, const cudaMemsetParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2396 cdef bint usePTDS = cudaPythonInit()
2397 if usePTDS:
2398 return ptds._cudaGraphMemsetNodeSetParams(node, pNodeParams)
2399 return _static_cudaGraphMemsetNodeSetParams(node, pNodeParams)
2402cdef cudaError_t _cudaGraphAddHostNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaHostNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2403 cdef bint usePTDS = cudaPythonInit()
2404 if usePTDS:
2405 return ptds._cudaGraphAddHostNode(pGraphNode, graph, pDependencies, numDependencies, pNodeParams)
2406 return _static_cudaGraphAddHostNode(pGraphNode, graph, pDependencies, numDependencies, pNodeParams)
2409cdef cudaError_t _cudaGraphHostNodeGetParams(cudaGraphNode_t node, cudaHostNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2410 cdef bint usePTDS = cudaPythonInit()
2411 if usePTDS:
2412 return ptds._cudaGraphHostNodeGetParams(node, pNodeParams)
2413 return _static_cudaGraphHostNodeGetParams(node, pNodeParams)
2416cdef cudaError_t _cudaGraphHostNodeSetParams(cudaGraphNode_t node, const cudaHostNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2417 cdef bint usePTDS = cudaPythonInit()
2418 if usePTDS:
2419 return ptds._cudaGraphHostNodeSetParams(node, pNodeParams)
2420 return _static_cudaGraphHostNodeSetParams(node, pNodeParams)
2423cdef cudaError_t _cudaGraphAddChildGraphNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaGraph_t childGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
2424 cdef bint usePTDS = cudaPythonInit()
2425 if usePTDS:
2426 return ptds._cudaGraphAddChildGraphNode(pGraphNode, graph, pDependencies, numDependencies, childGraph) 1dltuxmBK
2427 return _static_cudaGraphAddChildGraphNode(pGraphNode, graph, pDependencies, numDependencies, childGraph) 1dltuxmBK
2430cdef cudaError_t _cudaGraphChildGraphNodeGetGraph(cudaGraphNode_t node, cudaGraph_t* pGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
2431 cdef bint usePTDS = cudaPythonInit()
2432 if usePTDS:
2433 return ptds._cudaGraphChildGraphNodeGetGraph(node, pGraph)
2434 return _static_cudaGraphChildGraphNodeGetGraph(node, pGraph)
2437cdef cudaError_t _cudaGraphAddEmptyNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies) except ?cudaErrorCallRequiresNewerDriver nogil:
2438 cdef bint usePTDS = cudaPythonInit() 1dltuxmBK
2439 if usePTDS: 1adltuxmBK
2440 return ptds._cudaGraphAddEmptyNode(pGraphNode, graph, pDependencies, numDependencies)
2441 return _static_cudaGraphAddEmptyNode(pGraphNode, graph, pDependencies, numDependencies) 1dltuxmBK
2444cdef cudaError_t _cudaGraphAddEventRecordNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2445 cdef bint usePTDS = cudaPythonInit()
2446 if usePTDS:
2447 return ptds._cudaGraphAddEventRecordNode(pGraphNode, graph, pDependencies, numDependencies, event)
2448 return _static_cudaGraphAddEventRecordNode(pGraphNode, graph, pDependencies, numDependencies, event)
2451cdef cudaError_t _cudaGraphEventRecordNodeGetEvent(cudaGraphNode_t node, cudaEvent_t* event_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2452 cdef bint usePTDS = cudaPythonInit()
2453 if usePTDS:
2454 return ptds._cudaGraphEventRecordNodeGetEvent(node, event_out)
2455 return _static_cudaGraphEventRecordNodeGetEvent(node, event_out)
2458cdef cudaError_t _cudaGraphEventRecordNodeSetEvent(cudaGraphNode_t node, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2459 cdef bint usePTDS = cudaPythonInit()
2460 if usePTDS:
2461 return ptds._cudaGraphEventRecordNodeSetEvent(node, event)
2462 return _static_cudaGraphEventRecordNodeSetEvent(node, event)
2465cdef cudaError_t _cudaGraphAddEventWaitNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2466 cdef bint usePTDS = cudaPythonInit()
2467 if usePTDS:
2468 return ptds._cudaGraphAddEventWaitNode(pGraphNode, graph, pDependencies, numDependencies, event)
2469 return _static_cudaGraphAddEventWaitNode(pGraphNode, graph, pDependencies, numDependencies, event)
2472cdef cudaError_t _cudaGraphEventWaitNodeGetEvent(cudaGraphNode_t node, cudaEvent_t* event_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2473 cdef bint usePTDS = cudaPythonInit()
2474 if usePTDS:
2475 return ptds._cudaGraphEventWaitNodeGetEvent(node, event_out)
2476 return _static_cudaGraphEventWaitNodeGetEvent(node, event_out)
2479cdef cudaError_t _cudaGraphEventWaitNodeSetEvent(cudaGraphNode_t node, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2480 cdef bint usePTDS = cudaPythonInit()
2481 if usePTDS:
2482 return ptds._cudaGraphEventWaitNodeSetEvent(node, event)
2483 return _static_cudaGraphEventWaitNodeSetEvent(node, event)
2486cdef cudaError_t _cudaGraphAddExternalSemaphoresSignalNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaExternalSemaphoreSignalNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2487 cdef bint usePTDS = cudaPythonInit()
2488 if usePTDS:
2489 return ptds._cudaGraphAddExternalSemaphoresSignalNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2490 return _static_cudaGraphAddExternalSemaphoresSignalNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2493cdef cudaError_t _cudaGraphExternalSemaphoresSignalNodeGetParams(cudaGraphNode_t hNode, cudaExternalSemaphoreSignalNodeParams* params_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2494 cdef bint usePTDS = cudaPythonInit()
2495 if usePTDS:
2496 return ptds._cudaGraphExternalSemaphoresSignalNodeGetParams(hNode, params_out)
2497 return _static_cudaGraphExternalSemaphoresSignalNodeGetParams(hNode, params_out)
2500cdef cudaError_t _cudaGraphExternalSemaphoresSignalNodeSetParams(cudaGraphNode_t hNode, const cudaExternalSemaphoreSignalNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2501 cdef bint usePTDS = cudaPythonInit()
2502 if usePTDS:
2503 return ptds._cudaGraphExternalSemaphoresSignalNodeSetParams(hNode, nodeParams)
2504 return _static_cudaGraphExternalSemaphoresSignalNodeSetParams(hNode, nodeParams)
2507cdef cudaError_t _cudaGraphAddExternalSemaphoresWaitNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, const cudaExternalSemaphoreWaitNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2508 cdef bint usePTDS = cudaPythonInit()
2509 if usePTDS:
2510 return ptds._cudaGraphAddExternalSemaphoresWaitNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2511 return _static_cudaGraphAddExternalSemaphoresWaitNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2514cdef cudaError_t _cudaGraphExternalSemaphoresWaitNodeGetParams(cudaGraphNode_t hNode, cudaExternalSemaphoreWaitNodeParams* params_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2515 cdef bint usePTDS = cudaPythonInit()
2516 if usePTDS:
2517 return ptds._cudaGraphExternalSemaphoresWaitNodeGetParams(hNode, params_out)
2518 return _static_cudaGraphExternalSemaphoresWaitNodeGetParams(hNode, params_out)
2521cdef cudaError_t _cudaGraphExternalSemaphoresWaitNodeSetParams(cudaGraphNode_t hNode, const cudaExternalSemaphoreWaitNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2522 cdef bint usePTDS = cudaPythonInit()
2523 if usePTDS:
2524 return ptds._cudaGraphExternalSemaphoresWaitNodeSetParams(hNode, nodeParams)
2525 return _static_cudaGraphExternalSemaphoresWaitNodeSetParams(hNode, nodeParams)
2528cdef cudaError_t _cudaGraphAddMemAllocNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, cudaMemAllocNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2529 cdef bint usePTDS = cudaPythonInit()
2530 if usePTDS:
2531 return ptds._cudaGraphAddMemAllocNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2532 return _static_cudaGraphAddMemAllocNode(pGraphNode, graph, pDependencies, numDependencies, nodeParams)
2535cdef cudaError_t _cudaGraphMemAllocNodeGetParams(cudaGraphNode_t node, cudaMemAllocNodeParams* params_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2536 cdef bint usePTDS = cudaPythonInit()
2537 if usePTDS:
2538 return ptds._cudaGraphMemAllocNodeGetParams(node, params_out)
2539 return _static_cudaGraphMemAllocNodeGetParams(node, params_out)
2542cdef cudaError_t _cudaGraphAddMemFreeNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, size_t numDependencies, void* dptr) except ?cudaErrorCallRequiresNewerDriver nogil:
2543 cdef bint usePTDS = cudaPythonInit()
2544 if usePTDS:
2545 return ptds._cudaGraphAddMemFreeNode(pGraphNode, graph, pDependencies, numDependencies, dptr)
2546 return _static_cudaGraphAddMemFreeNode(pGraphNode, graph, pDependencies, numDependencies, dptr)
2549cdef cudaError_t _cudaGraphMemFreeNodeGetParams(cudaGraphNode_t node, void* dptr_out) except ?cudaErrorCallRequiresNewerDriver nogil:
2550 cdef bint usePTDS = cudaPythonInit()
2551 if usePTDS:
2552 return ptds._cudaGraphMemFreeNodeGetParams(node, dptr_out)
2553 return _static_cudaGraphMemFreeNodeGetParams(node, dptr_out)
2556cdef cudaError_t _cudaDeviceGraphMemTrim(int device) except ?cudaErrorCallRequiresNewerDriver nogil:
2557 cdef bint usePTDS = cudaPythonInit()
2558 if usePTDS:
2559 return ptds._cudaDeviceGraphMemTrim(device)
2560 return _static_cudaDeviceGraphMemTrim(device)
2563cdef cudaError_t _cudaDeviceGetGraphMemAttribute(int device, cudaGraphMemAttributeType attr, void* value) except ?cudaErrorCallRequiresNewerDriver nogil:
2564 cdef bint usePTDS = cudaPythonInit()
2565 if usePTDS:
2566 return ptds._cudaDeviceGetGraphMemAttribute(device, attr, value)
2567 return _static_cudaDeviceGetGraphMemAttribute(device, attr, value)
2570cdef cudaError_t _cudaDeviceSetGraphMemAttribute(int device, cudaGraphMemAttributeType attr, void* value) except ?cudaErrorCallRequiresNewerDriver nogil:
2571 cdef bint usePTDS = cudaPythonInit()
2572 if usePTDS:
2573 return ptds._cudaDeviceSetGraphMemAttribute(device, attr, value)
2574 return _static_cudaDeviceSetGraphMemAttribute(device, attr, value)
2577cdef cudaError_t _cudaGraphClone(cudaGraph_t* pGraphClone, cudaGraph_t originalGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
2578 cdef bint usePTDS = cudaPythonInit()
2579 if usePTDS:
2580 return ptds._cudaGraphClone(pGraphClone, originalGraph)
2581 return _static_cudaGraphClone(pGraphClone, originalGraph)
2584cdef cudaError_t _cudaGraphNodeFindInClone(cudaGraphNode_t* pNode, cudaGraphNode_t originalNode, cudaGraph_t clonedGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
2585 cdef bint usePTDS = cudaPythonInit()
2586 if usePTDS:
2587 return ptds._cudaGraphNodeFindInClone(pNode, originalNode, clonedGraph) 1B
2588 return _static_cudaGraphNodeFindInClone(pNode, originalNode, clonedGraph) 1B
2591cdef cudaError_t _cudaGraphNodeGetType(cudaGraphNode_t node, cudaGraphNodeType* pType) except ?cudaErrorCallRequiresNewerDriver nogil:
2592 cdef bint usePTDS = cudaPythonInit()
2593 if usePTDS:
2594 return ptds._cudaGraphNodeGetType(node, pType)
2595 return _static_cudaGraphNodeGetType(node, pType)
2598cdef cudaError_t _cudaGraphGetNodes(cudaGraph_t graph, cudaGraphNode_t* nodes, size_t* numNodes) except ?cudaErrorCallRequiresNewerDriver nogil:
2599 cdef bint usePTDS = cudaPythonInit() 1B
2600 if usePTDS: 1aB
2601 return ptds._cudaGraphGetNodes(graph, nodes, numNodes) 1x
2602 return _static_cudaGraphGetNodes(graph, nodes, numNodes) 1xB
2605cdef cudaError_t _cudaGraphGetRootNodes(cudaGraph_t graph, cudaGraphNode_t* pRootNodes, size_t* pNumRootNodes) except ?cudaErrorCallRequiresNewerDriver nogil:
2606 cdef bint usePTDS = cudaPythonInit()
2607 if usePTDS:
2608 return ptds._cudaGraphGetRootNodes(graph, pRootNodes, pNumRootNodes) 1m
2609 return _static_cudaGraphGetRootNodes(graph, pRootNodes, pNumRootNodes) 1m
2612cdef cudaError_t _cudaGraphGetEdges(cudaGraph_t graph, cudaGraphNode_t* from_, cudaGraphNode_t* to, cudaGraphEdgeData* edgeData, size_t* numEdges) except ?cudaErrorCallRequiresNewerDriver nogil:
2613 cdef bint usePTDS = cudaPythonInit() 1x
2614 if usePTDS: 1ax
2615 return ptds._cudaGraphGetEdges(graph, from_, to, edgeData, numEdges) 1m
2616 return _static_cudaGraphGetEdges(graph, from_, to, edgeData, numEdges) 1xm
2619cdef cudaError_t _cudaGraphNodeGetDependencies(cudaGraphNode_t node, cudaGraphNode_t* pDependencies, cudaGraphEdgeData* edgeData, size_t* pNumDependencies) except ?cudaErrorCallRequiresNewerDriver nogil:
2620 cdef bint usePTDS = cudaPythonInit() 1m
2621 if usePTDS: 1am
2622 return ptds._cudaGraphNodeGetDependencies(node, pDependencies, edgeData, pNumDependencies)
2623 return _static_cudaGraphNodeGetDependencies(node, pDependencies, edgeData, pNumDependencies) 1m
2626cdef cudaError_t _cudaGraphNodeGetDependentNodes(cudaGraphNode_t node, cudaGraphNode_t* pDependentNodes, cudaGraphEdgeData* edgeData, size_t* pNumDependentNodes) except ?cudaErrorCallRequiresNewerDriver nogil:
2627 cdef bint usePTDS = cudaPythonInit() 1m
2628 if usePTDS: 1am
2629 return ptds._cudaGraphNodeGetDependentNodes(node, pDependentNodes, edgeData, pNumDependentNodes)
2630 return _static_cudaGraphNodeGetDependentNodes(node, pDependentNodes, edgeData, pNumDependentNodes) 1m
2633cdef cudaError_t _cudaGraphAddDependencies(cudaGraph_t graph, const cudaGraphNode_t* from_, const cudaGraphNode_t* to, const cudaGraphEdgeData* edgeData, size_t numDependencies) except ?cudaErrorCallRequiresNewerDriver nogil:
2634 cdef bint usePTDS = cudaPythonInit()
2635 if usePTDS:
2636 return ptds._cudaGraphAddDependencies(graph, from_, to, edgeData, numDependencies) 1K
2637 return _static_cudaGraphAddDependencies(graph, from_, to, edgeData, numDependencies) 1K
2640cdef cudaError_t _cudaGraphRemoveDependencies(cudaGraph_t graph, const cudaGraphNode_t* from_, const cudaGraphNode_t* to, const cudaGraphEdgeData* edgeData, size_t numDependencies) except ?cudaErrorCallRequiresNewerDriver nogil:
2641 cdef bint usePTDS = cudaPythonInit()
2642 if usePTDS:
2643 return ptds._cudaGraphRemoveDependencies(graph, from_, to, edgeData, numDependencies) 1decJ
2644 return _static_cudaGraphRemoveDependencies(graph, from_, to, edgeData, numDependencies) 1decJ
2647cdef cudaError_t _cudaGraphDestroyNode(cudaGraphNode_t node) except ?cudaErrorCallRequiresNewerDriver nogil:
2648 cdef bint usePTDS = cudaPythonInit() 1K
2649 if usePTDS: 1aK
2650 return ptds._cudaGraphDestroyNode(node)
2651 return _static_cudaGraphDestroyNode(node) 1K
2654cdef cudaError_t _cudaGraphInstantiate(cudaGraphExec_t* pGraphExec, cudaGraph_t graph, unsigned long long flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2655 cdef bint usePTDS = cudaPythonInit() 1decJ
2656 if usePTDS: 1adecJ
2657 return ptds._cudaGraphInstantiate(pGraphExec, graph, flags)
2658 return _static_cudaGraphInstantiate(pGraphExec, graph, flags) 1decJ
2661cdef cudaError_t _cudaGraphInstantiateWithFlags(cudaGraphExec_t* pGraphExec, cudaGraph_t graph, unsigned long long flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2662 cdef bint usePTDS = cudaPythonInit()
2663 if usePTDS:
2664 return ptds._cudaGraphInstantiateWithFlags(pGraphExec, graph, flags)
2665 return _static_cudaGraphInstantiateWithFlags(pGraphExec, graph, flags)
2668cdef cudaError_t _cudaGraphInstantiateWithParams(cudaGraphExec_t* pGraphExec, cudaGraph_t graph, cudaGraphInstantiateParams* instantiateParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2669 cdef bint usePTDS = cudaPythonInit()
2670 if usePTDS:
2671 return ptds._cudaGraphInstantiateWithParams(pGraphExec, graph, instantiateParams)
2672 return _static_cudaGraphInstantiateWithParams(pGraphExec, graph, instantiateParams)
2675cdef cudaError_t _cudaGraphExecGetFlags(cudaGraphExec_t graphExec, unsigned long long* flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2676 cdef bint usePTDS = cudaPythonInit()
2677 if usePTDS:
2678 return ptds._cudaGraphExecGetFlags(graphExec, flags)
2679 return _static_cudaGraphExecGetFlags(graphExec, flags)
2682cdef cudaError_t _cudaGraphExecKernelNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaKernelNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2683 cdef bint usePTDS = cudaPythonInit()
2684 if usePTDS:
2685 return ptds._cudaGraphExecKernelNodeSetParams(hGraphExec, node, pNodeParams)
2686 return _static_cudaGraphExecKernelNodeSetParams(hGraphExec, node, pNodeParams)
2689cdef cudaError_t _cudaGraphExecMemcpyNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaMemcpy3DParms* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2690 cdef bint usePTDS = cudaPythonInit()
2691 if usePTDS:
2692 return ptds._cudaGraphExecMemcpyNodeSetParams(hGraphExec, node, pNodeParams)
2693 return _static_cudaGraphExecMemcpyNodeSetParams(hGraphExec, node, pNodeParams)
2696cdef cudaError_t _cudaGraphExecMemcpyNodeSetParams1D(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, void* dst, const void* src, size_t count, cudaMemcpyKind kind) except ?cudaErrorCallRequiresNewerDriver nogil:
2697 cdef bint usePTDS = cudaPythonInit()
2698 if usePTDS:
2699 return ptds._cudaGraphExecMemcpyNodeSetParams1D(hGraphExec, node, dst, src, count, kind)
2700 return _static_cudaGraphExecMemcpyNodeSetParams1D(hGraphExec, node, dst, src, count, kind)
2703cdef cudaError_t _cudaGraphExecMemsetNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaMemsetParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2704 cdef bint usePTDS = cudaPythonInit()
2705 if usePTDS:
2706 return ptds._cudaGraphExecMemsetNodeSetParams(hGraphExec, node, pNodeParams)
2707 return _static_cudaGraphExecMemsetNodeSetParams(hGraphExec, node, pNodeParams)
2710cdef cudaError_t _cudaGraphExecHostNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, const cudaHostNodeParams* pNodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2711 cdef bint usePTDS = cudaPythonInit()
2712 if usePTDS:
2713 return ptds._cudaGraphExecHostNodeSetParams(hGraphExec, node, pNodeParams)
2714 return _static_cudaGraphExecHostNodeSetParams(hGraphExec, node, pNodeParams)
2717cdef cudaError_t _cudaGraphExecChildGraphNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t node, cudaGraph_t childGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
2718 cdef bint usePTDS = cudaPythonInit()
2719 if usePTDS:
2720 return ptds._cudaGraphExecChildGraphNodeSetParams(hGraphExec, node, childGraph)
2721 return _static_cudaGraphExecChildGraphNodeSetParams(hGraphExec, node, childGraph)
2724cdef cudaError_t _cudaGraphExecEventRecordNodeSetEvent(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2725 cdef bint usePTDS = cudaPythonInit()
2726 if usePTDS:
2727 return ptds._cudaGraphExecEventRecordNodeSetEvent(hGraphExec, hNode, event)
2728 return _static_cudaGraphExecEventRecordNodeSetEvent(hGraphExec, hNode, event)
2731cdef cudaError_t _cudaGraphExecEventWaitNodeSetEvent(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
2732 cdef bint usePTDS = cudaPythonInit()
2733 if usePTDS:
2734 return ptds._cudaGraphExecEventWaitNodeSetEvent(hGraphExec, hNode, event)
2735 return _static_cudaGraphExecEventWaitNodeSetEvent(hGraphExec, hNode, event)
2738cdef cudaError_t _cudaGraphExecExternalSemaphoresSignalNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, const cudaExternalSemaphoreSignalNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2739 cdef bint usePTDS = cudaPythonInit()
2740 if usePTDS:
2741 return ptds._cudaGraphExecExternalSemaphoresSignalNodeSetParams(hGraphExec, hNode, nodeParams)
2742 return _static_cudaGraphExecExternalSemaphoresSignalNodeSetParams(hGraphExec, hNode, nodeParams)
2745cdef cudaError_t _cudaGraphExecExternalSemaphoresWaitNodeSetParams(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, const cudaExternalSemaphoreWaitNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2746 cdef bint usePTDS = cudaPythonInit()
2747 if usePTDS:
2748 return ptds._cudaGraphExecExternalSemaphoresWaitNodeSetParams(hGraphExec, hNode, nodeParams)
2749 return _static_cudaGraphExecExternalSemaphoresWaitNodeSetParams(hGraphExec, hNode, nodeParams)
2752cdef cudaError_t _cudaGraphNodeSetEnabled(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, unsigned int isEnabled) except ?cudaErrorCallRequiresNewerDriver nogil:
2753 cdef bint usePTDS = cudaPythonInit()
2754 if usePTDS:
2755 return ptds._cudaGraphNodeSetEnabled(hGraphExec, hNode, isEnabled)
2756 return _static_cudaGraphNodeSetEnabled(hGraphExec, hNode, isEnabled)
2759cdef cudaError_t _cudaGraphNodeGetEnabled(cudaGraphExec_t hGraphExec, cudaGraphNode_t hNode, unsigned int* isEnabled) except ?cudaErrorCallRequiresNewerDriver nogil:
2760 cdef bint usePTDS = cudaPythonInit()
2761 if usePTDS:
2762 return ptds._cudaGraphNodeGetEnabled(hGraphExec, hNode, isEnabled)
2763 return _static_cudaGraphNodeGetEnabled(hGraphExec, hNode, isEnabled)
2766cdef cudaError_t _cudaGraphExecUpdate(cudaGraphExec_t hGraphExec, cudaGraph_t hGraph, cudaGraphExecUpdateResultInfo* resultInfo) except ?cudaErrorCallRequiresNewerDriver nogil:
2767 cdef bint usePTDS = cudaPythonInit()
2768 if usePTDS:
2769 return ptds._cudaGraphExecUpdate(hGraphExec, hGraph, resultInfo) 1ec
2770 return _static_cudaGraphExecUpdate(hGraphExec, hGraph, resultInfo) 1ec
2773cdef cudaError_t _cudaGraphUpload(cudaGraphExec_t graphExec, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2774 cdef bint usePTDS = cudaPythonInit()
2775 if usePTDS:
2776 return ptds._cudaGraphUpload(graphExec, stream) 1dJ
2777 return _static_cudaGraphUpload(graphExec, stream) 1dJ
2780cdef cudaError_t _cudaGraphLaunch(cudaGraphExec_t graphExec, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
2781 cdef bint usePTDS = cudaPythonInit() 1ec
2782 if usePTDS: 1aec
2783 return ptds._cudaGraphLaunch(graphExec, stream) 1sdEltuxmJKV
2784 return _static_cudaGraphLaunch(graphExec, stream) 1sdEltuecxmJKV
2787cdef cudaError_t _cudaGraphExecDestroy(cudaGraphExec_t graphExec) except ?cudaErrorCallRequiresNewerDriver nogil:
2788 cdef bint usePTDS = cudaPythonInit() 1dJ
2789 if usePTDS: 1adJ
2790 return ptds._cudaGraphExecDestroy(graphExec)
2791 return _static_cudaGraphExecDestroy(graphExec) 1dJ
2794cdef cudaError_t _cudaGraphDestroy(cudaGraph_t graph) except ?cudaErrorCallRequiresNewerDriver nogil:
2795 cdef bint usePTDS = cudaPythonInit() 1sdEltuxmJKV
2796 if usePTDS: 1asdEltuxmJKV
2797 return ptds._cudaGraphDestroy(graph)
2798 return _static_cudaGraphDestroy(graph) 1sdEltuxmJKV
2801cdef cudaError_t _cudaGraphDebugDotPrint(cudaGraph_t graph, const char* path, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2802 cdef bint usePTDS = cudaPythonInit()
2803 if usePTDS:
2804 return ptds._cudaGraphDebugDotPrint(graph, path, flags)
2805 return _static_cudaGraphDebugDotPrint(graph, path, flags)
2808cdef cudaError_t _cudaUserObjectCreate(cudaUserObject_t* object_out, void* ptr, cudaHostFn_t destroy, unsigned int initialRefcount, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2809 cdef bint usePTDS = cudaPythonInit()
2810 if usePTDS:
2811 return ptds._cudaUserObjectCreate(object_out, ptr, destroy, initialRefcount, flags)
2812 return _static_cudaUserObjectCreate(object_out, ptr, destroy, initialRefcount, flags)
2815cdef cudaError_t _cudaUserObjectRetain(cudaUserObject_t object, unsigned int count) except ?cudaErrorCallRequiresNewerDriver nogil:
2816 cdef bint usePTDS = cudaPythonInit()
2817 if usePTDS:
2818 return ptds._cudaUserObjectRetain(object, count)
2819 return _static_cudaUserObjectRetain(object, count)
2822cdef cudaError_t _cudaUserObjectRelease(cudaUserObject_t object, unsigned int count) except ?cudaErrorCallRequiresNewerDriver nogil:
2823 cdef bint usePTDS = cudaPythonInit()
2824 if usePTDS:
2825 return ptds._cudaUserObjectRelease(object, count)
2826 return _static_cudaUserObjectRelease(object, count)
2829cdef cudaError_t _cudaGraphRetainUserObject(cudaGraph_t graph, cudaUserObject_t object, unsigned int count, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2830 cdef bint usePTDS = cudaPythonInit()
2831 if usePTDS:
2832 return ptds._cudaGraphRetainUserObject(graph, object, count, flags) 1lG
2833 return _static_cudaGraphRetainUserObject(graph, object, count, flags) 1lG
2836cdef cudaError_t _cudaGraphReleaseUserObject(cudaGraph_t graph, cudaUserObject_t object, unsigned int count) except ?cudaErrorCallRequiresNewerDriver nogil:
2837 cdef bint usePTDS = cudaPythonInit()
2838 if usePTDS:
2839 return ptds._cudaGraphReleaseUserObject(graph, object, count)
2840 return _static_cudaGraphReleaseUserObject(graph, object, count)
2843cdef cudaError_t _cudaGraphAddNode(cudaGraphNode_t* pGraphNode, cudaGraph_t graph, const cudaGraphNode_t* pDependencies, const cudaGraphEdgeData* dependencyData, size_t numDependencies, cudaGraphNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2844 cdef bint usePTDS = cudaPythonInit() 1lG
2845 if usePTDS: 1alG
2846 return ptds._cudaGraphAddNode(pGraphNode, graph, pDependencies, dependencyData, numDependencies, nodeParams)
2847 return _static_cudaGraphAddNode(pGraphNode, graph, pDependencies, dependencyData, numDependencies, nodeParams) 1lG
2850cdef cudaError_t _cudaGraphNodeSetParams(cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2851 cdef bint usePTDS = cudaPythonInit()
2852 if usePTDS:
2853 return ptds._cudaGraphNodeSetParams(node, nodeParams) 1G
2854 return _static_cudaGraphNodeSetParams(node, nodeParams) 1G
2857cdef cudaError_t _cudaGraphExecNodeSetParams(cudaGraphExec_t graphExec, cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
2858 cdef bint usePTDS = cudaPythonInit()
2859 if usePTDS:
2860 return ptds._cudaGraphExecNodeSetParams(graphExec, node, nodeParams)
2861 return _static_cudaGraphExecNodeSetParams(graphExec, node, nodeParams)
2864cdef cudaError_t _cudaGraphConditionalHandleCreate(cudaGraphConditionalHandle* pHandle_out, cudaGraph_t graph, unsigned int defaultLaunchValue, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
2865 cdef bint usePTDS = cudaPythonInit() 1G
2866 if usePTDS: 1aG
2867 return ptds._cudaGraphConditionalHandleCreate(pHandle_out, graph, defaultLaunchValue, flags)
2868 return _static_cudaGraphConditionalHandleCreate(pHandle_out, graph, defaultLaunchValue, flags) 1G
2871cdef cudaError_t _cudaGetDriverEntryPoint(const char* symbol, void** funcPtr, unsigned long long flags, cudaDriverEntryPointQueryResult* driverStatus) except ?cudaErrorCallRequiresNewerDriver nogil:
2872 cdef bint usePTDS = cudaPythonInit()
2873 if usePTDS:
2874 return ptds._cudaGetDriverEntryPoint(symbol, funcPtr, flags, driverStatus)
2875 return _static_cudaGetDriverEntryPoint(symbol, funcPtr, flags, driverStatus)
2878cdef cudaError_t _cudaGetDriverEntryPointByVersion(const char* symbol, void** funcPtr, unsigned int cudaVersion, unsigned long long flags, cudaDriverEntryPointQueryResult* driverStatus) except ?cudaErrorCallRequiresNewerDriver nogil:
2879 cdef bint usePTDS = cudaPythonInit()
2880 if usePTDS:
2881 return ptds._cudaGetDriverEntryPointByVersion(symbol, funcPtr, cudaVersion, flags, driverStatus)
2882 return _static_cudaGetDriverEntryPointByVersion(symbol, funcPtr, cudaVersion, flags, driverStatus)
2885cdef cudaError_t _cudaLibraryLoadData(cudaLibrary_t* library, const void* code, cudaJitOption* jitOptions, void** jitOptionsValues, unsigned int numJitOptions, cudaLibraryOption* libraryOptions, void** libraryOptionValues, unsigned int numLibraryOptions) except ?cudaErrorCallRequiresNewerDriver nogil:
2886 cdef bint usePTDS = cudaPythonInit()
2887 if usePTDS:
2888 return ptds._cudaLibraryLoadData(library, code, jitOptions, jitOptionsValues, numJitOptions, libraryOptions, libraryOptionValues, numLibraryOptions)
2889 return _static_cudaLibraryLoadData(library, code, jitOptions, jitOptionsValues, numJitOptions, libraryOptions, libraryOptionValues, numLibraryOptions)
2892cdef cudaError_t _cudaLibraryLoadFromFile(cudaLibrary_t* library, const char* fileName, cudaJitOption* jitOptions, void** jitOptionsValues, unsigned int numJitOptions, cudaLibraryOption* libraryOptions, void** libraryOptionValues, unsigned int numLibraryOptions) except ?cudaErrorCallRequiresNewerDriver nogil:
2893 cdef bint usePTDS = cudaPythonInit()
2894 if usePTDS:
2895 return ptds._cudaLibraryLoadFromFile(library, fileName, jitOptions, jitOptionsValues, numJitOptions, libraryOptions, libraryOptionValues, numLibraryOptions)
2896 return _static_cudaLibraryLoadFromFile(library, fileName, jitOptions, jitOptionsValues, numJitOptions, libraryOptions, libraryOptionValues, numLibraryOptions)
2899cdef cudaError_t _cudaLibraryUnload(cudaLibrary_t library) except ?cudaErrorCallRequiresNewerDriver nogil:
2900 cdef bint usePTDS = cudaPythonInit()
2901 if usePTDS:
2902 return ptds._cudaLibraryUnload(library)
2903 return _static_cudaLibraryUnload(library)
2906cdef cudaError_t _cudaLibraryGetKernel(cudaKernel_t* pKernel, cudaLibrary_t library, const char* name) except ?cudaErrorCallRequiresNewerDriver nogil:
2907 cdef bint usePTDS = cudaPythonInit()
2908 if usePTDS:
2909 return ptds._cudaLibraryGetKernel(pKernel, library, name)
2910 return _static_cudaLibraryGetKernel(pKernel, library, name)
2913cdef cudaError_t _cudaLibraryGetGlobal(void** dptr, size_t* bytes, cudaLibrary_t library, const char* name) except ?cudaErrorCallRequiresNewerDriver nogil:
2914 cdef bint usePTDS = cudaPythonInit()
2915 if usePTDS:
2916 return ptds._cudaLibraryGetGlobal(dptr, bytes, library, name)
2917 return _static_cudaLibraryGetGlobal(dptr, bytes, library, name)
2920cdef cudaError_t _cudaLibraryGetManaged(void** dptr, size_t* bytes, cudaLibrary_t library, const char* name) except ?cudaErrorCallRequiresNewerDriver nogil:
2921 cdef bint usePTDS = cudaPythonInit()
2922 if usePTDS:
2923 return ptds._cudaLibraryGetManaged(dptr, bytes, library, name)
2924 return _static_cudaLibraryGetManaged(dptr, bytes, library, name)
2927cdef cudaError_t _cudaLibraryGetUnifiedFunction(void** fptr, cudaLibrary_t library, const char* symbol) except ?cudaErrorCallRequiresNewerDriver nogil:
2928 cdef bint usePTDS = cudaPythonInit()
2929 if usePTDS:
2930 return ptds._cudaLibraryGetUnifiedFunction(fptr, library, symbol)
2931 return _static_cudaLibraryGetUnifiedFunction(fptr, library, symbol)
2934cdef cudaError_t _cudaLibraryGetKernelCount(unsigned int* count, cudaLibrary_t lib) except ?cudaErrorCallRequiresNewerDriver nogil:
2935 cdef bint usePTDS = cudaPythonInit()
2936 if usePTDS:
2937 return ptds._cudaLibraryGetKernelCount(count, lib)
2938 return _static_cudaLibraryGetKernelCount(count, lib)
2941cdef cudaError_t _cudaLibraryEnumerateKernels(cudaKernel_t* kernels, unsigned int numKernels, cudaLibrary_t lib) except ?cudaErrorCallRequiresNewerDriver nogil:
2942 cdef bint usePTDS = cudaPythonInit()
2943 if usePTDS:
2944 return ptds._cudaLibraryEnumerateKernels(kernels, numKernels, lib)
2945 return _static_cudaLibraryEnumerateKernels(kernels, numKernels, lib)
2948cdef cudaError_t _cudaKernelSetAttributeForDevice(cudaKernel_t kernel, cudaFuncAttribute attr, int value, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
2949 cdef bint usePTDS = cudaPythonInit()
2950 if usePTDS:
2951 return ptds._cudaKernelSetAttributeForDevice(kernel, attr, value, device)
2952 return _static_cudaKernelSetAttributeForDevice(kernel, attr, value, device)
2955cdef cudaError_t _cudaGetExportTable(const void** ppExportTable, const cudaUUID_t* pExportTableId) except ?cudaErrorCallRequiresNewerDriver nogil:
2956 cdef bint usePTDS = cudaPythonInit()
2957 if usePTDS:
2958 return ptds._cudaGetExportTable(ppExportTable, pExportTableId) 1S
2959 return _static_cudaGetExportTable(ppExportTable, pExportTableId) 1S
2962cdef cudaError_t _cudaGetKernel(cudaKernel_t* kernelPtr, const void* entryFuncAddr) except ?cudaErrorCallRequiresNewerDriver nogil:
2963 cdef bint usePTDS = cudaPythonInit()
2964 if usePTDS:
2965 return ptds._cudaGetKernel(kernelPtr, entryFuncAddr) 1S
2966 return _static_cudaGetKernel(kernelPtr, entryFuncAddr) 1S
2969cdef cudaError_t _cudaProfilerStart() except ?cudaErrorCallRequiresNewerDriver nogil:
2970 cdef bint usePTDS = cudaPythonInit() 1S
2971 if usePTDS: 1aS
2972 return ptds._cudaProfilerStart() 1#$
2973 return _static_cudaProfilerStart() 1#$S
2976cdef cudaError_t _cudaProfilerStop() except ?cudaErrorCallRequiresNewerDriver nogil:
2977 cdef bint usePTDS = cudaPythonInit() 1S
2978 if usePTDS: 1aS
2979 return ptds._cudaProfilerStop()
2980 return _static_cudaProfilerStop() 1S
2983cdef cudaError_t _cudaGetDeviceProperties(cudaDeviceProp* prop, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
2984 cdef bint usePTDS = cudaPythonInit() 1#$
2985 if usePTDS: 1a#$
2986 return ptds._cudaGetDeviceProperties(prop, device)
2987 return _static_cudaGetDeviceProperties(prop, device) 1#$
2990cdef cudaError_t _cudaDeviceGetHostAtomicCapabilities(unsigned int* capabilities, const cudaAtomicOperation* operations, unsigned int count, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
2991 cdef bint usePTDS = cudaPythonInit()
2992 if usePTDS:
2993 return ptds._cudaDeviceGetHostAtomicCapabilities(capabilities, operations, count, device) 1A
2994 return _static_cudaDeviceGetHostAtomicCapabilities(capabilities, operations, count, device) 1A
2997cdef cudaError_t _cudaDeviceGetP2PAtomicCapabilities(unsigned int* capabilities, const cudaAtomicOperation* operations, unsigned int count, int srcDevice, int dstDevice) except ?cudaErrorCallRequiresNewerDriver nogil:
2998 cdef bint usePTDS = cudaPythonInit()
2999 if usePTDS:
3000 return ptds._cudaDeviceGetP2PAtomicCapabilities(capabilities, operations, count, srcDevice, dstDevice)
3001 return _static_cudaDeviceGetP2PAtomicCapabilities(capabilities, operations, count, srcDevice, dstDevice)
3004cdef cudaError_t _cudaStreamGetCaptureInfo(cudaStream_t stream, cudaStreamCaptureStatus* captureStatus_out, unsigned long long* id_out, cudaGraph_t* graph_out, const cudaGraphNode_t** dependencies_out, const cudaGraphEdgeData** edgeData_out, size_t* numDependencies_out) except ?cudaErrorCallRequiresNewerDriver nogil:
3005 cdef bint usePTDS = cudaPythonInit() 1A
3006 if usePTDS: 1aA
3007 return ptds._cudaStreamGetCaptureInfo(stream, captureStatus_out, id_out, graph_out, dependencies_out, edgeData_out, numDependencies_out)
3008 return _static_cudaStreamGetCaptureInfo(stream, captureStatus_out, id_out, graph_out, dependencies_out, edgeData_out, numDependencies_out) 1A
3011cdef cudaError_t _cudaSignalExternalSemaphoresAsync(const cudaExternalSemaphore_t* extSemArray, const cudaExternalSemaphoreSignalParams* paramsArray, unsigned int numExtSems, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3012 cdef bint usePTDS = cudaPythonInit()
3013 if usePTDS:
3014 return ptds._cudaSignalExternalSemaphoresAsync(extSemArray, paramsArray, numExtSems, stream)
3015 return _static_cudaSignalExternalSemaphoresAsync(extSemArray, paramsArray, numExtSems, stream)
3018cdef cudaError_t _cudaWaitExternalSemaphoresAsync(const cudaExternalSemaphore_t* extSemArray, const cudaExternalSemaphoreWaitParams* paramsArray, unsigned int numExtSems, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3019 cdef bint usePTDS = cudaPythonInit()
3020 if usePTDS:
3021 return ptds._cudaWaitExternalSemaphoresAsync(extSemArray, paramsArray, numExtSems, stream)
3022 return _static_cudaWaitExternalSemaphoresAsync(extSemArray, paramsArray, numExtSems, stream)
3025cdef cudaError_t _cudaMemPrefetchBatchAsync(void** dptrs, size_t* sizes, size_t count, cudaMemLocation* prefetchLocs, size_t* prefetchLocIdxs, size_t numPrefetchLocs, unsigned long long flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3026 cdef bint usePTDS = cudaPythonInit()
3027 if usePTDS:
3028 return ptds._cudaMemPrefetchBatchAsync(dptrs, sizes, count, prefetchLocs, prefetchLocIdxs, numPrefetchLocs, flags, stream)
3029 return _static_cudaMemPrefetchBatchAsync(dptrs, sizes, count, prefetchLocs, prefetchLocIdxs, numPrefetchLocs, flags, stream)
3032cdef cudaError_t _cudaMemDiscardBatchAsync(void** dptrs, size_t* sizes, size_t count, unsigned long long flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3033 cdef bint usePTDS = cudaPythonInit()
3034 if usePTDS:
3035 return ptds._cudaMemDiscardBatchAsync(dptrs, sizes, count, flags, stream)
3036 return _static_cudaMemDiscardBatchAsync(dptrs, sizes, count, flags, stream)
3039cdef cudaError_t _cudaMemDiscardAndPrefetchBatchAsync(void** dptrs, size_t* sizes, size_t count, cudaMemLocation* prefetchLocs, size_t* prefetchLocIdxs, size_t numPrefetchLocs, unsigned long long flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3040 cdef bint usePTDS = cudaPythonInit()
3041 if usePTDS:
3042 return ptds._cudaMemDiscardAndPrefetchBatchAsync(dptrs, sizes, count, prefetchLocs, prefetchLocIdxs, numPrefetchLocs, flags, stream)
3043 return _static_cudaMemDiscardAndPrefetchBatchAsync(dptrs, sizes, count, prefetchLocs, prefetchLocIdxs, numPrefetchLocs, flags, stream)
3046cdef cudaError_t _cudaMemGetDefaultMemPool(cudaMemPool_t* memPool, cudaMemLocation* location, cudaMemAllocationType type) except ?cudaErrorCallRequiresNewerDriver nogil:
3047 cdef bint usePTDS = cudaPythonInit()
3048 if usePTDS:
3049 return ptds._cudaMemGetDefaultMemPool(memPool, location, type)
3050 return _static_cudaMemGetDefaultMemPool(memPool, location, type)
3053cdef cudaError_t _cudaMemGetMemPool(cudaMemPool_t* memPool, cudaMemLocation* location, cudaMemAllocationType type) except ?cudaErrorCallRequiresNewerDriver nogil:
3054 cdef bint usePTDS = cudaPythonInit()
3055 if usePTDS:
3056 return ptds._cudaMemGetMemPool(memPool, location, type)
3057 return _static_cudaMemGetMemPool(memPool, location, type)
3060cdef cudaError_t _cudaMemSetMemPool(cudaMemLocation* location, cudaMemAllocationType type, cudaMemPool_t memPool) except ?cudaErrorCallRequiresNewerDriver nogil:
3061 cdef bint usePTDS = cudaPythonInit()
3062 if usePTDS:
3063 return ptds._cudaMemSetMemPool(location, type, memPool)
3064 return _static_cudaMemSetMemPool(location, type, memPool)
3067cdef cudaError_t _cudaLogsRegisterCallback(cudaLogsCallback_t callbackFunc, void* userData, cudaLogsCallbackHandle* callback_out) except ?cudaErrorCallRequiresNewerDriver nogil:
3068 cdef bint usePTDS = cudaPythonInit()
3069 if usePTDS:
3070 return ptds._cudaLogsRegisterCallback(callbackFunc, userData, callback_out)
3071 return _static_cudaLogsRegisterCallback(callbackFunc, userData, callback_out)
3074cdef cudaError_t _cudaLogsUnregisterCallback(cudaLogsCallbackHandle callback) except ?cudaErrorCallRequiresNewerDriver nogil:
3075 cdef bint usePTDS = cudaPythonInit()
3076 if usePTDS:
3077 return ptds._cudaLogsUnregisterCallback(callback)
3078 return _static_cudaLogsUnregisterCallback(callback)
3081cdef cudaError_t _cudaLogsCurrent(cudaLogIterator* iterator_out, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
3082 cdef bint usePTDS = cudaPythonInit()
3083 if usePTDS:
3084 return ptds._cudaLogsCurrent(iterator_out, flags)
3085 return _static_cudaLogsCurrent(iterator_out, flags)
3088cdef cudaError_t _cudaLogsDumpToFile(cudaLogIterator* iterator, const char* pathToFile, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
3089 cdef bint usePTDS = cudaPythonInit()
3090 if usePTDS:
3091 return ptds._cudaLogsDumpToFile(iterator, pathToFile, flags) 1l
3092 return _static_cudaLogsDumpToFile(iterator, pathToFile, flags) 1l
3095cdef cudaError_t _cudaLogsDumpToMemory(cudaLogIterator* iterator, char* buffer, size_t* size, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
3096 cdef bint usePTDS = cudaPythonInit()
3097 if usePTDS:
3098 return ptds._cudaLogsDumpToMemory(iterator, buffer, size, flags) 1t
3099 return _static_cudaLogsDumpToMemory(iterator, buffer, size, flags) 1t
3102cdef cudaError_t _cudaGraphNodeGetContainingGraph(cudaGraphNode_t hNode, cudaGraph_t* phGraph) except ?cudaErrorCallRequiresNewerDriver nogil:
3103 cdef bint usePTDS = cudaPythonInit() 1l
3104 if usePTDS: 1al
3105 return ptds._cudaGraphNodeGetContainingGraph(hNode, phGraph) 1u
3106 return _static_cudaGraphNodeGetContainingGraph(hNode, phGraph) 1lu
3109cdef cudaError_t _cudaGraphNodeGetLocalId(cudaGraphNode_t hNode, unsigned int* nodeId) except ?cudaErrorCallRequiresNewerDriver nogil:
3110 cdef bint usePTDS = cudaPythonInit() 1t
3111 if usePTDS: 1at
3112 return ptds._cudaGraphNodeGetLocalId(hNode, nodeId) 1E
3113 return _static_cudaGraphNodeGetLocalId(hNode, nodeId) 1Et
3116cdef cudaError_t _cudaGraphNodeGetToolsId(cudaGraphNode_t hNode, unsigned long long* toolsNodeId) except ?cudaErrorCallRequiresNewerDriver nogil:
3117 cdef bint usePTDS = cudaPythonInit() 1u
3118 if usePTDS: 1au
3119 return ptds._cudaGraphNodeGetToolsId(hNode, toolsNodeId) 1d
3120 return _static_cudaGraphNodeGetToolsId(hNode, toolsNodeId) 1du
3123cdef cudaError_t _cudaGraphGetId(cudaGraph_t hGraph, unsigned int* graphID) except ?cudaErrorCallRequiresNewerDriver nogil:
3124 cdef bint usePTDS = cudaPythonInit() 1E
3125 if usePTDS: 1aE
3126 return ptds._cudaGraphGetId(hGraph, graphID) 1s
3127 return _static_cudaGraphGetId(hGraph, graphID) 1sE
3130cdef cudaError_t _cudaGraphExecGetId(cudaGraphExec_t hGraphExec, unsigned int* graphID) except ?cudaErrorCallRequiresNewerDriver nogil:
3131 cdef bint usePTDS = cudaPythonInit() 1d
3132 if usePTDS: 1ad
3133 return ptds._cudaGraphExecGetId(hGraphExec, graphID) 1MN19q
3134 return _static_cudaGraphExecGetId(hGraphExec, graphID) 1MN19dq
3137cdef cudaError_t _cudaGraphConditionalHandleCreate_v2(cudaGraphConditionalHandle* pHandle_out, cudaGraph_t graph, cudaExecutionContext_t ctx, unsigned int defaultLaunchValue, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
3138 cdef bint usePTDS = cudaPythonInit() 1s
3139 if usePTDS: 1as
3140 return ptds._cudaGraphConditionalHandleCreate_v2(pHandle_out, graph, ctx, defaultLaunchValue, flags) 1N
3141 return _static_cudaGraphConditionalHandleCreate_v2(pHandle_out, graph, ctx, defaultLaunchValue, flags) 1Ns
3144cdef cudaError_t _cudaDeviceGetDevResource(int device, cudaDevResource* resource, cudaDevResourceType type) except ?cudaErrorCallRequiresNewerDriver nogil:
3145 cdef bint usePTDS = cudaPythonInit() 1MN19q
3146 if usePTDS: 1aMN19q
3147 return ptds._cudaDeviceGetDevResource(device, resource, type) 11
3148 return _static_cudaDeviceGetDevResource(device, resource, type) 1MN19q
3151cdef cudaError_t _cudaDevSmResourceSplitByCount(cudaDevResource* result, unsigned int* nbGroups, const cudaDevResource* input, cudaDevResource* remaining, unsigned int flags, unsigned int minCount) except ?cudaErrorCallRequiresNewerDriver nogil:
3152 cdef bint usePTDS = cudaPythonInit() 1N
3153 if usePTDS: 1aN
3154 return ptds._cudaDevSmResourceSplitByCount(result, nbGroups, input, remaining, flags, minCount) 1Mq
3155 return _static_cudaDevSmResourceSplitByCount(result, nbGroups, input, remaining, flags, minCount) 1MNq
3158cdef cudaError_t _cudaDevSmResourceSplit(cudaDevResource* result, unsigned int nbGroups, const cudaDevResource* input, cudaDevResource* remainder, unsigned int flags, cudaDevSmResourceGroupParams* groupParams) except ?cudaErrorCallRequiresNewerDriver nogil:
3159 cdef bint usePTDS = cudaPythonInit() 11
3160 if usePTDS: 1a1
3161 return ptds._cudaDevSmResourceSplit(result, nbGroups, input, remainder, flags, groupParams) 1q
3162 return _static_cudaDevSmResourceSplit(result, nbGroups, input, remainder, flags, groupParams) 11q
3165cdef cudaError_t _cudaDevResourceGenerateDesc(cudaDevResourceDesc_t* phDesc, cudaDevResource* resources, unsigned int nbResources) except ?cudaErrorCallRequiresNewerDriver nogil:
3166 cdef bint usePTDS = cudaPythonInit() 1Mq
3167 if usePTDS: 1aMq
3168 return ptds._cudaDevResourceGenerateDesc(phDesc, resources, nbResources) 1q
3169 return _static_cudaDevResourceGenerateDesc(phDesc, resources, nbResources) 1Mq
3172cdef cudaError_t _cudaGreenCtxCreate(cudaExecutionContext_t* phCtx, cudaDevResourceDesc_t desc, int device, unsigned int flags) except ?cudaErrorCallRequiresNewerDriver nogil:
3173 cdef bint usePTDS = cudaPythonInit() 1q
3174 if usePTDS: 1aq
3175 return ptds._cudaGreenCtxCreate(phCtx, desc, device, flags) 1O
3176 return _static_cudaGreenCtxCreate(phCtx, desc, device, flags) 1Oq
3179cdef cudaError_t _cudaExecutionCtxDestroy(cudaExecutionContext_t ctx) except ?cudaErrorCallRequiresNewerDriver nogil:
3180 cdef bint usePTDS = cudaPythonInit() 1q
3181 if usePTDS: 1aq
3182 return ptds._cudaExecutionCtxDestroy(ctx) 1P
3183 return _static_cudaExecutionCtxDestroy(ctx) 1Pq
3186cdef cudaError_t _cudaExecutionCtxGetDevResource(cudaExecutionContext_t ctx, cudaDevResource* resource, cudaDevResourceType type) except ?cudaErrorCallRequiresNewerDriver nogil:
3187 cdef bint usePTDS = cudaPythonInit() 1O
3188 if usePTDS: 1aO
3189 return ptds._cudaExecutionCtxGetDevResource(ctx, resource, type) 1Q
3190 return _static_cudaExecutionCtxGetDevResource(ctx, resource, type) 1OQ
3193cdef cudaError_t _cudaExecutionCtxGetDevice(int* device, cudaExecutionContext_t ctx) except ?cudaErrorCallRequiresNewerDriver nogil:
3194 cdef bint usePTDS = cudaPythonInit() 1P
3195 if usePTDS: 1aP
3196 return ptds._cudaExecutionCtxGetDevice(device, ctx) 1D
3197 return _static_cudaExecutionCtxGetDevice(device, ctx) 1PD
3200cdef cudaError_t _cudaExecutionCtxGetId(cudaExecutionContext_t ctx, unsigned long long* ctxId) except ?cudaErrorCallRequiresNewerDriver nogil:
3201 cdef bint usePTDS = cudaPythonInit() 1Q
3202 if usePTDS: 1aQ
3203 return ptds._cudaExecutionCtxGetId(ctx, ctxId)
3204 return _static_cudaExecutionCtxGetId(ctx, ctxId) 1Q
3207cdef cudaError_t _cudaExecutionCtxStreamCreate(cudaStream_t* phStream, cudaExecutionContext_t ctx, unsigned int flags, int priority) except ?cudaErrorCallRequiresNewerDriver nogil:
3208 cdef bint usePTDS = cudaPythonInit() 1D
3209 if usePTDS: 1aD
3210 return ptds._cudaExecutionCtxStreamCreate(phStream, ctx, flags, priority) 1F
3211 return _static_cudaExecutionCtxStreamCreate(phStream, ctx, flags, priority) 1DF
3214cdef cudaError_t _cudaExecutionCtxSynchronize(cudaExecutionContext_t ctx) except ?cudaErrorCallRequiresNewerDriver nogil:
3215 cdef bint usePTDS = cudaPythonInit()
3216 if usePTDS:
3217 return ptds._cudaExecutionCtxSynchronize(ctx)
3218 return _static_cudaExecutionCtxSynchronize(ctx)
3221cdef cudaError_t _cudaStreamGetDevResource(cudaStream_t hStream, cudaDevResource* resource, cudaDevResourceType type) except ?cudaErrorCallRequiresNewerDriver nogil:
3222 cdef bint usePTDS = cudaPythonInit() 1F
3223 if usePTDS: 1aF
3224 return ptds._cudaStreamGetDevResource(hStream, resource, type)
3225 return _static_cudaStreamGetDevResource(hStream, resource, type) 1F
3228cdef cudaError_t _cudaExecutionCtxRecordEvent(cudaExecutionContext_t ctx, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
3229 cdef bint usePTDS = cudaPythonInit()
3230 if usePTDS:
3231 return ptds._cudaExecutionCtxRecordEvent(ctx, event) 1OPQDs
3232 return _static_cudaExecutionCtxRecordEvent(ctx, event) 1OPQDs
3235cdef cudaError_t _cudaExecutionCtxWaitEvent(cudaExecutionContext_t ctx, cudaEvent_t event) except ?cudaErrorCallRequiresNewerDriver nogil:
3236 cdef bint usePTDS = cudaPythonInit()
3237 if usePTDS:
3238 return ptds._cudaExecutionCtxWaitEvent(ctx, event)
3239 return _static_cudaExecutionCtxWaitEvent(ctx, event)
3242cdef cudaError_t _cudaDeviceGetExecutionCtx(cudaExecutionContext_t* ctx, int device) except ?cudaErrorCallRequiresNewerDriver nogil:
3243 cdef bint usePTDS = cudaPythonInit() 1OPQDs
3244 if usePTDS: 1aOPQDs
3245 return ptds._cudaDeviceGetExecutionCtx(ctx, device)
3246 return _static_cudaDeviceGetExecutionCtx(ctx, device) 1OPQDs
3249cdef cudaError_t _cudaFuncGetParamCount(const void* func, size_t* paramCount) except ?cudaErrorCallRequiresNewerDriver nogil:
3250 cdef bint usePTDS = cudaPythonInit()
3251 if usePTDS:
3252 return ptds._cudaFuncGetParamCount(func, paramCount)
3253 return _static_cudaFuncGetParamCount(func, paramCount)
3256cdef cudaError_t _cudaLaunchHostFunc_v2(cudaStream_t stream, cudaHostFn_t fn, void* userData, unsigned int syncMode) except ?cudaErrorCallRequiresNewerDriver nogil:
3257 cdef bint usePTDS = cudaPythonInit()
3258 if usePTDS:
3259 return ptds._cudaLaunchHostFunc_v2(stream, fn, userData, syncMode)
3260 return _static_cudaLaunchHostFunc_v2(stream, fn, userData, syncMode)
3263cdef cudaError_t _cudaMemcpyWithAttributesAsync(void* dst, const void* src, size_t size, cudaMemcpyAttributes* attr, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3264 cdef bint usePTDS = cudaPythonInit()
3265 if usePTDS:
3266 return ptds._cudaMemcpyWithAttributesAsync(dst, src, size, attr, stream)
3267 return _static_cudaMemcpyWithAttributesAsync(dst, src, size, attr, stream)
3270cdef cudaError_t _cudaMemcpy3DWithAttributesAsync(cudaMemcpy3DBatchOp* op, unsigned long long flags, cudaStream_t stream) except ?cudaErrorCallRequiresNewerDriver nogil:
3271 cdef bint usePTDS = cudaPythonInit()
3272 if usePTDS:
3273 return ptds._cudaMemcpy3DWithAttributesAsync(op, flags, stream)
3274 return _static_cudaMemcpy3DWithAttributesAsync(op, flags, stream)
3277cdef cudaError_t _cudaGraphNodeGetParams(cudaGraphNode_t node, cudaGraphNodeParams* nodeParams) except ?cudaErrorCallRequiresNewerDriver nogil:
3278 cdef bint usePTDS = cudaPythonInit()
3279 if usePTDS:
3280 return ptds._cudaGraphNodeGetParams(node, nodeParams)
3281 return _static_cudaGraphNodeGetParams(node, nodeParams)
3284cdef cudaError_t _cudaStreamBeginRecaptureToGraph(cudaStream_t stream, cudaStreamCaptureMode mode, cudaGraph_t graph, cudaGraphRecaptureCallbackData* callbackData) except ?cudaErrorCallRequiresNewerDriver nogil:
3285 cdef bint usePTDS = cudaPythonInit()
3286 if usePTDS:
3287 return ptds._cudaStreamBeginRecaptureToGraph(stream, mode, graph, callbackData)
3288 return _static_cudaStreamBeginRecaptureToGraph(stream, mode, graph, callbackData)